@@ -78,8 +78,11 @@ lw6cli_test (int mode)
        * Just to make sure most functions are stuffed in the binary
        */
       lw6sys_test (mode);
+      lw6glb_test (mode);
       lw6cfg_test (mode);
       lw6net_test (mode);
+      lw6nod_test (mode);
+      lw6msg_test (mode);
     }
 
   if (lw6net_init (argc, argv))
