@@ -27,16 +27,6 @@
 #include "../cli.h"
 #include "mod-udp-internal.h"
 
-int
-_mod_udp_can_handle (_udp_context_t * udp_context, char *server_url)
-{
-  int ret = 0;
-
-  // todo
-
-  return ret;
-}
-
 lw6cli_connection_t *
 _mod_udp_connect (_udp_context_t * udp_context, char *server_url,
 		  char *client_url, char *password)
