@@ -28,20 +28,37 @@
 #include "mod-udp-internal.h"
 
 _udp_context_t *
-_mod_udp_init ()
+_mod_udp_init (int argc, char *argv[])
 {
   _udp_context_t *udp_context = NULL;
+  char *data_dir = NULL;
+  int ok = 0;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("udp init"));
 
   udp_context = (_udp_context_t *) LW6SYS_CALLOC (sizeof (_udp_context_t));
-  if (!udp_context)
+  if (udp_context)
     {
-      /*
-       * No use to continue if this basic malloc fails...
-       */
-      exit (1);
+      data_dir = lw6sys_get_data_dir (argc, argv);
+      if (data_dir)
+	{
+	  if (_mod_udp_load_data (&(udp_context->data), data_dir))
+	    {
+	      ok = 1;
+	    }
+	  LW6SYS_FREE (data_dir);
+	}
+      if (!ok)
+	{
+	  _mod_udp_quit (udp_context);
+	  udp_context = NULL;
+	}
     }
 
-  lw6sys_log (LW6SYS_LOG_INFO, "cli-mod-udp", _("udp init"));
+  if (!udp_context)
+    {
+      lw6sys_log (LW6SYS_LOG_ERROR, _("can't initialize mod_udp"));
+    }
 
   return udp_context;
 }
@@ -49,6 +66,7 @@ _mod_udp_init ()
 void
 _mod_udp_quit (_udp_context_t * udp_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, "cli-mod-udp", _("udp quit"));
+  lw6sys_log (LW6SYS_LOG_INFO, _("udp quit"));
+  _mod_udp_unload_data (&(udp_context->data));
   LW6SYS_FREE (udp_context);
 }
