@@ -44,3 +44,20 @@ _mod_udp_is_alive (_udp_context_t * udp_context,
 
   return ret;
 }
+
+int
+_mod_udp_timeout_ok (_udp_context_t * udp_context, int64_t origin_timestamp,
+		     int broadcast)
+{
+  int ret = 0;
+  int d = 0;
+
+  d =
+    origin_timestamp +
+    ((broadcast ? udp_context->data.consts.
+      broadcast_timeout : udp_context->data.consts.global_timeout) * 1000) -
+    lw6sys_get_timestamp ();
+  ret = (d > 0);
+
+  return ret;
+}
