@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include "../dyn/dyn.h"
 #include "../map/map.h"
 #include "../ker/ker.h"
+#include "../pil/pil.h"
 #include "../hlp/hlp.h"
 #include "../cfg/cfg.h"
 #include "../ldr/ldr.h"
@@ -53,11 +54,12 @@ typedef struct lw6gfx_backend_s
 		  lw6map_level_t * level,
 		  lw6ker_game_struct_t * game_struct,
 		  lw6ker_game_state_t * game_state,
-		  lw6gui_main_cursor_t * main_cursor,
+		  lw6pil_local_cursors_t * local_cursors,
 		  lw6gui_menu_t * menu,
 		  float progress,
-		  float fps, float rps,
-		  char **log_list, int debug_team_id, int debug_layer_id);
+		  float fps, float mps,
+		  char **log_list, int capture, int gfx_debug,
+		  int debug_team_id, int debug_layer_id);
 }
 lw6gfx_backend_t;
 
@@ -80,9 +82,10 @@ extern int lw6gfx_display (lw6gfx_backend_t * backend, int mask,
 			   lw6gui_look_t * look, lw6map_level_t * level,
 			   lw6ker_game_struct_t * game_struct,
 			   lw6ker_game_state_t * game_state,
-			   lw6gui_main_cursor_t * main_cursor,
+			   lw6pil_local_cursors_t * local_cursors,
 			   lw6gui_menu_t * menu, float progress, float fps,
-			   float rps, char **log_list, int debug_team_id,
+			   float mps, char **log_list, int capture,
+			   int gfx_debug, int debug_team_id,
 			   int debug_layer_id);
 
 /*
@@ -93,9 +96,7 @@ extern lw6gfx_backend_t *lw6gfx_create_backend (int argc, char *argv[],
 						char *name);
 extern void lw6gfx_destroy_backend (lw6gfx_backend_t * backend);
 
-/*
- * In test.c
- */
-extern int lw6gfx_test ();
+/* gfx-test.c */
+extern int lw6gfx_test (int mode);
 
 #endif
