@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include "../../mod-gl.h"
 #include "gl-bubbles-internal.h"
 
+/*
 static void
 set_background_texture_options (mod_gl_utils_context_t * utils_context,
 				_mod_gl_background_bubbles_context_t *
@@ -37,24 +38,32 @@ set_background_texture_options (mod_gl_utils_context_t * utils_context,
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
 }
+*/
 
 static void
-display_background (mod_gl_utils_context_t * utils_context,
-		    _mod_gl_background_bubbles_context_t * bubbles_context,
-		    lw6gui_look_t * look)
+_display_background (mod_gl_utils_context_t * utils_context,
+		     _mod_gl_background_bubbles_context_t * bubbles_context,
+		     lw6gui_look_t * look)
 {
   mod_gl_utils_set_render_mode_2d (utils_context);
 
-  glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.background);
-  set_background_texture_options (utils_context, bubbles_context);
+  mod_gl_utils_bitmap_colorize (utils_context,
+				bubbles_context->bitmap_data.background,
+				look->style.colorize,
+				&(look->style.color_set.
+				  background_color_root));
+  mod_gl_utils_bitmap_bind (utils_context,
+			    bubbles_context->bitmap_data.background);
+
+  //glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.background);
+  //set_background_texture_options (utils_context, bubbles_context);
 
   glMatrixMode (GL_TEXTURE);
   glPushMatrix ();
   glLoadIdentity ();
   glTranslatef (0.0f,
 		bubbles_context->const_data.yspeed *
-		(mod_gl_utils_timer_uptime (utils_context) % 1000000000) /
-		1000.0f, 0.0f);
+		mod_gl_utils_timer_get_cycle (utils_context) / 1000.0f, 0.0f);
 
   glBegin (GL_QUADS);
   glTexCoord2d (0.0f, 0.0f);
@@ -72,9 +81,10 @@ display_background (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-display_bubble (mod_gl_utils_context_t * utils_context,
-		_mod_gl_background_bubbles_context_t *
-		bubbles_context, _mod_gl_background_bubbles_bubble_t * bubble)
+_display_bubble (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_background_bubbles_context_t *
+		 bubbles_context,
+		 _mod_gl_background_bubbles_bubble_t * bubble)
 {
   int dt;
   float y;
@@ -83,23 +93,26 @@ display_bubble (mod_gl_utils_context_t * utils_context,
   if (!bubble->active)
     {
       bubble->active = 1;
-      bubble->t0 = mod_gl_utils_timer_uptime (utils_context);
+      bubble->t0 = mod_gl_utils_timer_get_uptime (utils_context);
       bubble->size =
 	lw6sys_random_float (bubbles_context->const_data.bubble_size_min,
 			     bubbles_context->const_data.bubble_size_max);
       bubble->x = lw6sys_random_float (0.0f, 1.0f);
     }
 
-  dt = mod_gl_utils_timer_uptime (utils_context) - bubble->t0;
+  dt = mod_gl_utils_timer_get_uptime (utils_context) - bubble->t0;
   x_px = bubble->x * utils_context->video_mode.width;
   y =
     1.0f + (bubble->size / 2.0f) -
     (bubble->size * bubbles_context->const_data.bubble_yspeed * dt / 1000.0f);
   y_px = y * utils_context->video_mode.height;
   size2_px = (utils_context->video_mode.height * bubble->size) / 2.0f;
-
-  glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.bubble);
-  set_background_texture_options (utils_context, bubbles_context);
+  /*
+     glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.bubble);
+     set_background_texture_options (utils_context, bubbles_context);
+   */
+  //  mod_gl_utils_bitmap_colorize(utils_context,bubbles_context->bitmap_data.bubble,look->style.colorize,&(look->style.background_stuff));
+  //mod_gl_utils_bitmap_bind(utils_context,bubbles_context->bitmap_data.bubble);
 
   glMatrixMode (GL_TEXTURE);
   glPushMatrix ();
@@ -126,16 +139,24 @@ display_bubble (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-display_bubbles (mod_gl_utils_context_t * utils_context,
-		 _mod_gl_background_bubbles_context_t *
-		 bubbles_context, lw6gui_look_t * look)
+_display_bubbles (mod_gl_utils_context_t * utils_context,
+		  _mod_gl_background_bubbles_context_t *
+		  bubbles_context, lw6gui_look_t * look)
 {
   int i;
 
   mod_gl_utils_set_render_mode_2d_blend (utils_context);
 
-  glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.bubble);
-  set_background_texture_options (utils_context, bubbles_context);
+  //glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.bubble);
+  mod_gl_utils_bitmap_colorize (utils_context,
+				bubbles_context->bitmap_data.bubble,
+				look->style.colorize,
+				&(look->style.color_set.
+				  background_color_stuff));
+  mod_gl_utils_bitmap_bind (utils_context,
+			    bubbles_context->bitmap_data.bubble);
+
+  //set_background_texture_options (utils_context, bubbles_context);
 
   if (bubbles_context->const_data.nb_bubbles >
       _MOD_GL_BACKGROUND_BUBBLES_MAX_BUBBLES)
@@ -146,8 +167,8 @@ display_bubbles (mod_gl_utils_context_t * utils_context,
 
   for (i = 0; i < bubbles_context->const_data.nb_bubbles; ++i)
     {
-      display_bubble (utils_context, bubbles_context,
-		      &(bubbles_context->state.bubbles[i]));
+      _display_bubble (utils_context, bubbles_context,
+		       &(bubbles_context->state.bubbles[i]));
     }
 }
 
@@ -158,10 +179,10 @@ _mod_gl_background_bubbles_display_background (mod_gl_utils_context_t *
 					       * bubbles_context,
 					       lw6gui_look_t * look)
 {
-  _mod_gl_background_bubbles_colorize_if_needed (utils_context,
-						 bubbles_context, look);
-  display_background (utils_context, bubbles_context, look);
-  display_bubbles (utils_context, bubbles_context, look);
+  //  _mod_gl_background_bubbles_colorize_if_needed (utils_context,
+  //                                             bubbles_context, look);
+  _display_background (utils_context, bubbles_context, look);
+  _display_bubbles (utils_context, bubbles_context, look);
 }
 
 void
