@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -61,8 +61,8 @@ draw_cylinder_with_color (mod_gl_utils_context_t * utils_context,
   float radius;
   float cyl_height;
 
-  done = look->style.menu_color_default.fg;
-  todo = look->style.menu_color_default.bg;
+  done = look->style.color_set.menu_color_default.fg;
+  todo = look->style.color_set.menu_color_default.bg;
   sdl_done = mod_gl_utils_color_8_to_sdl (done);
   sdl_todo = mod_gl_utils_color_8_to_sdl (todo);
   i_done = lw6sys_color_8_to_i (done);
