@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,57 +36,56 @@ mod_gl_utils_display_log (mod_gl_utils_context_t * context,
   mod_gl_utils_draw_system_text_bottom_left (context, look, log_list);
 }
 
-void
-mod_gl_display_log (void *context, lw6gui_look_t * look, char **log_list)
-{
-  mod_gl_utils_display_log ((mod_gl_utils_context_t *) context, look,
-			    log_list);
-}
-
 void
 mod_gl_utils_display_fps (mod_gl_utils_context_t * context,
 			  lw6gui_look_t * look, float fps)
 {
   char *list_fps[2];
 
-  list_fps[0] = lw6sys_itoa ((int) fps);
-  list_fps[1] = NULL;
-
-  if (list_fps[0])
+  if (fps >= 0)
     {
-      mod_gl_utils_draw_system_text_top_right (context, look, list_fps);
-      LW6SYS_FREE (list_fps[0]);
-    }
-}
+      list_fps[0] = lw6sys_itoa (fps);
+      list_fps[1] = NULL;
 
-void
-mod_gl_display_fps (void *context, lw6gui_look_t * look, float fps)
-{
-  mod_gl_utils_display_fps ((mod_gl_utils_context_t *) context, look, fps);
-}
-
-void
-mod_gl_utils_display_rps (mod_gl_utils_context_t * context,
-			  lw6gui_look_t * look, float rps)
-{
-  char *list_rps[3];
-
-  if (rps >= 0.1f)
-    {
-      list_rps[0] = " ";
-      list_rps[1] = lw6sys_new_sprintf ("%0.1f", rps);
-      list_rps[2] = NULL;
-
-      if (list_rps[0])
+      if (list_fps[0])
 	{
-	  mod_gl_utils_draw_system_text_top_right (context, look, list_rps);
-	  LW6SYS_FREE (list_rps[1]);
+	  mod_gl_utils_draw_system_text_top_left (context, look, list_fps);
+	  LW6SYS_FREE (list_fps[0]);
 	}
     }
 }
 
 void
-mod_gl_display_rps (void *context, lw6gui_look_t * look, float rps)
+mod_gl_utils_display_mps (mod_gl_utils_context_t * context,
+			  lw6gui_look_t * look, float mps, int target_mps)
 {
-  mod_gl_utils_display_rps ((mod_gl_utils_context_t *) context, look, rps);
+  char *list_mps[3];
+
+  if (mps >= 0.0f)
+    {
+      list_mps[0] = " ";
+      list_mps[1] = lw6sys_new_sprintf ("%d/%d", (int) mps, target_mps);
+      list_mps[2] = NULL;
+
+      if (list_mps[0])
+	{
+	  mod_gl_utils_draw_system_text_top_left (context, look, list_mps);
+	  LW6SYS_FREE (list_mps[1]);
+	}
+    }
+}
+
+void
+mod_gl_utils_display_url (mod_gl_utils_context_t * context,
+			  lw6gui_look_t * look, char *url)
+{
+  char *list_url[2];
+
+  if (url)
+    {
+      list_url[0] = url;
+      list_url[1] = NULL;
+
+      mod_gl_utils_draw_system_text_bottom_right (context, look, list_url);
+    }
 }
