@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,22 +28,33 @@
 #include "gl-utils.h"
 
 #define SUB "gfx/gl"
+#define CAPTURE "capture"
 
 int
 mod_gl_utils_path_init (mod_gl_utils_context_t *
 			utils_context, int argc, char *argv[])
 {
   char *data_root_dir = NULL;
+  char *user_dir = NULL;
   int ret = 0;
 
   data_root_dir = lw6sys_get_data_dir (argc, argv);
   if (data_root_dir)
     {
       utils_context->path.data_dir = lw6sys_path_concat (data_root_dir, SUB);
-      ret = 1;
       LW6SYS_FREE (data_root_dir);
     }
 
+  user_dir = lw6sys_get_user_dir (argc, argv);
+  if (user_dir)
+    {
+      utils_context->path.capture_dir =
+	lw6sys_path_concat (user_dir, CAPTURE);
+      LW6SYS_FREE (user_dir);
+    }
+
+  ret = (utils_context->path.data_dir && utils_context->path.capture_dir);
+
   return ret;
 }
 
@@ -54,4 +65,8 @@ mod_gl_utils_path_quit (mod_gl_utils_context_t * utils_context)
     {
       LW6SYS_FREE (utils_context->path.data_dir);
     }
+  if (utils_context->path.capture_dir)
+    {
+      LW6SYS_FREE (utils_context->path.capture_dir);
+    }
 }
