@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,17 +31,36 @@ void
 mod_gl_utils_timer_update (mod_gl_utils_context_t * utils_context)
 {
   lw6sys_timer_update (&(utils_context->timer.timestamp),
-		       &(utils_context->timer.uptime));
+		       &(utils_context->timer.uptime),
+		       &(utils_context->timer.cycle));
 }
 
 int64_t
-mod_gl_utils_timer_timestamp (mod_gl_utils_context_t * utils_context)
+mod_gl_utils_timer_get_timestamp (mod_gl_utils_context_t * utils_context)
 {
   return utils_context->timer.timestamp;
 }
 
 int64_t
-mod_gl_utils_timer_uptime (mod_gl_utils_context_t * utils_context)
+mod_gl_utils_timer_get_uptime (mod_gl_utils_context_t * utils_context)
 {
   return utils_context->timer.uptime;
 }
+
+int32_t
+mod_gl_utils_timer_get_cycle (mod_gl_utils_context_t * utils_context)
+{
+  return utils_context->timer.cycle;
+}
+
+extern int64_t
+mod_gl_utils_timer_get_bitmap_refresh (mod_gl_utils_context_t * utils_context)
+{
+  return utils_context->timer.bitmap_refresh;
+}
+
+extern void
+mod_gl_utils_timer_set_bitmap_refresh (mod_gl_utils_context_t * utils_context)
+{
+  utils_context->timer.bitmap_refresh = utils_context->timer.timestamp;
+}
