@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -64,9 +64,43 @@
  */
 #define MOD_GL_SHADES_FOR_FIGHTERS_SCALE 64
 
+typedef struct mod_gl_utils_bitmap_s
+{
+  u_int32_t id;
+  char *filename;
+  SDL_Surface *surface;
+  int has_alpha;
+  SDL_Surface *colorized_surface;
+  int colorize;
+  lw6map_color_couple_t colorize_color;
+  int mipmap;
+  GLint wrap;
+  GLint filter;
+  GLuint texture;
+  int texture_w;
+  int texture_h;
+  float s1;
+  float t1;
+  float s2;
+  float t2;
+  u_int64_t last_refresh;
+} mod_gl_utils_bitmap_t;
+
+typedef struct mod_gl_utils_shaded_text_s
+{
+  TTF_Font *font;
+  char *text;
+  lw6map_color_couple_t color;
+  mod_gl_utils_bitmap_t *bg;
+  mod_gl_utils_bitmap_t *fg;
+  int texture_w;
+  int texture_h;
+} mod_gl_utils_shaded_text_t;
+
 typedef struct mod_gl_utils_path_s
 {
   char *data_dir;
+  char *capture_dir;
 }
 mod_gl_utils_path_t;
 
@@ -95,6 +129,12 @@ typedef enum mod_gl_utils_render_mode_e
 }
 mod_gl_utils_render_mode_t;
 
+typedef struct mod_gl_utils_render_param_s
+{
+  mod_gl_utils_render_mode_t mode;
+  int gfx_quality;
+} mod_gl_utils_render_param_t;
+
 typedef struct mod_gl_utils_rect_array_s
 {
   int n_w;
@@ -108,19 +148,12 @@ typedef struct mod_gl_utils_rect_array_s
 }
 mod_gl_utils_rect_array_t;
 
-typedef struct mod_gl_utils_surface_array_s
+typedef struct mod_gl_utils_bitmap_array_s
 {
   mod_gl_utils_rect_array_t layout;
-  SDL_Surface **surfaces;
+  mod_gl_utils_bitmap_t **bitmaps;
 }
-mod_gl_utils_surface_array_t;
-
-typedef struct mod_gl_utils_texture_array_s
-{
-  mod_gl_utils_rect_array_t layout;
-  GLuint *textures;
-}
-mod_gl_utils_texture_array_t;
+mod_gl_utils_bitmap_array_t;
 
 typedef struct mod_gl_utils_texture_data_s
 {
@@ -140,7 +173,7 @@ mod_gl_utils_font_data_t;
 typedef struct mod_gl_utils_menucache_item_s
 {
   char *key;
-  SDL_Surface *surface;
+  mod_gl_utils_bitmap_t *bitmap;
 }
 mod_gl_utils_menucache_item_t;
 
@@ -152,24 +185,6 @@ typedef struct mod_gl_utils_menucache_array_s
 }
 mod_gl_utils_menucache_array_t;
 
-typedef struct mod_gl_utils_texturecache_item_s
-{
-  int used;
-  int surface_w;
-  int surface_h;
-  char *str_key;
-  int int_key;
-  GLuint texture;
-}
-mod_gl_utils_texturecache_item_t;
-
-typedef struct mod_gl_utils_texturecache_array_s
-{
-  mod_gl_utils_texturecache_item_t
-    item_array[MOD_GL_UTILS_TEXTURECACHE_ARRAY_SIZE];
-}
-mod_gl_utils_texturecache_array_t;
-
 typedef struct mod_gl_utils_const_data_s
 {
   /*
@@ -243,15 +258,33 @@ mod_gl_utils_const_data_t;
 
 typedef struct mod_gl_utils_texture_1x1_s
 {
-  /*
-   * Set by the background module
-   */
-  GLuint menu_fg;
-  GLuint menu_bg;
-  GLuint menu_fg_disabled;
-  GLuint menu_bg_disabled;
-  GLuint menu_fg_selected;
-  GLuint menu_bg_selected;
+  lw6map_color_set_t color_set;
+  mod_gl_utils_bitmap_t *color_base_fg;
+  mod_gl_utils_bitmap_t *color_base_bg;
+  mod_gl_utils_bitmap_t *color_alternate_fg;
+  mod_gl_utils_bitmap_t *color_alternate_bg;
+  mod_gl_utils_bitmap_t *background_color_root_fg;
+  mod_gl_utils_bitmap_t *background_color_root_bg;
+  mod_gl_utils_bitmap_t *background_color_stuff_fg;
+  mod_gl_utils_bitmap_t *background_color_stuff_bg;
+  mod_gl_utils_bitmap_t *hud_color_frame_fg;
+  mod_gl_utils_bitmap_t *hud_color_frame_bg;
+  mod_gl_utils_bitmap_t *hud_color_text_fg;
+  mod_gl_utils_bitmap_t *hud_color_text_bg;
+  mod_gl_utils_bitmap_t *menu_color_default_fg;
+  mod_gl_utils_bitmap_t *menu_color_default_bg;
+  mod_gl_utils_bitmap_t *menu_color_selected_fg;
+  mod_gl_utils_bitmap_t *menu_color_selected_bg;
+  mod_gl_utils_bitmap_t *menu_color_disabled_fg;
+  mod_gl_utils_bitmap_t *menu_color_disabled_bg;
+  mod_gl_utils_bitmap_t *view_color_cursor_fg;
+  mod_gl_utils_bitmap_t *view_color_cursor_bg;
+  mod_gl_utils_bitmap_t *view_color_map_fg;
+  mod_gl_utils_bitmap_t *view_color_map_bg;
+  mod_gl_utils_bitmap_t *system_color_fg;
+  mod_gl_utils_bitmap_t *system_color_bg;
+  mod_gl_utils_bitmap_t *team_color_dead;
+  mod_gl_utils_bitmap_t *team_colors[LW6MAP_NB_TEAM_COLORS];
 }
 mod_gl_utils_texture_1x1_t;
 
@@ -265,8 +298,8 @@ mod_gl_utils_team_color_map_t;
 
 typedef struct mod_gl_utils_last_action_s
 {
-  int game_texture_array_update_id;
-  int game_texture_array_update_rounds;
+  int game_bitmap_array_update_id;
+  int game_bitmap_array_update_rounds;
 }
 mod_gl_utils_last_action_t;
 
@@ -288,6 +321,8 @@ typedef struct mod_gl_utils_timer_s
 {
   int64_t timestamp;
   int64_t uptime;
+  int32_t cycle;
+  int64_t bitmap_refresh;
 }
 mod_gl_utils_timer_t;
 
@@ -312,6 +347,18 @@ typedef struct _mod_gl_utils_smoothed_s
 }
 _mod_gl_utils_smoothed_t;
 
+typedef struct mod_gl_utils_icon_s
+{
+  mod_gl_utils_bitmap_t *bitmap;
+}
+mod_gl_utils_icon_t;
+
+typedef struct mod_gl_utils_counter_s
+{
+  int nb_frames;
+}
+mod_gl_utils_counter_t;
+
 typedef struct mod_gl_utils_context_s
 {
   lw6gui_resize_callback_func_t resize_callback;
@@ -320,13 +367,12 @@ typedef struct mod_gl_utils_context_s
   mod_gl_utils_mem_counter_t texture_counter;
   mod_gl_utils_caps_t caps;
   lw6gui_video_mode_t video_mode;
-  mod_gl_utils_render_mode_t render_mode;
+  mod_gl_utils_render_param_t render_param;
   mod_gl_utils_texture_data_t texture_data;
   mod_gl_utils_font_data_t font_data;
   mod_gl_utils_const_data_t const_data;
   mod_gl_utils_texture_1x1_t textures_1x1;
   mod_gl_utils_menucache_array_t menucache_array;
-  mod_gl_utils_texturecache_array_t texturecache_array;
   mod_gl_utils_team_color_map_t team_color_map;
   mod_gl_utils_last_action_t last_action;
   mod_gl_utils_joysticks_info_t joysticks_info;
@@ -335,9 +381,112 @@ typedef struct mod_gl_utils_context_s
   lw6gui_input_t input;
   _mod_gl_utils_smoothers_t smoothers;
   _mod_gl_utils_smoothed_t smoothed;
+  mod_gl_utils_icon_t icon;
+  mod_gl_utils_counter_t counter;
 }
 mod_gl_utils_context_t;
 
+/*
+ * In bitmap.c
+ */
+extern mod_gl_utils_bitmap_t *mod_gl_utils_bitmap_new (mod_gl_utils_context_t
+						       * utils_context,
+						       int width, int height);
+extern mod_gl_utils_bitmap_t *mod_gl_utils_bitmap_load (mod_gl_utils_context_t
+							* utils_context,
+							char *filename);
+extern mod_gl_utils_bitmap_t
+  * mod_gl_utils_surface2bitmap (mod_gl_utils_context_t * utils_context,
+				 SDL_Surface * surface);
+extern void mod_gl_utils_bitmap_free (mod_gl_utils_context_t * utils_context,
+				      mod_gl_utils_bitmap_t * bitmap);
+extern int mod_gl_utils_bitmap_colorize (mod_gl_utils_context_t *
+					 utils_context,
+					 mod_gl_utils_bitmap_t * bitmap,
+					 int colorize,
+					 lw6map_color_couple_t * color);
+extern int mod_gl_utils_bitmap_set_wrap (mod_gl_utils_context_t *
+					 utils_context,
+					 mod_gl_utils_bitmap_t * bitmap,
+					 GLint wrap);
+extern int mod_gl_utils_bitmap_set_filter (mod_gl_utils_context_t *
+					   utils_context,
+					   mod_gl_utils_bitmap_t * bitmap,
+					   GLint filter);
+extern int mod_gl_utils_bitmap_set_texture_coords (mod_gl_utils_context_t *
+						   utils_context,
+						   mod_gl_utils_bitmap_t *
+						   bitmap, float s1, float t1,
+						   float s2, float t2);
+extern void mod_gl_utils_bitmap_clear_texture (mod_gl_utils_context_t *
+					       utils_context,
+					       mod_gl_utils_bitmap_t *
+					       bitmap);
+extern void mod_gl_utils_bitmap_clear_texture_now (mod_gl_utils_context_t *
+						   utils_context,
+						   mod_gl_utils_bitmap_t *
+						   bitmap);
+extern int mod_gl_utils_bitmap_refresh (mod_gl_utils_context_t *
+					utils_context,
+					mod_gl_utils_bitmap_t * bitmap);
+extern int mod_gl_utils_bitmap_force_refresh (mod_gl_utils_context_t *
+					      utils_context,
+					      mod_gl_utils_bitmap_t * bitmap);
+extern int mod_gl_utils_bitmap_bind (mod_gl_utils_context_t * utils_context,
+				     mod_gl_utils_bitmap_t * bitmap);
+extern int mod_gl_utils_bitmap_display (mod_gl_utils_context_t *
+					utils_context,
+					mod_gl_utils_bitmap_t * bitmap,
+					float x1, float y1, float x2,
+					float y2);
+extern int mod_gl_utils_bitmap_update_texture (mod_gl_utils_context_t *
+					       utils_context,
+					       mod_gl_utils_bitmap_t *
+					       bitmap);
+
+/*
+ * In bitmaparray.c
+ */
+extern int mod_gl_utils_bitmap_array_init (mod_gl_utils_context_t *
+					   utils_context,
+					   mod_gl_utils_bitmap_array_t *
+					   bitmap_array, int w, int h,
+					   int tile_size);
+extern int mod_gl_utils_bitmap_array_init_from_surface (mod_gl_utils_context_t
+							* utils_context,
+							mod_gl_utils_bitmap_array_t
+							* bitmap_array,
+							SDL_Surface * surface,
+							int tile_size);
+extern int mod_gl_utils_bitmap_array_init_from_map (mod_gl_utils_context_t *
+						    utils_context,
+						    mod_gl_utils_bitmap_array_t
+						    * bitmap_array,
+						    lw6map_level_t * level,
+						    int tile_size);
+extern int mod_gl_utils_bitmap_array_update (mod_gl_utils_context_t *
+					     utils_context,
+					     mod_gl_utils_bitmap_array_t *
+					     bitmap_array, GLint wrap,
+					     GLint filter);
+extern void mod_gl_utils_bitmap_array_clear (mod_gl_utils_context_t *
+					     utils_context,
+					     mod_gl_utils_bitmap_array_t *
+					     bitmap_array);
+extern int mod_gl_utils_bitmap_array_set (mod_gl_utils_bitmap_array_t *
+					  bitmap_array, int n_x, int n_y,
+					  mod_gl_utils_bitmap_t * bitmap);
+extern mod_gl_utils_bitmap_t
+  * mod_gl_utils_bitmap_array_get (mod_gl_utils_bitmap_array_t * bitmap_array,
+				   int n_x, int n_y);
+
+/*
+ * In capture.c
+ */
+extern SDL_Surface *mod_gl_utils_capture2surface (mod_gl_utils_context_t *
+						  utils_context);
+extern int mod_gl_utils_capture2disk (mod_gl_utils_context_t * utils_context);
+
 /*
  * In color.c
  */
@@ -367,11 +516,11 @@ mod_gl_utils_get_shaded_color_for_fighter (mod_gl_utils_context_t *
 }
 
 // gl-utils-colorize.c
-extern SDL_Surface *mod_gl_utils_colorize_image (mod_gl_utils_context_t *
-						 utils_context,
-						 SDL_Surface * image,
-						 lw6map_color_couple_t *
-						 color, int has_alpha);
+extern SDL_Surface *mod_gl_utils_colorize_surface (mod_gl_utils_context_t *
+						   utils_context,
+						   SDL_Surface * surface,
+						   lw6map_color_couple_t *
+						   color, int has_alpha);
 
 /*
  * In consts.c
@@ -481,22 +630,26 @@ extern void mod_gl_utils_draw_system_text_bottom_right (mod_gl_utils_context_t
 /*
  * In game.c
  */
-extern void mod_gl_utils_update_game_texture (mod_gl_utils_context_t *
-					      utils_context,
-					      SDL_Surface * surface,
-					      GLuint texture,
-					      lw6ker_game_state_t *
-					      game_state,
-					      lw6gui_look_t * look);
-extern void mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
-						    utils_context,
-						    mod_gl_utils_surface_array_t
-						    * surface_array,
-						    mod_gl_utils_texture_array_t
-						    * texture_array,
-						    lw6ker_game_state_t *
-						    game_state,
-						    lw6gui_look_t * look);
+extern void mod_gl_utils_update_game_bitmap_raw (mod_gl_utils_context_t *
+						 utils_context,
+						 mod_gl_utils_bitmap_t *
+						 bitmap,
+						 lw6ker_game_state_t *
+						 game_state,
+						 lw6map_color_couple_t *
+						 map_color, int invert_y);
+extern void mod_gl_utils_update_game_bitmap (mod_gl_utils_context_t *
+					     utils_context,
+					     mod_gl_utils_bitmap_t * bitmap,
+					     lw6ker_game_state_t * game_state,
+					     lw6gui_look_t * look);
+extern void mod_gl_utils_update_game_bitmap_array (mod_gl_utils_context_t *
+						   utils_context,
+						   mod_gl_utils_bitmap_array_t
+						   * bitmap_array,
+						   lw6ker_game_state_t *
+						   game_state,
+						   lw6gui_look_t * look);
 
 /*
  * In gradient.c
@@ -507,6 +660,12 @@ extern SDL_Surface
 					  lw6ker_map_state_t * map_state,
 					  int team_id, int layer_id);
 
+/*
+ * In icon.c
+ */
+extern int mod_gl_utils_icon_set (mod_gl_utils_context_t * utils_context);
+extern void mod_gl_utils_icon_unset (mod_gl_utils_context_t * utils_context);
+
 /*
  * In info.c
  */
@@ -514,8 +673,11 @@ extern void mod_gl_utils_display_log (mod_gl_utils_context_t * utils_context,
 				      lw6gui_look_t * look, char **log_list);
 extern void mod_gl_utils_display_fps (mod_gl_utils_context_t * utils_context,
 				      lw6gui_look_t * look, float fps);
-extern void mod_gl_utils_display_rps (mod_gl_utils_context_t * utils_context,
-				      lw6gui_look_t * look, float rps);
+extern void mod_gl_utils_display_mps (mod_gl_utils_context_t * utils_context,
+				      lw6gui_look_t * look, float mps,
+				      int target_mps);
+extern void mod_gl_utils_display_url (mod_gl_utils_context_t * utils_context,
+				      lw6gui_look_t * look, char *url);
 
 /*
  * In joystick.c
@@ -538,8 +700,9 @@ extern int mod_gl_utils_store_button_in_menucache (mod_gl_utils_context_t *
 						   lw6gui_look_t * look,
 						   lw6gui_menuitem_t *
 						   menuitem,
-						   SDL_Surface * surface);
-extern SDL_Surface
+						   mod_gl_utils_bitmap_t *
+						   bitmap);
+extern mod_gl_utils_bitmap_t
   * mod_gl_utils_get_button_from_menucache (mod_gl_utils_context_t * context,
 					    lw6gui_look_t * look,
 					    lw6gui_menuitem_t * menuitem);
@@ -566,6 +729,8 @@ extern int mod_gl_utils_set_resize_callback (mod_gl_utils_context_t *
 					     utils_context,
 					     lw6gui_resize_callback_func_t
 					     resize_callback);
+extern void mod_gl_utils_call_resize_callback (mod_gl_utils_context_t *
+					       utils_context);
 
 /*
  * In mouse.c
@@ -639,6 +804,30 @@ extern void mod_gl_utils_find_closest_resolution (mod_gl_utils_context_t *
 						  int *closest_height,
 						  int wished_width,
 						  int wished_height);
+
+/*
+ * In shaded_text.c
+ */
+extern mod_gl_utils_shaded_text_t
+  * mod_gl_utils_shaded_text_new (mod_gl_utils_context_t * utils_context,
+				  TTF_Font * font, char *text,
+				  lw6map_color_couple_t * color);
+extern int mod_gl_utils_shaded_text_update (mod_gl_utils_context_t *
+					    utils_context,
+					    mod_gl_utils_shaded_text_t *
+					    shaded_text, char *text,
+					    lw6map_color_couple_t * color);
+extern int mod_gl_utils_shaded_text_display (mod_gl_utils_context_t *
+					     utils_context,
+					     mod_gl_utils_shaded_text_t *
+					     shaded_text, float x1, float y1,
+					     float x2, float y2, float dw,
+					     float dh);
+extern void mod_gl_utils_shaded_text_free (mod_gl_utils_context_t *
+					   utils_context,
+					   mod_gl_utils_shaded_text_t *
+					   shaded_text);
+
 /*
  * In smoothers.c
  */
@@ -673,46 +862,6 @@ extern SDL_Surface *mod_gl_utils_map2surface (mod_gl_utils_context_t *
 					      utils_context,
 					      lw6map_level_t * level);
 
-/*
- * In surfacearray.c
- */
-extern int mod_gl_utils_surface_array_init (mod_gl_utils_context_t *
-					    utils_context,
-					    mod_gl_utils_surface_array_t *
-					    surface_array, int w, int h,
-					    int tile_size);
-extern int
-mod_gl_utils_surface_array_init_from_surface (mod_gl_utils_context_t *
-					      utils_context,
-					      mod_gl_utils_surface_array_t *
-					      surface_array,
-					      SDL_Surface * surface,
-					      int tile_size);
-extern int mod_gl_utils_surface_array_init_from_map (mod_gl_utils_context_t *
-						     utils_context,
-						     mod_gl_utils_surface_array_t
-						     * surface_array,
-						     lw6map_level_t * level,
-						     int tile_size);
-extern void mod_gl_utils_surface_array_clear (mod_gl_utils_context_t *
-					      utils_context,
-					      mod_gl_utils_surface_array_t *
-					      surface_array);
-static inline void
-mod_gl_utils_set_surface_array_surface (mod_gl_utils_surface_array_t *
-					surface_array, int n_x, int n_y,
-					SDL_Surface * surface)
-{
-  surface_array->surfaces[n_y * surface_array->layout.n_w + n_x] = surface;
-}
-
-static inline SDL_Surface *
-mod_gl_utils_get_surface_array_surface (mod_gl_utils_surface_array_t *
-					surface_array, int n_x, int n_y)
-{
-  return (surface_array->surfaces[n_y * surface_array->layout.n_w + n_x]);
-}
-
 /*
  * In texture.c
  */
@@ -752,106 +901,36 @@ extern void mod_gl_utils_delete_scheduled_textures (mod_gl_utils_context_t *
 						    utils_context);
 extern void mod_gl_utils_texture_update (mod_gl_utils_context_t *
 					 utils_context, GLuint texture,
-					 SDL_Surface * surface, int pixelize);
+					 SDL_Surface * surface);
 
 /*
  * In texture1x1.c
  */
-extern GLuint mod_gl_utils_texture_1x1_color2texture (mod_gl_utils_context_t *
-						      utils_context,
-						      lw6sys_color_8_t
-						      color_8);
+extern mod_gl_utils_bitmap_t
+  * mod_gl_utils_texture_1x1_color2bitmap (mod_gl_utils_context_t *
+					   utils_context,
+					   lw6sys_color_8_t color_8);
 extern int mod_gl_utils_texture_1x1_update (mod_gl_utils_context_t *
 					    utils_context,
 					    lw6gui_look_t * look);
 extern void mod_gl_utils_texture_1x1_clear (mod_gl_utils_context_t *
 					    utils_context);
 
-/*
- * In texturearray.c
- */
-extern int mod_gl_utils_texture_array_init (mod_gl_utils_context_t *
-					    utils_context,
-					    mod_gl_utils_texture_array_t *
-					    texture_array, int w, int h,
-					    int tile_size, int mipmap);
-extern void mod_gl_utils_texture_array_update (mod_gl_utils_context_t *
-					       utils_context,
-					       mod_gl_utils_texture_array_t *
-					       texture_array,
-					       mod_gl_utils_surface_array_t *
-					       surface_array, int pixelize);
-extern void mod_gl_utils_texture_array_clear (mod_gl_utils_context_t *
-					      utils_context,
-					      mod_gl_utils_texture_array_t *
-					      texture_array);
-extern void mod_gl_utils_schedule_delete_texture_array (mod_gl_utils_context_t
-							* utils_context,
-							mod_gl_utils_texture_array_t
-							* texture_array);
-static inline void
-mod_gl_utils_set_texture_array_texture (mod_gl_utils_texture_array_t *
-					texture_array, int n_x, int n_y,
-					GLuint texture)
-{
-  texture_array->textures[n_y * texture_array->layout.n_w + n_x] = texture;
-}
-
-static inline GLuint
-mod_gl_utils_get_texture_array_texture (mod_gl_utils_texture_array_t *
-					texture_array, int n_x, int n_y)
-{
-  return (texture_array->textures[n_y * texture_array->layout.n_w + n_x]);
-}
-
-/*
- * In texturecache.c
- */
-extern GLuint
-mod_gl_utils_surface2texture_xywh_using_cache (mod_gl_utils_context_t *
-					       context, SDL_Surface * surface,
-					       int x, int y, int w, int h,
-					       char *str_key, int int_key);
-extern GLuint
-mod_gl_utils_surface2texture_wh_using_cache (mod_gl_utils_context_t * context,
-					     SDL_Surface * surface, int w,
-					     int h, char *str_key,
-					     int int_key);
-extern GLuint mod_gl_utils_surface2texture_using_cache (mod_gl_utils_context_t
-							* utils_context,
-							SDL_Surface * surface,
-							char *str_key,
-							int int_key);
-extern GLuint
-mod_gl_utils_map2texture_xywh_using_cache (mod_gl_utils_context_t * context,
-					   lw6map_level_t * level, int x,
-					   int y, int w, int h, char *str_key,
-					   int int_key);
-extern GLuint mod_gl_utils_map2texture_wh_using_cache (mod_gl_utils_context_t
-						       * context,
-						       lw6map_level_t * level,
-						       int w, int h,
-						       char *str_key,
-						       int int_key);
-extern GLuint mod_gl_utils_map2texture_using_cache (mod_gl_utils_context_t *
-						    utils_context,
-						    lw6map_level_t * level,
-						    char *str_key,
-						    int int_key);
-extern void mod_gl_utils_optimize_texturecache (mod_gl_utils_context_t *
-						utils_context);
-extern void mod_gl_utils_clear_texturecache (mod_gl_utils_context_t *
-					     utils_context);
-
 /*
  * In timer.c
  */
 extern void mod_gl_utils_timer_update (mod_gl_utils_context_t *
 				       utils_context);
-extern int64_t mod_gl_utils_timer_timestamp (mod_gl_utils_context_t *
+extern int64_t mod_gl_utils_timer_get_timestamp (mod_gl_utils_context_t *
+						 utils_context);
+extern int64_t mod_gl_utils_timer_get_uptime (mod_gl_utils_context_t *
+					      utils_context);
+extern int32_t mod_gl_utils_timer_get_cycle (mod_gl_utils_context_t *
 					     utils_context);
-extern int64_t mod_gl_utils_timer_uptime (mod_gl_utils_context_t *
-					  utils_context);
+extern int64_t mod_gl_utils_timer_get_bitmap_refresh (mod_gl_utils_context_t *
+						      utils_context);
+extern void mod_gl_utils_timer_set_bitmap_refresh (mod_gl_utils_context_t *
+						   utils_context);
 
 /*
  * In viewport.c
