@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,6 +52,7 @@ _set_fighters_rules (mod_gl_utils_context_t * utils_context,
    */
 }
 
+/*
 static void
 _set_cursor_rules (mod_gl_utils_context_t * utils_context,
 		   _mod_gl_view_flat_context_t * flat_context)
@@ -61,16 +62,17 @@ _set_cursor_rules (mod_gl_utils_context_t * utils_context,
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
 }
+*/
 
 static void
-_display_texture_array (mod_gl_utils_context_t * utils_context,
-			_mod_gl_view_flat_context_t * flat_context,
-			int texture_array_w,
-			int texture_array_h,
-			int shape_w,
-			int shape_h,
-			mod_gl_utils_texture_array_t * texture_array,
-			int center_x, int center_y, lw6gui_look_t * look)
+_display_bitmap_array (mod_gl_utils_context_t * utils_context,
+		       _mod_gl_view_flat_context_t * flat_context,
+		       int bitmap_array_w,
+		       int bitmap_array_h,
+		       int shape_w,
+		       int shape_h,
+		       mod_gl_utils_bitmap_array_t * bitmap_array,
+		       lw6gui_look_t * look)
 {
   float x1, y1, x2, y2, w, h, coef_x, coef_y;
   float texture_x1, texture_x2, texture_y1, texture_y2;
@@ -78,6 +80,7 @@ _display_texture_array (mod_gl_utils_context_t * utils_context,
   int n_x, n_y;
   int view_x, view_y, view_w, view_h;
   float min_x, min_y, max_x, max_y;
+  mod_gl_utils_bitmap_t *bitmap = NULL;
 
   x1 = flat_context->viewport.map_main.x1;
   y1 = flat_context->viewport.map_main.y1;
@@ -86,8 +89,8 @@ _display_texture_array (mod_gl_utils_context_t * utils_context,
 
   w = x2 - x1;
   h = y2 - y1;
-  coef_x = w / texture_array_w;
-  coef_y = h / texture_array_h;
+  coef_x = w / bitmap_array_w;
+  coef_y = h / bitmap_array_h;
 
   view_x = flat_context->viewport.drawable.x1;
   view_y = flat_context->viewport.drawable.y1;
@@ -99,68 +102,65 @@ _display_texture_array (mod_gl_utils_context_t * utils_context,
   max_x = view_x + view_w;
   max_y = view_y + view_h;
 
-  if (texture_array->layout.n_w > 0)
+  if (bitmap_array->layout.n_w > 0)
     {
-      for (n_x = 0; n_x < texture_array->layout.n_w; ++n_x)
+      for (n_x = 0; n_x < bitmap_array->layout.n_w; ++n_x)
 	{
-	  texture_array->layout.screen_x[n_x] =
-	    x1 + (texture_array->layout.x0[n_x] + 1) * coef_x;
+	  bitmap_array->layout.screen_x[n_x] =
+	    x1 + (bitmap_array->layout.x0[n_x] + 1) * coef_x;
 	}
-      texture_array->layout.screen_x[texture_array->layout.n_w] =
-	texture_array->layout.screen_x[texture_array->layout.n_w - 1] +
-	(texture_array->layout.w[texture_array->layout.n_w - 1] - 2) * coef_x;
+      bitmap_array->layout.screen_x[bitmap_array->layout.n_w] =
+	bitmap_array->layout.screen_x[bitmap_array->layout.n_w - 1] +
+	(bitmap_array->layout.w[bitmap_array->layout.n_w - 1] - 2) * coef_x;
     }
 
-  if (texture_array->layout.n_h > 0)
+  if (bitmap_array->layout.n_h > 0)
     {
-      for (n_y = 0; n_y < texture_array->layout.n_h; ++n_y)
+      for (n_y = 0; n_y < bitmap_array->layout.n_h; ++n_y)
 	{
-	  texture_array->layout.screen_y[n_y] =
-	    y1 + (texture_array->layout.y0[n_y] + 1) * coef_y;
+	  bitmap_array->layout.screen_y[n_y] =
+	    y1 + (bitmap_array->layout.y0[n_y] + 1) * coef_y;
 	}
-      texture_array->layout.screen_y[texture_array->layout.n_h] =
-	texture_array->layout.screen_y[texture_array->layout.n_h - 1] +
-	(texture_array->layout.h[texture_array->layout.n_h - 1] - 2) * coef_y;
+      bitmap_array->layout.screen_y[bitmap_array->layout.n_h] =
+	bitmap_array->layout.screen_y[bitmap_array->layout.n_h - 1] +
+	(bitmap_array->layout.h[bitmap_array->layout.n_h - 1] - 2) * coef_y;
     }
 
-  for (n_y = 0; n_y < texture_array->layout.n_h; ++n_y)
+  for (n_y = 0; n_y < bitmap_array->layout.n_h; ++n_y)
     {
-      for (n_x = 0; n_x < texture_array->layout.n_w; ++n_x)
+      for (n_x = 0; n_x < bitmap_array->layout.n_w; ++n_x)
 	{
-	  if (texture_array->layout.screen_x[n_x] > max_x ||
-	      texture_array->layout.screen_y[n_y] > max_y ||
-	      texture_array->layout.screen_x[n_x + 1] < min_x
-	      || texture_array->layout.screen_y[n_y + 1] < min_y)
+	  if (bitmap_array->layout.screen_x[n_x] > max_x ||
+	      bitmap_array->layout.screen_y[n_y] > max_y ||
+	      bitmap_array->layout.screen_x[n_x + 1] < min_x
+	      || bitmap_array->layout.screen_y[n_y + 1] < min_y)
 	    {
 	      // skip texture, it's outside our screen...
 	    }
 	  else
 	    {
-	      layout_w = texture_array->layout.w[n_x];
-	      layout_h = texture_array->layout.h[n_y];
+	      layout_w = bitmap_array->layout.w[n_x];
+	      layout_h = bitmap_array->layout.h[n_y];
 	      texture_w = mod_gl_utils_power_of_two_ge (layout_w);
 	      texture_h = mod_gl_utils_power_of_two_ge (layout_h);
 	      texture_x1 = 1.0f / texture_w;
 	      texture_y1 = 1.0f / texture_h;
 	      texture_x2 = (layout_w - 1.0f) / texture_w;
 	      texture_y2 = (layout_h - 1.0f) / texture_h;
-	      mod_gl_utils_display_texture_with_filter (utils_context,
-							mod_gl_utils_get_texture_array_texture
-							(texture_array, n_x,
-							 n_y),
-							texture_array->layout.
-							screen_x[n_x],
-							texture_array->layout.
-							screen_y[n_y],
-							texture_array->layout.
-							screen_x[n_x + 1],
-							texture_array->layout.
-							screen_y[n_y + 1],
-							texture_x1,
-							texture_y1,
-							texture_x2,
-							texture_y2,
-							look->style.pixelize);
+	      bitmap = mod_gl_utils_bitmap_array_get (bitmap_array, n_x, n_y);
+	      mod_gl_utils_bitmap_bind (utils_context, bitmap);
+	      mod_gl_utils_display_texture (utils_context,
+					    bitmap->texture,
+					    bitmap_array->layout.
+					    screen_x[n_x],
+					    bitmap_array->layout.
+					    screen_y[n_y],
+					    bitmap_array->layout.
+					    screen_x[n_x + 1],
+					    bitmap_array->layout.
+					    screen_y[n_y + 1], texture_x1,
+					    texture_y1, texture_x2,
+					    texture_y2);
 	    }
 	}
     }
@@ -169,17 +169,16 @@ _display_texture_array (mod_gl_utils_context_t * utils_context,
 static void
 _display_map_preview (mod_gl_utils_context_t * utils_context,
 		      _mod_gl_view_flat_context_t * flat_context,
-		      lw6gui_look_t * look, lw6map_level_t * level,
-		      int center_x, int center_y)
+		      lw6gui_look_t * look, lw6map_level_t * level)
 {
   _set_map_rules (utils_context, flat_context);
-  _display_texture_array (utils_context, flat_context,
-			  flat_context->game_context.map.level->texture.w,
-			  flat_context->game_context.map.level->texture.h,
-			  flat_context->game_context.map.level->body.shape.w,
-			  flat_context->game_context.map.level->body.shape.h,
-			  &(flat_context->game_context.map.map_texture_array),
-			  center_x, center_y, look);
+  _display_bitmap_array (utils_context, flat_context,
+			 flat_context->game_context.map.level->texture.w,
+			 flat_context->game_context.map.level->texture.h,
+			 flat_context->game_context.map.level->body.shape.w,
+			 flat_context->game_context.map.level->body.shape.h,
+			 &(flat_context->game_context.map.map_bitmap_array),
+			 look);
 }
 
 void
@@ -210,8 +209,7 @@ _mod_gl_view_flat_display_preview (mod_gl_utils_context_t * utils_context,
 
       _mod_gl_view_flat_viewport_update_preview (utils_context,
 						 flat_context, look, level);
-      _display_map_preview (utils_context, flat_context, look, level,
-			    level->body.shape.w / 2, level->body.shape.h / 2);
+      _display_map_preview (utils_context, flat_context, look, level);
     }
 }
 
@@ -234,28 +232,25 @@ mod_gl_view_flat_display_preview (mod_gl_utils_context_t * utils_context,
 static void
 _display_armies (mod_gl_utils_context_t * utils_context,
 		 _mod_gl_view_flat_context_t *
-		 flat_context, int center_x, int center_y,
-		 lw6gui_look_t * look)
+		 flat_context, lw6gui_look_t * look)
 {
-  mod_gl_utils_update_game_texture_array (utils_context,
-					  &(flat_context->game_context.
-					    armies.armies_surface_array),
-					  &(flat_context->game_context.armies.
-					    armies_texture_array),
-					  flat_context->game_context.
-					  armies.game_state, look);
+  mod_gl_utils_update_game_bitmap_array (utils_context,
+					 &(flat_context->game_context.armies.
+					   armies_bitmap_array),
+					 flat_context->game_context.
+					 armies.game_state, look);
   _set_fighters_rules (utils_context, flat_context);
-  _display_texture_array (utils_context, flat_context,
-			  flat_context->game_context.armies.game_state->
-			  map_state.shape.w,
-			  flat_context->game_context.armies.game_state->
-			  map_state.shape.h,
-			  flat_context->game_context.armies.game_state->
-			  map_state.shape.w,
-			  flat_context->game_context.armies.game_state->
-			  map_state.shape.h,
-			  &(flat_context->game_context.armies.
-			    armies_texture_array), center_x, center_y, look);
+  _display_bitmap_array (utils_context, flat_context,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.w,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.h,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.w,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.h,
+			 &(flat_context->game_context.armies.
+			   armies_bitmap_array), look);
 }
 
 /*
@@ -269,14 +264,11 @@ _display_map (mod_gl_utils_context_t * utils_context,
 	      _mod_gl_view_flat_context_t *
 	      flat_context, lw6gui_look_t * look,
 	      lw6ker_game_state_t * game_state,
-	      lw6gui_main_cursor_t * main_cursor)
+	      lw6pil_local_cursors_t * local_cursors)
 {
-  int center_x = 0;
-  int center_y = 0;
-
   lw6sys_log (LW6SYS_LOG_DEBUG, _("display map"));
   _display_map_preview (utils_context, flat_context, look,
-			game_state->game_struct->level, center_x, center_y);
+			game_state->game_struct->level);
 }
 
 void
@@ -285,7 +277,7 @@ _mod_gl_view_flat_display_map (mod_gl_utils_context_t * utils_context,
 			       flat_context,
 			       lw6gui_look_t * look,
 			       lw6ker_game_state_t * game_state,
-			       lw6gui_main_cursor_t * main_cursor)
+			       lw6pil_local_cursors_t * local_cursors)
 {
   if (utils_context && flat_context && game_state)
     {
@@ -312,10 +304,10 @@ _mod_gl_view_flat_display_map (mod_gl_utils_context_t * utils_context,
 
       _mod_gl_view_flat_viewport_update (utils_context,
 					 flat_context, look, game_state,
-					 main_cursor);
+					 local_cursors);
 
       _display_map (utils_context, flat_context, look, game_state,
-		    main_cursor);
+		    local_cursors);
     }
 }
 
@@ -324,11 +316,12 @@ mod_gl_view_flat_display_map (mod_gl_utils_context_t * utils_context,
 			      void *flat_context,
 			      lw6gui_look_t * look,
 			      lw6ker_game_state_t * game_state,
-			      lw6gui_main_cursor_t * main_cursor)
+			      lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_view_flat_display_map (utils_context,
 				 (_mod_gl_view_flat_context_t *)
-				 flat_context, look, game_state, main_cursor);
+				 flat_context, look, game_state,
+				 local_cursors);
 }
 
 /*
@@ -342,13 +335,10 @@ _display_fighters (mod_gl_utils_context_t * utils_context,
 		   _mod_gl_view_flat_context_t *
 		   flat_context, lw6gui_look_t * look,
 		   lw6ker_game_state_t * game_state,
-		   lw6gui_main_cursor_t * main_cursor)
+		   lw6pil_local_cursors_t * local_cursors)
 {
-  int center_x = 0;
-  int center_y = 0;
-
   lw6sys_log (LW6SYS_LOG_DEBUG, _("display fighters"));
-  _display_armies (utils_context, flat_context, center_x, center_y, look);
+  _display_armies (utils_context, flat_context, look);
 }
 
 void
@@ -357,7 +347,7 @@ _mod_gl_view_flat_display_fighters (mod_gl_utils_context_t * utils_context,
 				    flat_context,
 				    lw6gui_look_t * look,
 				    lw6ker_game_state_t * game_state,
-				    lw6gui_main_cursor_t * main_cursor)
+				    lw6pil_local_cursors_t * local_cursors)
 {
   if (utils_context && flat_context && game_state)
     {
@@ -377,9 +367,9 @@ _mod_gl_view_flat_display_fighters (mod_gl_utils_context_t * utils_context,
 
       _mod_gl_view_flat_viewport_update (utils_context,
 					 flat_context, look, game_state,
-					 main_cursor);
+					 local_cursors);
       _display_fighters (utils_context, flat_context, look, game_state,
-			 main_cursor);
+			 local_cursors);
     }
 }
 
@@ -388,31 +378,31 @@ mod_gl_view_flat_display_fighters (mod_gl_utils_context_t * utils_context,
 				   void *flat_context,
 				   lw6gui_look_t * look,
 				   lw6ker_game_state_t * game_state,
-				   lw6gui_main_cursor_t * main_cursor)
+				   lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_view_flat_display_fighters (utils_context,
 				      (_mod_gl_view_flat_context_t *)
 				      flat_context, look, game_state,
-				      main_cursor);
+				      local_cursors);
 }
 
 static void
-_display_cursor_texture (mod_gl_utils_context_t * utils_context,
-			 _mod_gl_view_flat_context_t * flat_context,
-			 float x, float y, float w, float h, GLuint texture)
+_display_cursor_bitmap (mod_gl_utils_context_t * utils_context,
+			_mod_gl_view_flat_context_t * flat_context,
+			float x, float y, float w, float h,
+			mod_gl_utils_bitmap_t * bitmap)
 {
-  _set_cursor_rules (utils_context, flat_context);
-  mod_gl_utils_display_texture (utils_context,
-				texture, x - w / 2.0f, y - h / 2.0f,
-				x + w / 2.0f, y + h / 2.0f, 0.0f, 0.0f, 1.0f,
-				1.0f);
+  mod_gl_utils_bitmap_bind (utils_context, bitmap);
+  mod_gl_utils_bitmap_display (utils_context,
+			       bitmap, x - w / 2.0f, y - h / 2.0f,
+			       x + w / 2.0f, y + h / 2.0f);
 }
 
 static void
 _display_cursor (mod_gl_utils_context_t * utils_context,
 		 _mod_gl_view_flat_context_t * flat_context,
-		 lw6gui_look_t * look, lw6gui_main_cursor_t * main_cursor,
-		 int i, int x, int y, int even_odd, int is_main_cursor)
+		 lw6gui_look_t * look, lw6pil_local_cursor_t * local_cursor,
+		 int i, int x, int y, int even_odd)
 {
 
   float cursor_x = 0.0f;
@@ -420,32 +410,39 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
   float cursor_w = 0.0f;
   float cursor_h = 0.0f;
 
-  if (is_main_cursor)
+  if (local_cursor && local_cursor->is_main && local_cursor->mouse_controlled)
     {
-      if (!main_cursor->mouse_controlled)
-	{
-	  x = main_cursor->x;
-	  y = main_cursor->y;
-	}
+      x = local_cursor->x;
+      y = local_cursor->y;
     }
 
   lw6gui_viewport_map_to_screen (&(flat_context->viewport), &cursor_x,
 				 &cursor_y, x, y, 0);
-  if (is_main_cursor)
+
+  if (local_cursor)
     {
-      if (main_cursor->mouse_controlled)
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("cursor %x is local"),
+		  local_cursor->cursor_id);
+      if (local_cursor->mouse_controlled)
 	{
 	  cursor_x = utils_context->input.mouse.x;
 	  cursor_y = utils_context->input.mouse.y;
-	  cursor_x =
-	    lw6sys_max (cursor_x, flat_context->viewport.map_visible.x1);
-	  cursor_x =
-	    lw6sys_min (cursor_x, flat_context->viewport.map_visible.x2);
-	  cursor_y =
-	    lw6sys_max (cursor_y, flat_context->viewport.map_visible.y1);
-	  cursor_y =
-	    lw6sys_min (cursor_y, flat_context->viewport.map_visible.y2);
 	}
+      else
+	{
+	  lw6gui_viewport_map_to_screen (&(flat_context->viewport), &cursor_x,
+					 &cursor_y, local_cursor->x,
+					 local_cursor->y, 0);
+	}
+
+      cursor_x = lw6sys_max (cursor_x, flat_context->viewport.map_visible.x1);
+      cursor_x = lw6sys_min (cursor_x, flat_context->viewport.map_visible.x2);
+      cursor_y = lw6sys_max (cursor_y, flat_context->viewport.map_visible.y1);
+      cursor_y = lw6sys_min (cursor_y, flat_context->viewport.map_visible.y2);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("displaying non-local cursor"));
     }
 
   if (cursor_x >= flat_context->viewport.map_visible.x1 &&
@@ -456,7 +453,7 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
       cursor_w = cursor_h =
 	(utils_context->video_mode.width +
 	 utils_context->video_mode.height) *
-	lw6sys_math_heartbeat (mod_gl_utils_timer_uptime (utils_context),
+	lw6sys_math_heartbeat (mod_gl_utils_timer_get_uptime (utils_context),
 			       flat_context->const_data.
 			       cursor_heartbeat_period,
 			       flat_context->const_data.cursor_size_min,
@@ -465,11 +462,11 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
       lw6sys_log (LW6SYS_LOG_DEBUG,
 		  _("display cursor %d %0.1f , %0.1f - %0.1f x %0.1f"), i,
 		  cursor_x, cursor_y, cursor_w, cursor_h);
-      _display_cursor_texture (utils_context, flat_context, cursor_x,
-			       cursor_y, cursor_w, cursor_h,
-			       even_odd ? flat_context->cursors_context.
-			       cursor[i].texture_even : flat_context->
-			       cursors_context.cursor[i].texture_odd);
+      _display_cursor_bitmap (utils_context, flat_context, cursor_x, cursor_y,
+			      cursor_w, cursor_h,
+			      even_odd ? flat_context->cursors_context.
+			      cursor[i].bitmap_even : flat_context->
+			      cursors_context.cursor[i].bitmap_odd);
     }
 }
 
@@ -478,10 +475,11 @@ _display_cursors (mod_gl_utils_context_t * utils_context,
 		  _mod_gl_view_flat_context_t *
 		  flat_context,
 		  lw6gui_look_t * look, lw6ker_game_state_t * game_state,
-		  lw6gui_main_cursor_t * main_cursor)
+		  lw6pil_local_cursors_t * local_cursors)
 {
   int i;
   lw6ker_cursor_t *cursor;
+  lw6pil_local_cursor_t *local_cursor;
   int blink_state;
 
   lw6sys_log (LW6SYS_LOG_DEBUG, _("display cursors"));
@@ -490,12 +488,14 @@ _display_cursors (mod_gl_utils_context_t * utils_context,
       cursor = &(game_state->map_state.cursor_array.cursors[i]);
       if (cursor->enabled)
 	{
+	  local_cursor =
+	    lw6pil_local_cursors_get_cursor (local_cursors,
+					     cursor->cursor_id);
 	  blink_state =
-	    lw6sys_math_blink (mod_gl_utils_timer_uptime (utils_context),
+	    lw6sys_math_blink (mod_gl_utils_timer_get_uptime (utils_context),
 			       flat_context->const_data.cursor_blink_period);
-	  _display_cursor (utils_context, flat_context, look, main_cursor, i,
-			   cursor->pos.x, cursor->pos.y, blink_state,
-			   main_cursor->cursor_id == cursor->cursor_id);
+	  _display_cursor (utils_context, flat_context, look, local_cursor, i,
+			   cursor->pos.x, cursor->pos.y, blink_state);
 	}
     }
 }
@@ -506,7 +506,7 @@ _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t * utils_context,
 				   flat_context,
 				   lw6gui_look_t * look,
 				   lw6ker_game_state_t * game_state,
-				   lw6gui_main_cursor_t * main_cursor)
+				   lw6pil_local_cursors_t * local_cursors)
 {
   if (utils_context && flat_context && game_state)
     {
@@ -523,10 +523,10 @@ _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t * utils_context,
 
       _mod_gl_view_flat_viewport_update (utils_context,
 					 flat_context, look, game_state,
-					 main_cursor);
+					 local_cursors);
 
       _display_cursors (utils_context, flat_context, look, game_state,
-			main_cursor);
+			local_cursors);
     }
 }
 
@@ -536,10 +536,10 @@ mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
 				  void *flat_context,
 				  lw6gui_look_t * look,
 				  lw6ker_game_state_t * game_state,
-				  lw6gui_main_cursor_t * main_cursor)
+				  lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_view_flat_display_cursors (utils_context,
 				     (_mod_gl_view_flat_context_t *)
 				     flat_context, look, game_state,
-				     main_cursor);
+				     local_cursors);
 }
