@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -84,12 +84,12 @@ mod_gl_view_display_map (mod_gl_utils_context_t * utils_context,
 			 mod_gl_view_backend_t * backend,
 			 lw6gui_look_t * look,
 			 lw6ker_game_state_t * game_state,
-			 lw6gui_main_cursor_t * main_cursor)
+			 lw6pil_local_cursors_t * local_cursors)
 {
   if (backend->display_map)
     {
       backend->display_map (utils_context, backend->view_context, look,
-			    game_state, main_cursor);
+			    game_state, local_cursors);
     }
   else
     {
@@ -102,12 +102,12 @@ mod_gl_view_display_fighters (mod_gl_utils_context_t * utils_context,
 			      mod_gl_view_backend_t * backend,
 			      lw6gui_look_t * look,
 			      lw6ker_game_state_t * game_state,
-			      lw6gui_main_cursor_t * main_cursor)
+			      lw6pil_local_cursors_t * local_cursors)
 {
   if (backend->display_fighters)
     {
       backend->display_fighters (utils_context, backend->view_context, look,
-				 game_state, main_cursor);
+				 game_state, local_cursors);
     }
   else
     {
@@ -120,12 +120,12 @@ mod_gl_view_display_cursors (mod_gl_utils_context_t * utils_context,
 			     mod_gl_view_backend_t * backend,
 			     lw6gui_look_t * look,
 			     lw6ker_game_state_t * game_state,
-			     lw6gui_main_cursor_t * main_cursor)
+			     lw6pil_local_cursors_t * local_cursors)
 {
   if (backend->display_cursors)
     {
       backend->display_cursors (utils_context, backend->view_context, look,
-				game_state, main_cursor);
+				game_state, local_cursors);
     }
   else
     {
