@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -117,7 +117,6 @@
 #define TEST_SMOOTHER_VALUE3 -1000.0f
 #define TEST_SMOOTHER_VALUE4 421.0f
 
-
 /*
  * Testing button
  */
@@ -858,24 +857,26 @@ test_smoother ()
 			  TEST_SMOOTHER_DURATION);
     lw6sys_delay (TEST_SMOOTHER_DELAY);
     lw6sys_log (LW6SYS_LOG_NOTICE, _("smoother init %f"),
-		lw6gui_smoother_get_value (&smoother, lw6sys_timestamp ()));
+		lw6gui_smoother_get_value (&smoother,
+					   lw6sys_get_timestamp ()));
     lw6gui_smoother_immediate_force (&smoother, TEST_SMOOTHER_VALUE2);
     lw6sys_log (LW6SYS_LOG_NOTICE, _("smoother force %f"),
-		lw6gui_smoother_get_value (&smoother, lw6sys_timestamp ()));
+		lw6gui_smoother_get_value (&smoother,
+					   lw6sys_get_timestamp ()));
     lw6gui_smoother_set_target (&smoother, TEST_SMOOTHER_VALUE3,
-				lw6sys_timestamp ());
+				lw6sys_get_timestamp ());
     lw6sys_log (LW6SYS_LOG_NOTICE, _("smoother set target %f"),
 		TEST_SMOOTHER_VALUE3);
     lw6sys_delay (TEST_SMOOTHER_DELAY);
     lw6gui_smoother_set_target (&smoother, TEST_SMOOTHER_VALUE4,
-				lw6sys_timestamp ());
+				lw6sys_get_timestamp ());
     lw6sys_log (LW6SYS_LOG_NOTICE, _("smoother set target %f"),
 		TEST_SMOOTHER_VALUE4);
     for (i = 0; i < TEST_SMOOTHER_N; i++)
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _("smoother value is %f"),
 		    lw6gui_smoother_get_value (&smoother,
-					       lw6sys_timestamp ()));
+					       lw6sys_get_timestamp ()));
 	lw6sys_delay (TEST_SMOOTHER_DELAY);
       }
   }
@@ -1087,12 +1088,14 @@ test_zone ()
 /**
  * lw6gui_test
  *
+ * @mode: 0 for check only, 1 for full test
+ *
  * Run tests in the gui module.
  * 
  * Return value: 1 if successfull, 0 if failed.
  */
 int
-lw6gui_test ()
+lw6gui_test (int mode)
 {
   int ret = 0;
 
@@ -1101,17 +1104,18 @@ lw6gui_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6hlp_test ();
-      lw6cfg_test ();
-      lw6map_test ();
-      lw6ldr_test ();
+      lw6sys_test (mode);
+      lw6hlp_test (mode);
+      lw6cfg_test (mode);
+      lw6map_test (mode);
+      lw6ldr_test (mode);
     }
 
   ret = test_button () && test_coord () && test_input () && test_joystick ()
-    && test_keyboard () && test_keypress () && test_look ()
-    && test_menuitem () && test_menu () && test_mouse () && test_smoother ()
-    && test_video_mode () && test_viewport () && test_zone ();
+    && test_keyboard () && test_keypress ()
+    && test_look () && test_menuitem () && test_menu () && test_mouse ()
+    && test_smoother () && test_video_mode () && test_viewport ()
+    && test_zone ();
 
   return ret;
 }
