@@ -39,6 +39,10 @@ update_quick (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_LIST);
   lw6sys_list_push_back (list, LW6DEF_ABOUT);
   lw6sys_list_push_back (list, LW6DEF_DEBUG);
+  lw6sys_list_push_back (list, LW6DEF_PEDIGREE);
+  lw6sys_list_push_back (list, LW6DEF_HOST);
+  lw6sys_list_push_back (list, LW6DEF_AUDIT);
+  lw6sys_list_push_back (list, LW6DEF_MODULES);
 
   return ((*list) != NULL);
 }
@@ -134,6 +138,7 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_LOCALEDIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_DOCDIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_CONSOLE);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_GTK);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_MOD_GL);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_MOD_CSOUND);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_MOD_OGG);
@@ -359,12 +364,16 @@ lw6hlp_list_sound ()
 static int
 update_network (lw6sys_list_t ** list)
 {
-  lw6sys_list_push_back (list, LW6DEF_LOCAL);
+  lw6sys_list_push_back (list, LW6DEF_SKIP_NETWORK);
+  lw6sys_list_push_back (list, LW6DEF_PASSWORD);
   lw6sys_list_push_back (list, LW6DEF_BIND_IP);
   lw6sys_list_push_back (list, LW6DEF_BIND_PORT);
   lw6sys_list_push_back (list, LW6DEF_CLI_BACKENDS);
   lw6sys_list_push_back (list, LW6DEF_SRV_BACKENDS);
   lw6sys_list_push_back (list, LW6DEF_PUBLIC_URL);
+  lw6sys_list_push_back (list, LW6DEF_NODE_TITLE);
+  lw6sys_list_push_back (list, LW6DEF_NODE_DESCRIPTION);
+  lw6sys_list_push_back (list, LW6DEF_KNOWN_NODES);
 
   return ((*list) != NULL);
 }
@@ -416,7 +425,7 @@ update_map_rules (lw6sys_list_t ** list)
 {
   lw6sys_list_push_back (list, LW6DEF_TOTAL_TIME);
   lw6sys_list_push_back (list, LW6DEF_RESPAWN_TEAM);
-  lw6sys_list_push_back (list, LW6DEF_RESPAWN_RANDOM_PLACE);
+  lw6sys_list_push_back (list, LW6DEF_RESPAWN_POSITION_MODE);
   lw6sys_list_push_back (list, LW6DEF_MOVES_PER_ROUND);
   lw6sys_list_push_back (list, LW6DEF_SPREADS_PER_ROUND);
   lw6sys_list_push_back (list, LW6DEF_ROUNDS_PER_SEC);
@@ -434,7 +443,7 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_TOTAL_ARMIES_SIZE);
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_TEAMS);
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_CURSORS);
-  lw6sys_list_push_back (list, LW6DEF_MAX_NB_SERVERS);
+  lw6sys_list_push_back (list, LW6DEF_MAX_NB_NODES);
   lw6sys_list_push_back (list, LW6DEF_X_POLARITY);
   lw6sys_list_push_back (list, LW6DEF_Y_POLARITY);
   lw6sys_list_push_back (list, LW6DEF_Z_POLARITY);
@@ -471,6 +480,9 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_BOOST_POWER);
   lw6sys_list_push_back (list, LW6DEF_DANGER_POWER);
   lw6sys_list_push_back (list, LW6DEF_MEDICINE_POWER);
+  lw6sys_list_push_back (list, LW6DEF_FRAGS_MODE);
+  lw6sys_list_push_back (list, LW6DEF_FRAGS_TO_DISTRIBUTE);
+  lw6sys_list_push_back (list, LW6DEF_FRAGS_FADE_OUT);
 
   return ((*list) != NULL);
 }
@@ -649,10 +661,6 @@ lw6hlp_list_hooks ()
 static int
 update_tuning (lw6sys_list_t ** list)
 {
-  lw6sys_list_push_back (list, LW6DEF_PEDIGREE);
-  lw6sys_list_push_back (list, LW6DEF_HOST);
-  lw6sys_list_push_back (list, LW6DEF_AUDIT);
-  lw6sys_list_push_back (list, LW6DEF_MODULES);
   lw6sys_list_push_back (list, LW6DEF_RESET);
   lw6sys_list_push_back (list, LW6DEF_RESET_CONFIG_ON_UPGRADE);
   lw6sys_list_push_back (list, LW6DEF_LOG_LEVEL);
@@ -697,6 +705,7 @@ update_tuning (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_GFX_CPU_USAGE);
   lw6sys_list_push_back (list, LW6DEF_DIRTY_READ);
   lw6sys_list_push_back (list, LW6DEF_GFX_DEBUG);
+  lw6sys_list_push_back (list, LW6DEF_EXECUTED_AGAIN);
 
   return ((*list) != NULL);
 }
