@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include "hlp.h"
 
 #define TEST_KEYWORD LW6DEF_PREFIX
+#define _TEST_MAX_CREDITS 50
 
 /*
  * Testing about
@@ -74,6 +75,39 @@ test_about ()
   return ret;
 }
 
+/*
+ * Testing credits
+ */
+static int
+test_credits ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    int i;
+    char *credits = NULL;
+
+    for (i = 0; i < _TEST_MAX_CREDITS; ++i)
+      {
+	credits = lw6hlp_get_credits (i);
+	if (credits)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("credit line %d: \"%s\""), i,
+			credits);
+	    LW6SYS_FREE (credits);
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing print
  */
@@ -92,14 +126,27 @@ test_print ()
 	lw6hlp_print_keyword (&list, stdout);
 	lw6sys_list_free (list);
       }
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("now showing what \"--about=%s\" would look like"),
+		TEST_KEYWORD);
+    lw6hlp_print_about (TEST_KEYWORD, stdout);
   }
 
   LW6SYS_TEST_FUNCTION_END;
   return ret;
 }
 
+/**
+ * lw6hlp_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @hlp module test suite.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6hlp_test ()
+lw6hlp_test (int mode)
 {
   int ret = 0;
 
@@ -108,10 +155,10 @@ lw6hlp_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
+      lw6sys_test (mode);
     }
 
-  ret = test_about () && test_print ();
+  ret = test_about () && test_credits () && test_print ();
 
   return ret;
 }
