@@ -39,7 +39,7 @@ void
 _lw6ker_cursor_update_checksum (lw6ker_cursor_t * cursor,
 				u_int32_t * checksum)
 {
-  lw6sys_checksum_update_int64 (checksum, cursor->server_id);
+  lw6sys_checksum_update_int64 (checksum, cursor->node_id);
   lw6sys_checksum_update_int32 (checksum, cursor->cursor_id);
   lw6sys_checksum_update_int32 (checksum, cursor->letter);
   lw6sys_checksum_update_int32 (checksum, cursor->enabled);
@@ -50,18 +50,18 @@ _lw6ker_cursor_update_checksum (lw6ker_cursor_t * cursor,
 }
 
 int
-_lw6ker_cursor_check_server_id (lw6ker_cursor_t * cursor, u_int64_t server_id)
+_lw6ker_cursor_check_node_id (lw6ker_cursor_t * cursor, u_int64_t node_id)
 {
   int ret = 0;
 
-  ret = (lw6sys_check_id_64 (server_id) && cursor->server_id == server_id);
+  ret = (lw6sys_check_id_64 (node_id) && cursor->node_id == node_id);
   if (!ret)
     {
       lw6sys_log (LW6SYS_LOG_DEBUG,
 		  _
-		  ("server id mismatch server_id=%" LW6SYS_PRINTF_LL
-		   "x cursor->server_id=%" LW6SYS_PRINTF_LL "x"), server_id,
-		  cursor->server_id);
+		  ("node id mismatch node_id=%" LW6SYS_PRINTF_LL
+		   "x cursor->node_id=%" LW6SYS_PRINTF_LL "x"), node_id,
+		  cursor->node_id);
     }
 
   return ret;
@@ -69,64 +69,81 @@ _lw6ker_cursor_check_server_id (lw6ker_cursor_t * cursor, u_int64_t server_id)
 
 int
 _lw6ker_cursor_get_start_xy (int32_t * x, int32_t * y, int team_color,
-			     int random_place, int random_seed,
+			     int position_mode, int random_seed,
 			     lw6sys_whd_t * shape, lw6map_rules_t * rules)
 {
   int ret = 1;
   int32_t px = 50;
   int32_t py = 50;
+  u_int32_t checksum = 0;
 
-  if (random_place)
+  checksum = lw6sys_checksum_int32 (random_seed + team_color);
+  /*
+   * Update with something for when seed is 0 (game beginning)
+   * then checksum is 0...
+   */
+  lw6sys_checksum_update_int32 (&checksum, shape->w * shape->h);
+
+  if (position_mode == LW6MAP_RULES_POSITION_MODE_TOTAL_RANDOM)
     {
-      team_color =
-	((team_color + random_seed) & 0xFFFF) % LW6MAP_NB_TEAM_COLORS;
+      px = checksum % 100;
+      py = lw6sys_checksum_int32 (checksum + team_color) % 100;
     }
-
-  switch (team_color)
+  else
     {
-    case LW6MAP_TEAM_COLOR_RED:
-      px = rules->start_red_x;
-      py = rules->start_red_y;
-      break;
-    case LW6MAP_TEAM_COLOR_GREEN:
-      px = rules->start_green_x;
-      py = rules->start_green_y;
-      break;
-    case LW6MAP_TEAM_COLOR_BLUE:
-      px = rules->start_blue_x;
-      py = rules->start_blue_y;
-      break;
-    case LW6MAP_TEAM_COLOR_YELLOW:
-      px = rules->start_yellow_x;
-      py = rules->start_yellow_y;
-      break;
-    case LW6MAP_TEAM_COLOR_CYAN:
-      px = rules->start_cyan_x;
-      py = rules->start_cyan_y;
-      break;
-    case LW6MAP_TEAM_COLOR_MAGENTA:
-      px = rules->start_magenta_x;
-      py = rules->start_magenta_y;
-      break;
-    case LW6MAP_TEAM_COLOR_ORANGE:
-      px = rules->start_orange_x;
-      py = rules->start_orange_y;
-      break;
-    case LW6MAP_TEAM_COLOR_LIGHTBLUE:
-      px = rules->start_lightblue_x;
-      py = rules->start_lightblue_y;
-      break;
-    case LW6MAP_TEAM_COLOR_PURPLE:
-      px = rules->start_purple_x;
-      py = rules->start_purple_y;
-      break;
-    case LW6MAP_TEAM_COLOR_PINK:
-      px = rules->start_pink_x;
-      py = rules->start_pink_y;
-      break;
-    default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _("invalid team_color=%d"), team_color);
-      ret = 0;
+      if (position_mode == LW6MAP_RULES_POSITION_MODE_PICK_EXISTING)
+	{
+	  team_color =
+	    ((team_color + checksum) & 0xFFFF) % LW6MAP_NB_TEAM_COLORS;
+	}
+
+      switch (team_color)
+	{
+	case LW6MAP_TEAM_COLOR_RED:
+	  px = rules->start_red_x;
+	  py = rules->start_red_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_GREEN:
+	  px = rules->start_green_x;
+	  py = rules->start_green_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_BLUE:
+	  px = rules->start_blue_x;
+	  py = rules->start_blue_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_YELLOW:
+	  px = rules->start_yellow_x;
+	  py = rules->start_yellow_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_CYAN:
+	  px = rules->start_cyan_x;
+	  py = rules->start_cyan_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_MAGENTA:
+	  px = rules->start_magenta_x;
+	  py = rules->start_magenta_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_ORANGE:
+	  px = rules->start_orange_x;
+	  py = rules->start_orange_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_LIGHTBLUE:
+	  px = rules->start_lightblue_x;
+	  py = rules->start_lightblue_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_PURPLE:
+	  px = rules->start_purple_x;
+	  py = rules->start_purple_y;
+	  break;
+	case LW6MAP_TEAM_COLOR_PINK:
+	  px = rules->start_pink_x;
+	  py = rules->start_pink_y;
+	  break;
+	default:
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("invalid team_color=%d"),
+		      team_color);
+	  ret = 0;
+	}
     }
 
   (*x) = lw6ker_percent (shape->w, px);
@@ -163,7 +180,7 @@ _lw6ker_cursor_reset (lw6ker_cursor_t * cursor)
 
 int
 lw6ker_cursor_enable (lw6ker_cursor_t * cursor,
-		      u_int64_t server_id,
+		      u_int64_t node_id,
 		      u_int16_t cursor_id,
 		      int team_color, int32_t x, int32_t y)
 {
@@ -171,7 +188,7 @@ lw6ker_cursor_enable (lw6ker_cursor_t * cursor,
 
   if (!cursor->enabled)
     {
-      cursor->server_id = server_id;
+      cursor->node_id = node_id;
       cursor->cursor_id = cursor_id;
       _lw6ker_cursor_reset (cursor);
       cursor->enabled = 1;
@@ -196,7 +213,7 @@ lw6ker_cursor_disable (lw6ker_cursor_t * cursor)
 
   if (cursor->enabled)
     {
-      cursor->server_id = 0;
+      cursor->node_id = 0;
       cursor->cursor_id = 0;
       _lw6ker_cursor_reset (cursor);
       ret = 1;
@@ -253,19 +270,19 @@ lw6ker_cursor_sanity_check (lw6ker_cursor_t * cursor,
 	}
     }
   if ((cursor->enabled
-       && ((!lw6sys_check_id_64 (cursor->server_id))
+       && ((!lw6sys_check_id_64 (cursor->node_id))
 	   || (!lw6sys_check_id_16 (cursor->cursor_id))
 	   || cursor->team_color < 0
 	   || cursor->team_color >= LW6MAP_MAX_NB_TEAMS))
       || ((!cursor->enabled)
-	  && (cursor->server_id != 0 || cursor->cursor_id != 0
+	  && (cursor->node_id != 0 || cursor->cursor_id != 0
 	      || cursor->team_color != LW6MAP_TEAM_COLOR_INVALID)))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
-		  ("inconsistent enabled cursor values enabled=%d server_id=%"
+		  ("inconsistent enabled cursor values enabled=%d node_id=%"
 		   LW6SYS_PRINTF_LL "x cursor_id=%x team_color=%d"),
-		  cursor->enabled, cursor->server_id, (int) cursor->cursor_id,
+		  cursor->enabled, cursor->node_id, (int) cursor->cursor_id,
 		  cursor->team_color);
       ret = 0;
     }
