@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -129,7 +129,7 @@ lw6ker_game_struct_dup (lw6ker_game_struct_t * game_struct,
   if (ret)
     {
       memcpy (ret, game_struct, sizeof (lw6ker_game_struct_t));
-      lw6sys_progress_update (progress, 0, 6, 1);
+      lw6sys_progress_update (progress, 0, 8, 1);
       /*
        * Set id after the memcpy, else will be overwritten
        */
@@ -138,26 +138,37 @@ lw6ker_game_struct_dup (lw6ker_game_struct_t * game_struct,
 	{
 	  ret->id = ++seq_id;
 	}
+      ret->map_struct.places =
+	(lw6ker_place_struct_t *)
+	LW6SYS_MALLOC (sizeof (lw6ker_place_struct_t) *
+		       ret->map_struct.nb_places);
+      lw6sys_progress_update (progress, 0, 8, 2);
+      if (ret->map_struct.places)
+	{
+	  memcpy (ret->map_struct.places, game_struct->map_struct.places,
+		  sizeof (lw6ker_place_struct_t) * ret->map_struct.nb_places);
+	}
+      lw6sys_progress_update (progress, 0, 8, 3);
       ret->map_struct.zones =
 	(lw6ker_zone_struct_t *) LW6SYS_MALLOC (sizeof (lw6ker_zone_struct_t)
 						* ret->map_struct.nb_zones);
-      lw6sys_progress_update (progress, 0, 6, 2);
+      lw6sys_progress_update (progress, 0, 8, 4);
       if (ret->map_struct.zones)
 	{
 	  memcpy (ret->map_struct.zones, game_struct->map_struct.zones,
 		  sizeof (lw6ker_zone_struct_t) * ret->map_struct.nb_zones);
 	}
-      lw6sys_progress_update (progress, 0, 6, 3);
+      lw6sys_progress_update (progress, 0, 8, 5);
       ret->map_struct.slots =
 	(lw6ker_slot_struct_t *) LW6SYS_MALLOC (sizeof (lw6ker_slot_struct_t)
 						* ret->map_struct.nb_slots);
-      lw6sys_progress_update (progress, 0, 6, 4);
+      lw6sys_progress_update (progress, 0, 8, 6);
       if (ret->map_struct.slots)
 	{
 	  memcpy (ret->map_struct.slots, game_struct->map_struct.slots,
 		  sizeof (lw6ker_slot_struct_t) * ret->map_struct.nb_slots);
 	}
-      lw6sys_progress_update (progress, 0, 6, 5);
+      lw6sys_progress_update (progress, 0, 8, 7);
       if ((!ret->map_struct.zones) || (!ret->map_struct.slots))
 	{
 	  if (ret->map_struct.zones)
