@@ -387,22 +387,65 @@ lw6ker_map_state_remove_fighters (lw6ker_map_state_t * map_state,
   int32_t i, j;
   int ret = 0;
   int32_t nb_fighters_removed = 0;
+  int32_t fighters_to_remove_per_team[LW6MAP_MAX_NB_TEAMS];
+  int32_t fighters_to_remove_total = 0;
+  int64_t this_team_fighters = 0;
+  int64_t active_fighters = 0;
+  lw6ker_fighter_t *fighter = NULL;
+  int team_color;
+
+  memset (fighters_to_remove_per_team, 0,
+	  sizeof (fighters_to_remove_per_team));
+  if (map_state->armies.active_fighters > 0)
+    {
+      active_fighters = map_state->armies.active_fighters;
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+	{
+	  this_team_fighters = map_state->armies.fighters_per_team[i];
+	  fighters_to_remove_per_team[i] =
+	    (nb_fighters * this_team_fighters) / active_fighters;
+	  fighters_to_remove_total += fighters_to_remove_per_team[i];
+	}
+    }
+  if (fighters_to_remove_total <= nb_fighters)
+    {
+      for (i = nb_fighters; fighters_to_remove_total < nb_fighters; ++i)
+	{
+	  /*
+	   * i is just used as a pseudo-random value to cycle
+	   * amoung teams
+	   */
+	  j = i % LW6MAP_MAX_NB_TEAMS;
+	  if (map_state->armies.fighters_per_team[j] >
+	      fighters_to_remove_per_team[j] + 1)
+	    {
+	      fighters_to_remove_per_team[j]++;
+	      fighters_to_remove_total++;
+	    }
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _
+		  ("strange, fighters_to_remove_total=%d but nb_fighters=%d"),
+		  fighters_to_remove_total, nb_fighters);
+    }
 
   if (nb_fighters <= map_state->armies.active_fighters)
     {
       while (nb_fighters_removed < nb_fighters)
 	{
 	  /*
-	   * To remove fighters, we simply pseudo-randomly
+	   * To remove fighters, we used to simply pseudo-randomly
 	   * pass the current map, trying not to process
 	   * low-numbered fighters systematically to avoid
 	   * disadvantaging "first" teams, and whenever we
-	   * encounter a fighter, we delete it. We count on
-	   * statistics so that deletion is globally fair
-	   * and no team should especially be adavantaged
-	   * by this. But it's true there's some luck and
-	   * a slight probability that all of the fighters
-	   * of a given team are deleted at once...
+	   * encounter a fighter, we deleted it.
+	   * Now it has evolved a bit, we check the fighter belongs
+	   * to a team that still has some fighters to give, hence
+	   * giving all teams reasonnable chances to survive.
+	   * This should solve https://savannah.gnu.org/bugs/?28030
 	   */
 	  for (i = 0;
 	       i < LW6MAP_MAX_NB_TEAMS && nb_fighters_removed < nb_fighters;
@@ -413,11 +456,24 @@ lw6ker_map_state_remove_fighters (lw6ker_map_state_t * map_state,
 		   && nb_fighters_removed < nb_fighters;
 		   j += LW6MAP_MAX_NB_TEAMS)
 		{
-		  lw6ker_map_state_remove_fighter (map_state, j);
-		  nb_fighters_removed++;
+		  fighter = &(map_state->armies.fighters[j]);
+		  team_color = fighter->team_color;
+		  if (fighters_to_remove_per_team[team_color] > 0)
+		    {
+		      lw6ker_map_state_remove_fighter (map_state, j);
+		      fighters_to_remove_per_team[team_color]--;
+		      fighters_to_remove_total--;
+		      nb_fighters_removed++;
+		    }
 		}
 	    }
 	}
+      if (fighters_to_remove_total != 0)
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("fighters_to_remove_total=%d and should be 0"),
+		      fighters_to_remove_total);
+	}
       ret = 1;
     }
   else
@@ -791,3 +847,184 @@ lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
 	}
     }
 }
+
+void
+_lw6ker_map_state_frag (lw6ker_map_state_t * map_state, int team_color,
+			int frags_mode, int frags_to_distribute,
+			int frags_fade_out)
+{
+  int active_fighters = 0;
+  int nb_loosers = 0;
+  int nb_winners = 0;
+  int i = 0, j = 0;
+  lw6ker_armies_t *armies = &(map_state->armies);
+  int frags_total = 0;
+  int delta_frags[LW6MAP_MAX_NB_TEAMS];
+
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      delta_frags[i] = 0;
+    }
+
+  if (frags_mode == LW6MAP_RULES_FRAGS_MODE_BALANCED
+      || frags_mode == LW6MAP_RULES_FRAGS_MODE_PROPORTIONAL)
+    {
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+	{
+	  if (map_state->teams[i].active)
+	    {
+	      armies->frags[i] =
+		lw6ker_percent (armies->frags[i], frags_fade_out);
+	    }
+	}
+    }
+
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      if (map_state->teams[i].active)
+	{
+	  if (armies->fighters_per_team[i] <= 0)
+	    {
+	      nb_loosers++;
+	    }
+	  else
+	    {
+	      nb_winners++;
+	    }
+	}
+    }
+
+  if (frags_mode == LW6MAP_RULES_FRAGS_MODE_ONE_NEGATIVE_POINT)
+    {
+      // old school simple moe
+      delta_frags[team_color] = -1;
+    }
+
+  if (frags_mode == LW6MAP_RULES_FRAGS_MODE_ONE_FOR_WINNERS_ALL_FOR_LOSER)
+    {
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+	{
+	  if (map_state->teams[i].active)
+	    {
+	      if (armies->fighters_per_team[i] <= 0)
+		{
+		  delta_frags[i] = -lw6sys_max (1, nb_winners);
+		}
+	      else
+		{
+		  delta_frags[i] = 1;
+		}
+	    }
+	}
+
+    }
+
+  active_fighters = armies->active_fighters;
+  if (frags_mode == LW6MAP_RULES_FRAGS_MODE_BALANCED
+      || frags_mode == LW6MAP_RULES_FRAGS_MODE_PROPORTIONAL)
+    {
+      if (active_fighters > 0)
+	{
+	  if (nb_loosers > 0)
+	    {
+	      if (nb_winners > 0)
+		{
+		  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+		    {
+		      if (map_state->teams[i].active)
+			{
+			  if (armies->fighters_per_team[i] <= 0)
+			    {
+			      if (frags_mode ==
+				  LW6MAP_RULES_FRAGS_MODE_BALANCED)
+				{
+				  delta_frags[i] -=
+				    lw6sys_max (1,
+						frags_to_distribute /
+						nb_loosers);
+				}
+			    }
+			  else
+			    {
+			      if (frags_mode ==
+				  LW6MAP_RULES_FRAGS_MODE_BALANCED
+				  || frags_mode ==
+				  LW6MAP_RULES_FRAGS_MODE_PROPORTIONAL)
+				delta_frags[i] +=
+				  lw6sys_max (1,
+					      (frags_to_distribute *
+					       armies->fighters_per_team[i]) /
+					      armies->active_fighters);
+			    }
+			}
+		    }
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _
+			      ("can't calculate frags when there are no winners"));
+		}
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _
+			  ("can't calculate frags when there are no loosers"));
+	    }
+	}
+    }
+
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      if (map_state->teams[i].active)
+	{
+	  frags_total += delta_frags[i];
+	}
+    }
+
+  if (frags_mode == LW6MAP_RULES_FRAGS_MODE_ONE_FOR_WINNERS_ALL_FOR_LOSER
+      || frags_mode == LW6MAP_RULES_FRAGS_MODE_BALANCED)
+    {
+      while (frags_total < 0)
+	{
+	  for (i = 0; i < LW6MAP_MAX_NB_TEAMS && frags_total < 0; ++i)
+	    {
+	      j = (i + team_color) % LW6MAP_MAX_NB_TEAMS;
+	      if (map_state->teams[j].active)
+		{
+		  if (delta_frags[j] >= 0)
+		    {
+		      delta_frags[j]++;
+		      frags_total++;
+		    }
+		}
+	    }
+	}
+
+      while (frags_total > 0)
+	{
+	  for (i = 0; i < LW6MAP_MAX_NB_TEAMS && frags_total > 0; ++i)
+	    {
+	      j = (i + team_color) % LW6MAP_MAX_NB_TEAMS;
+	      if (map_state->teams[j].active)
+		{
+		  if (delta_frags[j] <= 0)
+		    {
+		      delta_frags[j]--;
+		      frags_total--;
+		    }
+		}
+	    }
+	}
+    }
+
+
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      if (map_state->teams[i].active)
+	{
+	  armies->frags[i] += delta_frags[i];
+	}
+    }
+}
