@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -307,8 +307,9 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 void
 _lw6ldr_apply_guessed_colors (lw6map_level_t * level)
 {
-  level->param.style.color_base = level->texture.guessed_color_base;
-  level->param.style.color_alternate = level->texture.guessed_color_alternate;
+  level->param.style.color_set.color_base = level->texture.guessed_color_base;
+  level->param.style.color_set.color_alternate =
+    level->texture.guessed_color_alternate;
 }
 
 /**
@@ -330,32 +331,33 @@ lw6ldr_auto_colors (lw6map_style_t * style, lw6ldr_hints_t * hints)
 {
   if (hints->background_color_auto)
     {
-      style->background_color_root = style->color_base;
-      style->background_color_stuff = style->color_alternate;
+      style->color_set.background_color_root = style->color_set.color_base;
+      style->color_set.background_color_stuff =
+	style->color_set.color_alternate;
     }
 
   if (hints->hud_color_auto)
     {
-      style->hud_color_frame = style->color_base;
-      style->hud_color_text = style->color_alternate;
+      style->color_set.hud_color_frame = style->color_set.color_base;
+      style->color_set.hud_color_text = style->color_set.color_alternate;
     }
 
   if (hints->menu_color_auto)
     {
-      style->menu_color_default = style->color_alternate;
-      style->menu_color_selected = style->color_alternate;
-      lw6map_color_invert (&style->menu_color_selected);
-      style->menu_color_disabled = style->color_base;
+      style->color_set.menu_color_default = style->color_set.color_alternate;
+      style->color_set.menu_color_selected = style->color_set.color_alternate;
+      lw6map_color_invert (&style->color_set.menu_color_selected);
+      style->color_set.menu_color_disabled = style->color_set.color_base;
     }
 
   if (hints->view_color_auto)
     {
-      style->view_color_cursor = style->color_alternate;
-      style->view_color_map = style->color_base;
+      style->color_set.view_color_cursor = style->color_set.color_alternate;
+      style->color_set.view_color_map = style->color_set.color_base;
     }
 
   if (hints->system_color_auto)
     {
-      style->system_color = style->color_alternate;
+      style->color_set.system_color = style->color_set.color_alternate;
     }
 }
