@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #define LIQUIDWAR6LDR_INTERNAL_H
 
 #define _LW6LDR_FILE_README "README"
-#define _LW6LDR_FILE_README_TXT "README.txt"
+#define _LW6LDR_FILE_README_TXT "readme.txt"
 #define _LW6LDR_FILE_MAP_PNG "map.png"
 #define _LW6LDR_FILE_LAYER2_PNG "layer2.png"
 #define _LW6LDR_FILE_LAYER3_PNG "layer3.png"
@@ -32,6 +32,14 @@
 #define _LW6LDR_FILE_LAYER5_PNG "layer5.png"
 #define _LW6LDR_FILE_LAYER6_PNG "layer6.png"
 #define _LW6LDR_FILE_LAYER7_PNG "layer7.png"
+#define _LW6LDR_FILE_GLUE_PNG "glue.png"
+#define _LW6LDR_FILE_BOOST_PNG "boost.png"
+#define _LW6LDR_FILE_DANGER_PNG "danger.png"
+#define _LW6LDR_FILE_MEDICINE_PNG "medicine.png"
+#define _LW6LDR_FILE_ONE_WAY_NORTH_PNG "one-way-north.png"
+#define _LW6LDR_FILE_ONE_WAY_EAST_PNG "one-way-east.png"
+#define _LW6LDR_FILE_ONE_WAY_SOUTH_PNG "one-way-south.png"
+#define _LW6LDR_FILE_ONE_WAY_WEST_PNG "one-way-west.png"
 #define _LW6LDR_FILE_TEXTURE_PNG "texture.png"
 #define _LW6LDR_FILE_TEXTURE_JPEG "texture.jpeg"
 #define _LW6LDR_FILE_TEXTURE_JPG "texture.jpg"
@@ -46,7 +54,7 @@ typedef struct _lw6ldr_image_bw_s
 {
   int w;
   int h;
-  unsigned char **data;
+  u_int8_t **data;
   int step;
 }
 _lw6ldr_image_bw_t;
@@ -55,7 +63,7 @@ typedef struct _lw6ldr_image_rgba_s
 {
   int w;
   int h;
-  unsigned char **data;
+  u_int8_t **data;
 }
 _lw6ldr_image_rgba_t;
 
@@ -66,6 +74,7 @@ _lw6ldr_image_rgba_t;
 extern int _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
 			    lw6sys_progress_t * progress);
 extern void _lw6ldr_bw_clear (_lw6ldr_image_bw_t * image);
+extern float _lw6ldr_bw_gray_level (_lw6ldr_image_bw_t * image);
 
 /*
  * In color.c
