@@ -27,12 +27,13 @@
  * This is the main Liquid War 6 header file.
  */
 
-#define LW6_VERSION "0.0.8beta"
+#define LW6_VERSION "0.0.9beta"
 
 #include <pthread.h>
 #include <libguile.h>
 
 #include "sys/sys.h"
+#include "glb/glb.h"
 #include "dyn/dyn.h"
 #include "cns/cns.h"
 #include "hlp/hlp.h"
@@ -49,6 +50,7 @@
 #include "img/img.h"
 #include "pil/pil.h"
 #include "net/net.h"
+#include "nod/nod.h"
 #include "cli/cli.h"
 #include "srv/srv.h"
 #include "p2p/p2p.h"
@@ -65,6 +67,7 @@ typedef struct lw6_smob_types_s
   scm_t_bits bot;
   scm_t_bits look;
   scm_t_bits loader;
+  scm_t_bits db;
   scm_t_bits node;
 }
 lw6_smob_types_t;
@@ -137,9 +140,16 @@ typedef struct lw6_loader_smob_s
 }
 lw6_loader_smob_t;
 
+typedef struct lw6_db_smob_s
+{
+  lw6p2p_db_t *c_db;
+}
+lw6_db_smob_t;
+
 typedef struct lw6_node_smob_s
 {
   lw6p2p_node_t *c_node;
+  SCM db;
 }
 lw6_node_smob_t;
 
@@ -165,52 +175,41 @@ typedef struct lw6_global_s
   lw6sys_assoc_t *bot_smobs;
   lw6sys_assoc_t *look_smobs;
   lw6sys_assoc_t *loader_smobs;
+  lw6sys_assoc_t *db_smobs;
   lw6sys_assoc_t *node_smobs;
 }
 lw6_global_t;
 
-/*
- * In global.c
- */
+/* lw6-callback.c */
+extern void lw6_resize_callback (lw6gui_video_mode_t * video_mode);
+
+/* lw6-control.c */
+extern void lw6_release ();
+extern void lw6_exit ();
+
+/* lw6-fix.c */
+extern int lw6_fix_env (int argc, char *argv[]);
+
+/* lw6-funcs.c */
+extern int lw6_register_funcs ();
+extern void lw6_cns_handler (char *line);
+
+/* lw6-global.c */
 #define LW6_MUTEX_LOCK pthread_mutex_lock( &lw6_global.mutex );
 #define LW6_MUTEX_UNLOCK pthread_mutex_unlock( &lw6_global.mutex );
 
 extern lw6_global_t lw6_global;
 extern int lw6_init_global (int argc, char *argv[]);
-extern void lw6_quit_global_1 ();
-extern void lw6_quit_global_2 ();
+extern void lw6_quit_global ();
 
-/*
- * Functions in callback.c
- */
-extern void lw6_resize_callback (lw6gui_video_mode_t * video_mode);
-
-/*
- * Functions in control.c
- */
-extern void lw6_release ();
-extern void lw6_exit ();
-
-/*
- * Functions in funcs.c
- */
-extern int lw6_register_funcs ();
-extern void lw6_cns_handler (char *line);
-
-/*
- * Functions in main.c
- */
+/* lw6-main.c */
 extern int lw6_main (int argc, char *argv[]);
 
-/*
- * Functions in options.c
- */
+/* lw6-options.c */
 extern int lw6_process_non_run_options (int argc, char *argv[],
 					int *run_game);
 
-/*
- * In print.c
- */
+/* lw6-print.c */
 extern void lw6_print_help ();
 extern void lw6_print_version ();
 extern void lw6_print_short_copyright ();
@@ -242,9 +241,7 @@ extern void lw6_print_about (char *keyword);
 extern void lw6_print_hello (int argc, char *argv[]);
 extern void lw6_print_goodbye ();
 
-/*
- * Functions in smobs.c
- */
+/* lw6-smobs.c */
 extern SCM lw6_make_scm_dsp (lw6dsp_backend_t * c_dsp);
 extern lw6dsp_backend_t *lw6_scm_to_dsp (SCM dsp);
 extern void lw6_free_dsp_smob (lw6_dsp_smob_t * dsp_smob);
@@ -280,7 +277,10 @@ extern void lw6_free_look_smob (lw6_look_smob_t * look_smob);
 extern SCM lw6_make_scm_loader (lw6tsk_loader_t * c_loader);
 extern lw6tsk_loader_t *lw6_scm_to_loader (SCM loader);
 extern void lw6_free_loader_smob (lw6_loader_smob_t * loader_smob);
-extern SCM lw6_make_scm_node (lw6p2p_node_t * c_node);
+extern SCM lw6_make_scm_db (lw6p2p_db_t * c_db);
+extern lw6p2p_db_t *lw6_scm_to_db (SCM db);
+extern void lw6_free_db_smob (lw6_db_smob_t * db_smob);
+extern SCM lw6_make_scm_node (lw6p2p_node_t * c_node, SCM db);
 extern lw6p2p_node_t *lw6_scm_to_node (SCM node);
 extern void lw6_free_node_smob (lw6_node_smob_t * node_smob);
 extern int lw6_register_smobs ();
