@@ -41,8 +41,15 @@
  */
 lw6_global_t lw6_global;
 
-/*
- * Initializes global values to their defaults
+/**
+ * lw6_init_global
+ * 
+ * argc: number of args as passed to main
+ * argv: array of strings as passed to main
+ *
+ * Initializes global values to their defaults.
+ *
+ * Return value: 1 on success, 0 if failed
  */
 int
 lw6_init_global (int argc, char *argv[])
@@ -87,6 +94,8 @@ lw6_init_global (int argc, char *argv[])
     &&
     ((lw6_global.loader_smobs =
       lw6sys_assoc_new ((void (*)(void *)) lw6_free_loader_smob)) != NULL) &&
+    ((lw6_global.db_smobs =
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_db_smob)) != NULL) &&
     ((lw6_global.node_smobs =
       lw6sys_assoc_new ((void (*)(void *)) lw6_free_node_smob)) != NULL);
 
@@ -126,18 +135,20 @@ quit_net ()
   lw6_global.net_initialized = 0;
 }
 
+/**
+ * lw6_quit_global
+ * 
+ * argc: number of args as passed to main
+ * argv: array of strings as passed to main
+ *
+ * Frees global values. Will also garbage collect objects
+ * in case Guile failed to do it perfectly (or we failed to
+ * tell Guile how to do it).
+ *
+ * Return value: none.
+ */
 void
-lw6_quit_global_1 ()
-{
-  lw6sys_log (LW6SYS_LOG_INFO, _("free global ressources"));
-
-  quit_cns ();
-  quit_net ();
-  quit_cfg ();
-}
-
-void
-lw6_quit_global_2 ()
+lw6_quit_global ()
 {
   lw6sys_log (LW6SYS_LOG_INFO, _("final garbage collection"));
 
@@ -147,32 +158,51 @@ lw6_quit_global_2 ()
    * Should the Guile GC be perfect, not one single object
    * would be freed here.
    */
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining node smobs"));
   lw6sys_assoc_free (lw6_global.node_smobs);
   lw6_global.node_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining db smobs"));
+  lw6sys_assoc_free (lw6_global.db_smobs);
+  lw6_global.db_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining loader smobs"));
   lw6sys_assoc_free (lw6_global.loader_smobs);
   lw6_global.loader_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining look smobs"));
   lw6sys_assoc_free (lw6_global.look_smobs);
   lw6_global.look_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining bot smobs"));
   lw6sys_assoc_free (lw6_global.bot_smobs);
   lw6_global.bot_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining pilot smobs"));
   lw6sys_assoc_free (lw6_global.pilot_smobs);
   lw6_global.pilot_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining game_state smobs"));
   lw6sys_assoc_free (lw6_global.game_state_smobs);
   lw6_global.game_state_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining game_struct smobs"));
   lw6sys_assoc_free (lw6_global.game_struct_smobs);
   lw6_global.game_struct_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining menu smobs"));
   lw6sys_assoc_free (lw6_global.menu_smobs);
   lw6_global.menu_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining map smobs"));
   lw6sys_assoc_free (lw6_global.map_smobs);
   lw6_global.map_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining snd smobs"));
   lw6sys_assoc_free (lw6_global.snd_smobs);
   lw6_global.snd_smobs = NULL;
+  lw6sys_log (LW6SYS_LOG_INFO, _("freeing remaining dsp smobs"));
   lw6sys_assoc_free (lw6_global.dsp_smobs);
   lw6_global.dsp_smobs = NULL;
 
   LW6_MUTEX_UNLOCK;
 
-  pthread_mutex_destroy (&lw6_global.mutex);
+  quit_cns ();
+  quit_net ();
+  quit_cfg ();
 
+  pthread_mutex_destroy (&lw6_global.mutex);
   memset (&lw6_global, 0, sizeof (lw6_global_t));
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("all global stuff freed"));
 }
