@@ -29,6 +29,13 @@
 
 #include "liquidwar6.h"
 
+/**
+ * lw6_print_help
+ *
+ * Displays a short help message.
+ *
+ * Return value: none
+ */
 void
 lw6_print_help ()
 {
@@ -56,6 +63,13 @@ lw6_print_help ()
   fflush (stdout);
 }
 
+/**
+ * lw6_print_version
+ *
+ * Displays the version of the game.
+ *
+ * Return value: none
+ */
 void
 lw6_print_version ()
 {
@@ -66,6 +80,13 @@ lw6_print_version ()
   lw6_print_short_copyright ();
 }
 
+/**
+ * lw6_print_short_copyright
+ *
+ * Displays the copyright of the game (short version).
+ *
+ * Return value: none
+ */
 void
 lw6_print_short_copyright ()
 {
@@ -77,6 +98,13 @@ lw6_print_short_copyright ()
   fflush (stdout);
 }
 
+/**
+ * lw6_print_long_copyright
+ *
+ * Displays the copyright of the game (long version).
+ *
+ * Return value: none
+ */
 void
 lw6_print_long_copyright ()
 {
@@ -101,6 +129,13 @@ lw6_print_long_copyright ()
   fflush (stdout);
 }
 
+/**
+ * lw6_print_bench
+ *
+ * Displays the program bench value.
+ *
+ * Return value: none
+ */
 void
 lw6_print_bench (float bench_result)
 {
@@ -108,6 +143,14 @@ lw6_print_bench (float bench_result)
   fflush (stdout);
 }
 
+/**
+ * lw6_print_pedigree
+ *
+ * Displays the program pedigree, think of this as
+ * version on steroids.
+ *
+ * Return value: none
+ */
 void
 lw6_print_pedigree ()
 {
@@ -132,6 +175,13 @@ lw6_print_pedigree ()
   fflush (stdout);
 }
 
+/**
+ * lw6_print_host
+ *
+ * Displays the host on which the program was compiled.
+ *
+ * Return value: none
+ */
 void
 lw6_print_host ()
 {
@@ -146,6 +196,13 @@ lw6_print_host ()
   fflush (stdout);
 }
 
+/**
+ * lw6_print_audit
+ *
+ * Displays various paths used by the game.
+ *
+ * Return value: none
+ */
 void
 lw6_print_audit (int argc, char *argv[])
 {
@@ -355,10 +412,18 @@ lw6_print_audit (int argc, char *argv[])
   fflush (stdout);
 }
 
+/**
+ * lw6_print_audit
+ *
+ * Displays the list of modules compiled with the game.
+ *
+ * Return value: none
+ */
 void
 lw6_print_modules ()
 {
   printf ("enable-console: %s\n", lw6sys_build_get_enable_console ());
+  printf ("enable-gtk: %s\n", lw6sys_build_get_enable_gtk ());
   printf ("enable-mod-gl: %s\n", lw6sys_build_get_enable_mod_gl ());
   printf ("enable-mod-csound: %s\n", lw6sys_build_get_enable_mod_csound ());
   printf ("enable-mod-ogg: %s\n", lw6sys_build_get_enable_mod_ogg ());
@@ -376,6 +441,13 @@ lw6_print_modules ()
   fflush (stdout);
 }
 
+/**
+ * lw6_print_list_quick
+ *
+ * Displays the list of 'quick' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_quick ()
 {
@@ -389,6 +461,13 @@ lw6_print_list_quick ()
     }
 }
 
+/**
+ * lw6_print_list_doc
+ *
+ * Displays the list of 'doc' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_doc ()
 {
@@ -402,6 +481,13 @@ lw6_print_list_doc ()
     }
 }
 
+/**
+ * lw6_print_list_show
+ *
+ * Displays the list of 'show' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_show ()
 {
@@ -415,6 +501,13 @@ lw6_print_list_show ()
     }
 }
 
+/**
+ * lw6_print_list_path
+ *
+ * Displays the list of 'path' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_path ()
 {
@@ -428,6 +521,13 @@ lw6_print_list_path ()
     }
 }
 
+/**
+ * lw6_print_list_players
+ *
+ * Displays the list of 'players' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_players ()
 {
@@ -441,6 +541,13 @@ lw6_print_list_players ()
     }
 }
 
+/**
+ * lw6_print_list_input
+ *
+ * Displays the list of 'input' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_input ()
 {
@@ -454,6 +561,13 @@ lw6_print_list_input ()
     }
 }
 
+/**
+ * lw6_print_list_graphics
+ *
+ * Displays the list of 'graphics' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_graphics ()
 {
@@ -467,6 +581,13 @@ lw6_print_list_graphics ()
     }
 }
 
+/**
+ * lw6_print_list_sound
+ *
+ * Displays the list of 'sound' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_sound ()
 {
@@ -480,6 +601,13 @@ lw6_print_list_sound ()
     }
 }
 
+/**
+ * lw6_print_list_network
+ *
+ * Displays the list of 'network' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_network ()
 {
@@ -493,6 +621,13 @@ lw6_print_list_network ()
     }
 }
 
+/**
+ * lw6_print_list_map
+ *
+ * Displays the list of 'map' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_map ()
 {
@@ -506,6 +641,13 @@ lw6_print_list_map ()
     }
 }
 
+/**
+ * lw6_print_list_map_rules
+ *
+ * Displays the list of 'map rules' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_map_rules ()
 {
@@ -519,6 +661,13 @@ lw6_print_list_map_rules ()
     }
 }
 
+/**
+ * lw6_print_list_map_hints
+ *
+ * Displays the list of 'map hints' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_map_hints ()
 {
@@ -532,6 +681,13 @@ lw6_print_list_map_hints ()
     }
 }
 
+/**
+ * lw6_print_list_map_style
+ *
+ * Displays the list of 'amp style' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_map_style ()
 {
@@ -545,6 +701,13 @@ lw6_print_list_map_style ()
     }
 }
 
+/**
+ * lw6_print_list_funcs
+ *
+ * Displays the list of 'funcs'.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_funcs ()
 {
@@ -558,6 +721,13 @@ lw6_print_list_funcs ()
     }
 }
 
+/**
+ * lw6_print_list_hooks
+ *
+ * Displays the list of 'hooks'.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_hooks ()
 {
@@ -571,6 +741,13 @@ lw6_print_list_hooks ()
     }
 }
 
+/**
+ * lw6_print_list_tuning
+ *
+ * Displays the list of 'tuning' options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_tuning ()
 {
@@ -584,6 +761,13 @@ lw6_print_list_tuning ()
     }
 }
 
+/**
+ * lw6_print_list_aliases
+ *
+ * Displays the list of options aliases.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list_aliases ()
 {
@@ -597,6 +781,13 @@ lw6_print_list_aliases ()
     }
 }
 
+/**
+ * lw6_print_list
+ *
+ * Displays the list of all known options.
+ *
+ * Return value: none
+ */
 void
 lw6_print_list ()
 {
@@ -610,12 +801,26 @@ lw6_print_list ()
     }
 }
 
+/**
+ * lw6_print_about
+ *
+ * Displays the about message for a keyword.
+ *
+ * Return value: none
+ */
 void
 lw6_print_about (char *keyword)
 {
   lw6hlp_print_about (keyword, stdout);
 }
 
+/**
+ * lw6_print_hello
+ *
+ * Displays 'hello' at the beginning of the program.
+ *
+ * Return value: none
+ */
 void
 lw6_print_hello (int argc, char *argv[])
 {
@@ -630,6 +835,14 @@ lw6_print_hello (int argc, char *argv[])
 	      lw6sys_megabytes_available ());
 }
 
+/**
+ * lw6_print_goodbye
+ *
+ * Displays 'goodbye', typically use at end of program to
+ * know it's over and everything went fine.
+ *
+ * Return value: none
+ */
 void
 lw6_print_goodbye ()
 {
