@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,8 +26,23 @@
 
 #include "map.h"
 
+/**
+ * lw6map_body_builtin_custom
+ *
+ * @body: the body to initialize
+ * @w: the width
+ * @h: the height
+ * @d: the depth
+ * @noise_percent: the noise level to fill meta layers with
+ * @rules: the map rules
+ *
+ * Sets up a default body structure.
+ *
+ * Return value: none
+ */
 void
-lw6map_body_builtin_whd (lw6map_body_t * body, int w, int h, int d)
+lw6map_body_builtin_custom (lw6map_body_t * body, int w, int h, int d,
+			    int noise_percent, lw6map_rules_t * rules)
 {
   int layer;
 
@@ -44,11 +59,37 @@ lw6map_body_builtin_whd (lw6map_body_t * body, int w, int h, int d)
     }
   for (layer = 0; layer < body->shape.d; ++layer)
     {
-      lw6map_layer_builtin_whd (&(body->layers[layer]), w, h);
+      lw6map_layer_builtin_custom (&(body->layers[layer]), w, h);
     }
+  lw6map_body_check_and_fix_holes (body, rules);
+
+  lw6map_meta_layer_builtin_custom (&(body->glue), w, h, 1, noise_percent, 0);
+  lw6map_meta_layer_builtin_custom (&(body->boost), w, h, 1, noise_percent,
+				    1);
+  lw6map_meta_layer_builtin_custom (&(body->danger), w, h, 1, noise_percent,
+				    2);
+  lw6map_meta_layer_builtin_custom (&(body->medicine), w, h, 1, noise_percent,
+				    3);
+  lw6map_meta_layer_builtin_custom (&(body->one_way_north), w, h, 0,
+				    noise_percent, 4);
+  lw6map_meta_layer_builtin_custom (&(body->one_way_east), w, h, 0,
+				    noise_percent, 5);
+  lw6map_meta_layer_builtin_custom (&(body->one_way_south), w, h, 0,
+				    noise_percent, 6);
+  lw6map_meta_layer_builtin_custom (&(body->one_way_west), w, h, 0,
+				    noise_percent, 7);
   lw6map_body_fix_checksum (body);
 }
 
+/**
+ * lw6map_body_clear
+ *
+ * @body: the structure to clear
+ *
+ * Clears a body structure.
+ *
+ * Return value: none.
+ */
 void
 lw6map_body_clear (lw6map_body_t * body)
 {
@@ -58,6 +99,14 @@ lw6map_body_clear (lw6map_body_t * body)
     {
       lw6map_layer_clear (&(body->layers[layer]));
     }
+  lw6map_meta_layer_clear (&(body->glue));
+  lw6map_meta_layer_clear (&(body->boost));
+  lw6map_meta_layer_clear (&(body->danger));
+  lw6map_meta_layer_clear (&(body->medicine));
+  lw6map_meta_layer_clear (&(body->one_way_north));
+  lw6map_meta_layer_clear (&(body->one_way_east));
+  lw6map_meta_layer_clear (&(body->one_way_south));
+  lw6map_meta_layer_clear (&(body->one_way_west));
 
   memset (body, 0, sizeof (lw6map_body_t));
 }
@@ -81,6 +130,15 @@ update_checksum (lw6map_body_t * body, u_int32_t * checksum)
     }
 }
 
+/**
+ * lw6map_body_fix_checksum
+ *
+ * @body: the structure to update
+ *
+ * Updates (calculates) the checksum of a map body structure.
+ *
+ * Return value: none.
+ */
 void
 lw6map_body_fix_checksum (lw6map_body_t * body)
 {
@@ -138,9 +196,17 @@ update_if_needed (lw6map_body_t * dst, lw6map_body_t * src, int x,
   return ret;
 }
 
-/*
- * Checks the maps for "holes", that is fight zones that wouldn't
- * be connected with the main area, and fills them with walls.
+/**
+ * lw6map_body_check_and_fix_holes
+ *
+ * @body: the structure to update
+ * @rules: the game rules
+ *
+ * This (fundamental) function ensures that all playable areas in a map
+ * are connected. If isolated zones are found out, then they are marked
+ * as walls and not used any more.
+ *
+ * Return value: none.
  */
 int
 lw6map_body_check_and_fix_holes (lw6map_body_t * body, lw6map_rules_t * rules)
@@ -293,6 +359,19 @@ lw6map_body_check_and_fix_holes (lw6map_body_t * body, lw6map_rules_t * rules)
   return ret;
 }
 
+/**
+ * lw6map_body_coord_from_exture
+ *
+ * @level: the level to work on
+ * @body_x: the body (logical) x coord
+ * @body_y: the body (logical) y coord
+ * @texture_x: the texture x coord
+ * @texture_y: the texture y coord
+ *
+ * Gets body (logical) coords from texture position.
+ *
+ * Return value: 1 on success, 0 on failure (out of bounds)
+ */
 int
 lw6map_body_coord_from_texture (lw6map_level_t * level, int *body_x,
 				int *body_y, int texture_x, int texture_y)
@@ -318,7 +397,19 @@ lw6map_body_coord_from_texture (lw6map_level_t * level, int *body_x,
   return ret;
 }
 
-
+/**
+ * lw6map_body_get_with_texture_coord
+ *
+ * @level: the level to work on
+ * @texture_x: the texture x coord
+ * @texture_y: the texture y coord
+ * @z: the z position (depth related)
+ *
+ * Tells wether a given map position is free or not, but using
+ * texture coords.
+ *
+ * Return value: 1 if position is playable, 0 if not (wall)
+ */
 u_int8_t
 lw6map_body_get_with_texture_coord (lw6map_level_t * level,
 				    int texture_x, int texture_y, int z)
