@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -63,6 +63,29 @@ push_layer (lw6sys_hexa_serializer_t * hexa_serializer,
   return ret;
 }
 
+static int
+push_meta_layer (lw6sys_hexa_serializer_t * hexa_serializer,
+		 lw6map_meta_layer_t * meta_layer)
+{
+  int ret = 1;
+  int x, y;
+
+  ret = ret
+    && lw6sys_hexa_serializer_push_whd (hexa_serializer, meta_layer->shape);
+  for (y = 0; y < meta_layer->shape.h && ret; ++y)
+    {
+      for (x = 0; x < meta_layer->shape.w && ret; ++x)
+	{
+	  ret = ret
+	    && lw6sys_hexa_serializer_push_int8 (hexa_serializer,
+						 lw6map_meta_layer_get
+						 (meta_layer, x, y));
+	}
+    }
+
+  return ret;
+}
+
 static int
 push_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
 {
@@ -76,6 +99,14 @@ push_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
     {
       ret = ret && push_layer (hexa_serializer, &(body->layers[layer]));
     }
+  ret = ret && push_meta_layer (hexa_serializer, &(body->glue));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->boost));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->danger));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->medicine));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->one_way_north));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->one_way_east));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->one_way_south));
+  ret = ret && push_meta_layer (hexa_serializer, &(body->one_way_west));
 
   return ret;
 }
@@ -179,90 +210,120 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 					  param->style.pixelize);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.color_base.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.color_base.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.color_alternate.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.color_alternate.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.background_color_root.
+					  param->style.color_set.color_base.
 					  bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.background_color_root.
+					  param->style.color_set.color_base.
 					  fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.background_color_stuff.
+					  param->style.color_set.
+					  color_alternate.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  color_alternate.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  background_color_root.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  background_color_root.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  background_color_stuff.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  background_color_stuff.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  hud_color_frame.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  hud_color_frame.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  hud_color_text.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  hud_color_text.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  menu_color_default.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  menu_color_default.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  menu_color_selected.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  menu_color_selected.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  menu_color_disabled.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  menu_color_disabled.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  view_color_cursor.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  view_color_cursor.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  view_color_map.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.
+					  view_color_map.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_set.system_color.
 					  bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.background_color_stuff.
+					  param->style.color_set.system_color.
 					  fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.hud_color_frame.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.hud_color_frame.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.hud_color_text.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.hud_color_text.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_default.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_default.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_selected.
-					  bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_selected.
-					  fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_disabled.
-					  bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_disabled.
-					  fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.view_color_cursor.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.view_color_cursor.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.view_color_map.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.view_color_map.fg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.system_color.bg);
-  ret = ret
-    && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.system_color.fg);
+					  param->style.color_set.
+					  team_color_dead);
   for (i = 0; i < LW6MAP_NB_TEAM_COLORS && ret; ++i)
     {
       ret = ret
 	&& lw6sys_hexa_serializer_push_color (hexa_serializer,
-					      param->style.team_colors[i]);
+					      param->style.color_set.
+					      team_colors[i]);
     }
+  ret = ret
+    && lw6sys_hexa_serializer_push_str (hexa_serializer,
+					param->style.music_file);
+  ret = ret
+    && lw6sys_hexa_serializer_push_str (hexa_serializer,
+					param->style.music_filter);
+  ret = ret
+    && lw6sys_hexa_serializer_push_str (hexa_serializer,
+					param->style.music_exclude);
 
   return ret;
 }
@@ -357,6 +418,57 @@ pop_layer (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_layer_t * layer,
   return ret;
 }
 
+static int
+pop_meta_layer (lw6sys_hexa_serializer_t * hexa_serializer,
+		lw6map_meta_layer_t * meta_layer, lw6sys_whd_t * shape)
+{
+  int ret = 1;
+  int x, y;
+  int8_t c = 0;
+
+  ret = ret
+    && lw6sys_hexa_serializer_pop_whd (hexa_serializer, &(meta_layer->shape));
+  if (meta_layer->shape.w == shape->w && meta_layer->shape.h == shape->h)
+    {
+      meta_layer->data =
+	(u_int8_t *) LW6SYS_CALLOC (meta_layer->shape.w *
+				    meta_layer->shape.h);
+      if (meta_layer->data)
+	{
+	  for (y = 0; y < meta_layer->shape.h && ret; ++y)
+	    {
+	      for (x = 0; x < meta_layer->shape.w && ret; ++x)
+		{
+		  ret = ret
+		    && lw6sys_hexa_serializer_pop_int8 (hexa_serializer, &c);
+		  lw6map_meta_layer_set (meta_layer, x, y, c);
+		}
+	    }
+	}
+      else
+	{
+	  ret = 0;
+	}
+    }
+  else
+    {
+      if (meta_layer->shape.w == 0 && meta_layer->shape.h == 0)
+	{
+	  meta_layer->data = NULL;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("bad meta_layer shape (%dx%d != %dx%d)"),
+		      meta_layer->shape.w, meta_layer->shape.h, shape->w,
+		      shape->h);
+	  ret = 0;
+	}
+    }
+
+  return ret;
+}
+
 static int
 pop_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
 {
@@ -383,6 +495,26 @@ pop_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
 		  body->shape.w, body->shape.h, body->shape.d);
       ret = 0;
     }
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->glue), &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->boost), &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->danger), &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->medicine), &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->one_way_north),
+		       &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->one_way_east),
+		       &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->one_way_south),
+		       &(body->shape));
+  ret = ret
+    && pop_meta_layer (hexa_serializer, &(body->one_way_west),
+		       &(body->shape));
 
   return ret;
 }
@@ -514,94 +646,120 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
 					 &(param->style.pixelize));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.color_base.bg));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.color_base.fg));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.color_alternate.bg));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.color_alternate.fg));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.background_color_root.
+					 &(param->style.color_set.color_base.
 					   bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.background_color_root.
+					 &(param->style.color_set.color_base.
 					   fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
+					   color_alternate.bg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_set.
+					   color_alternate.fg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_set.
+					   background_color_root.bg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_set.
+					   background_color_root.fg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_set.
 					   background_color_stuff.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   background_color_stuff.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.hud_color_frame.bg));
+					 &(param->style.color_set.
+					   hud_color_frame.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.hud_color_frame.fg));
+					 &(param->style.color_set.
+					   hud_color_frame.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.hud_color_text.bg));
+					 &(param->style.color_set.
+					   hud_color_text.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.hud_color_text.fg));
+					 &(param->style.color_set.
+					   hud_color_text.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   menu_color_default.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   menu_color_default.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   menu_color_selected.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   menu_color_selected.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   menu_color_disabled.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   menu_color_disabled.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   view_color_cursor.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.
+					 &(param->style.color_set.
 					   view_color_cursor.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.view_color_map.bg));
+					 &(param->style.color_set.
+					   view_color_map.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.view_color_map.fg));
+					 &(param->style.color_set.
+					   view_color_map.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.system_color.bg));
+					 &(param->style.color_set.
+					   system_color.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.system_color.fg));
+					 &(param->style.color_set.
+					   system_color.fg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_set.
+					   team_color_dead));
   for (i = 0; i < LW6MAP_NB_TEAM_COLORS && ret; ++i)
     {
       ret = ret
 	&& lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					     &(param->style.team_colors[i]));
+					     &(param->style.color_set.
+					       team_colors[i]));
     }
+  ret = ret
+    && lw6sys_hexa_serializer_pop_str (hexa_serializer,
+				       &(param->style.music_file));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_str (hexa_serializer,
+				       &(param->style.music_filter));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_str (hexa_serializer,
+				       &(param->style.music_exclude));
 
   return ret;
 }
