@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -235,8 +235,20 @@ _default_source (lw6map_layer_t * layer, int width, int height)
   return ret;
 }
 
+/**
+ * lw6map_layer_builtin_custom
+ *
+ * @layer: the layer to init
+ * @w: width
+ * @h: height
+ *
+ * Creates a default layer. This is mostly for testing purposes, the default
+ * layer is not empty, it contains a simplified map of the world.
+ *
+ * Return value: none
+ */
 void
-lw6map_layer_builtin_whd (lw6map_layer_t * layer, int w, int h)
+lw6map_layer_builtin_custom (lw6map_layer_t * layer, int w, int h)
 {
   lw6map_layer_clear (layer);
 
@@ -250,6 +262,16 @@ lw6map_layer_builtin_whd (lw6map_layer_t * layer, int w, int h)
     }
 }
 
+/**
+ * lw6map_layer_clear
+ *
+ * @layer: the layer to init
+ *
+ * Clears a layer struct. This means freeing the pointer
+ * if it's non NULL and setting everything to 0.
+ *
+ * Return value: none
+ */
 void
 lw6map_layer_clear (lw6map_layer_t * layer)
 {
