@@ -31,7 +31,7 @@
 char *LW6MAP_RULES_LIST[] = {
   LW6DEF_TOTAL_TIME,
   LW6DEF_RESPAWN_TEAM,
-  LW6DEF_RESPAWN_RANDOM_PLACE,
+  LW6DEF_RESPAWN_POSITION_MODE,
   LW6DEF_MOVES_PER_ROUND,
   LW6DEF_SPREADS_PER_ROUND,
   LW6DEF_ROUNDS_PER_SEC,
@@ -49,7 +49,7 @@ char *LW6MAP_RULES_LIST[] = {
   LW6DEF_TOTAL_ARMIES_SIZE,
   LW6DEF_MAX_NB_TEAMS,
   LW6DEF_MAX_NB_CURSORS,
-  LW6DEF_MAX_NB_SERVERS,
+  LW6DEF_MAX_NB_NODES,
   LW6DEF_X_POLARITY,
   LW6DEF_Y_POLARITY,
   LW6DEF_Z_POLARITY,
@@ -86,13 +86,16 @@ char *LW6MAP_RULES_LIST[] = {
   LW6DEF_BOOST_POWER,
   LW6DEF_DANGER_POWER,
   LW6DEF_MEDICINE_POWER,
+  LW6DEF_FRAGS_MODE,
+  LW6DEF_FRAGS_TO_DISTRIBUTE,
+  LW6DEF_FRAGS_FADE_OUT,
   NULL				// very important that this list is NULL-terminated
 };
 
 static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_TOTAL_TIME,
   LW6MAP_RULES_DEFAULT_RESPAWN_TEAM,
-  LW6MAP_RULES_DEFAULT_RESPAWN_RANDOM_PLACE,
+  LW6MAP_RULES_DEFAULT_RESPAWN_POSITION_MODE,
   LW6MAP_RULES_DEFAULT_MOVES_PER_ROUND,
   LW6MAP_RULES_DEFAULT_SPREADS_PER_ROUND,
   LW6MAP_RULES_DEFAULT_ROUNDS_PER_SEC,
@@ -110,7 +113,7 @@ static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_TOTAL_ARMIES_SIZE,
   LW6MAP_RULES_DEFAULT_MAX_NB_TEAMS,
   LW6MAP_RULES_DEFAULT_MAX_NB_CURSORS,
-  LW6MAP_RULES_DEFAULT_MAX_NB_SERVERS,
+  LW6MAP_RULES_DEFAULT_MAX_NB_NODES,
   LW6MAP_RULES_DEFAULT_X_POLARITY,
   LW6MAP_RULES_DEFAULT_Y_POLARITY,
   LW6MAP_RULES_DEFAULT_Z_POLARITY,
@@ -146,13 +149,16 @@ static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_GLUE_POWER,
   LW6MAP_RULES_DEFAULT_BOOST_POWER,
   LW6MAP_RULES_DEFAULT_DANGER_POWER,
-  LW6MAP_RULES_DEFAULT_MEDICINE_POWER
+  LW6MAP_RULES_DEFAULT_MEDICINE_POWER,
+  LW6MAP_RULES_DEFAULT_FRAGS_MODE,
+  LW6MAP_RULES_DEFAULT_FRAGS_TO_DISTRIBUTE,
+  LW6MAP_RULES_DEFAULT_FRAGS_FADE_OUT
 };
 
 static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_TOTAL_TIME,
   LW6MAP_RULES_MIN_RESPAWN_TEAM,
-  LW6MAP_RULES_MIN_RESPAWN_RANDOM_PLACE,
+  LW6MAP_RULES_MIN_RESPAWN_POSITION_MODE,
   LW6MAP_RULES_MIN_MOVES_PER_ROUND,
   LW6MAP_RULES_MIN_SPREADS_PER_ROUND,
   LW6MAP_RULES_MIN_ROUNDS_PER_SEC,
@@ -170,7 +176,7 @@ static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_TOTAL_ARMIES_SIZE,
   LW6MAP_RULES_MIN_MAX_NB_TEAMS,
   LW6MAP_RULES_MIN_MAX_NB_CURSORS,
-  LW6MAP_RULES_MIN_MAX_NB_SERVERS,
+  LW6MAP_RULES_MIN_MAX_NB_NODES,
   LW6MAP_RULES_MIN_X_POLARITY,
   LW6MAP_RULES_MIN_Y_POLARITY,
   LW6MAP_RULES_MIN_Z_POLARITY,
@@ -206,13 +212,16 @@ static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_GLUE_POWER,
   LW6MAP_RULES_MIN_BOOST_POWER,
   LW6MAP_RULES_MIN_DANGER_POWER,
-  LW6MAP_RULES_MIN_MEDICINE_POWER
+  LW6MAP_RULES_MIN_MEDICINE_POWER,
+  LW6MAP_RULES_MIN_FRAGS_MODE,
+  LW6MAP_RULES_MIN_FRAGS_TO_DISTRIBUTE,
+  LW6MAP_RULES_MIN_FRAGS_FADE_OUT
 };
 
 static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_TOTAL_TIME,
   LW6MAP_RULES_MAX_RESPAWN_TEAM,
-  LW6MAP_RULES_MAX_RESPAWN_RANDOM_PLACE,
+  LW6MAP_RULES_MAX_RESPAWN_POSITION_MODE,
   LW6MAP_RULES_MAX_MOVES_PER_ROUND,
   LW6MAP_RULES_MAX_SPREADS_PER_ROUND,
   LW6MAP_RULES_MAX_ROUNDS_PER_SEC,
@@ -230,7 +239,7 @@ static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_TOTAL_ARMIES_SIZE,
   LW6MAP_RULES_MAX_MAX_NB_TEAMS,
   LW6MAP_RULES_MAX_MAX_NB_CURSORS,
-  LW6MAP_RULES_MAX_MAX_NB_SERVERS,
+  LW6MAP_RULES_MAX_MAX_NB_NODES,
   LW6MAP_RULES_MAX_X_POLARITY,
   LW6MAP_RULES_MAX_Y_POLARITY,
   LW6MAP_RULES_MAX_Z_POLARITY,
@@ -266,7 +275,10 @@ static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_GLUE_POWER,
   LW6MAP_RULES_MAX_BOOST_POWER,
   LW6MAP_RULES_MAX_DANGER_POWER,
-  LW6MAP_RULES_MAX_MEDICINE_POWER
+  LW6MAP_RULES_MAX_MEDICINE_POWER,
+  LW6MAP_RULES_MAX_FRAGS_MODE,
+  LW6MAP_RULES_MAX_FRAGS_TO_DISTRIBUTE,
+  LW6MAP_RULES_MAX_FRAGS_FADE_OUT
 };
 
 void
@@ -290,7 +302,7 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, rules->total_time);
   lw6sys_checksum_update_int32 (checksum, rules->respawn_team);
-  lw6sys_checksum_update_int32 (checksum, rules->respawn_random_place);
+  lw6sys_checksum_update_int32 (checksum, rules->respawn_position_mode);
   lw6sys_checksum_update_int32 (checksum, rules->moves_per_round);
   lw6sys_checksum_update_int32 (checksum, rules->spreads_per_round);
   lw6sys_checksum_update_int32 (checksum, rules->rounds_per_sec);
@@ -308,7 +320,7 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
   lw6sys_checksum_update_int32 (checksum, rules->total_armies_size);
   lw6sys_checksum_update_int32 (checksum, rules->max_nb_teams);
   lw6sys_checksum_update_int32 (checksum, rules->max_nb_cursors);
-  lw6sys_checksum_update_int32 (checksum, rules->max_nb_servers);
+  lw6sys_checksum_update_int32 (checksum, rules->max_nb_nodes);
   lw6sys_checksum_update_int32 (checksum, rules->x_polarity);
   lw6sys_checksum_update_int32 (checksum, rules->y_polarity);
   lw6sys_checksum_update_int32 (checksum, rules->z_polarity);
@@ -345,6 +357,9 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
   lw6sys_checksum_update_int32 (checksum, rules->boost_power);
   lw6sys_checksum_update_int32 (checksum, rules->danger_power);
   lw6sys_checksum_update_int32 (checksum, rules->medicine_power);
+  lw6sys_checksum_update_int32 (checksum, rules->frags_mode);
+  lw6sys_checksum_update_int32 (checksum, rules->frags_to_distribute);
+  lw6sys_checksum_update_int32 (checksum, rules->frags_fade_out);
 }
 
 int32_t *
@@ -366,9 +381,9 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->respawn_team);
 	    }
-	  else if (!strcmp (formatted_key, LW6DEF_RESPAWN_RANDOM_PLACE))
+	  else if (!strcmp (formatted_key, LW6DEF_RESPAWN_POSITION_MODE))
 	    {
-	      ret = &(rules->respawn_random_place);
+	      ret = &(rules->respawn_position_mode);
 	    }
 	  else if (!strcmp (formatted_key, LW6DEF_MOVES_PER_ROUND))
 	    {
@@ -438,9 +453,9 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->max_nb_cursors);
 	    }
-	  else if (!strcmp (formatted_key, LW6DEF_MAX_NB_SERVERS))
+	  else if (!strcmp (formatted_key, LW6DEF_MAX_NB_NODES))
 	    {
-	      ret = &(rules->max_nb_servers);
+	      ret = &(rules->max_nb_nodes);
 	    }
 	  else if (!strcmp (formatted_key, LW6DEF_X_POLARITY))
 	    {
@@ -586,6 +601,18 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->medicine_power);
 	    }
+	  else if (!strcmp (formatted_key, LW6DEF_FRAGS_MODE))
+	    {
+	      ret = &(rules->frags_mode);
+	    }
+	  else if (!strcmp (formatted_key, LW6DEF_FRAGS_TO_DISTRIBUTE))
+	    {
+	      ret = &(rules->frags_to_distribute);
+	    }
+	  else if (!strcmp (formatted_key, LW6DEF_FRAGS_FADE_OUT))
+	    {
+	      ret = &(rules->frags_fade_out);
+	    }
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
