@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,74 +56,79 @@ lw6map_style_defaults (lw6map_style_t * style)
   style->hidden_layer_alpha = LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA;
   style->colorize = LW6MAP_STYLE_DEFAULT_COLORIZE;
   style->pixelize = LW6MAP_STYLE_DEFAULT_PIXELIZE;
-  style->color_base.bg =
+  style->color_set.color_base.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_COLOR_BASE_BG);
-  style->color_base.fg =
+  style->color_set.color_base.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_COLOR_BASE_FG);
-  style->color_alternate.bg =
+  style->color_set.color_alternate.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_COLOR_ALTERNATE_BG);
-  style->color_alternate.fg =
+  style->color_set.color_alternate.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_COLOR_ALTERNATE_FG);
-  style->background_color_root.bg =
+  style->color_set.background_color_root.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_BACKGROUND_COLOR_ROOT_BG);
-  style->background_color_root.fg =
+  style->color_set.background_color_root.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_BACKGROUND_COLOR_ROOT_FG);
-  style->background_color_stuff.bg =
+  style->color_set.background_color_stuff.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_BACKGROUND_COLOR_STUFF_BG);
-  style->background_color_stuff.fg =
+  style->color_set.background_color_stuff.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_BACKGROUND_COLOR_STUFF_FG);
-  style->hud_color_frame.bg =
+  style->color_set.hud_color_frame.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_HUD_COLOR_FRAME_BG);
-  style->hud_color_frame.fg =
+  style->color_set.hud_color_frame.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_HUD_COLOR_FRAME_FG);
-  style->hud_color_text.bg =
+  style->color_set.hud_color_text.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_HUD_COLOR_TEXT_BG);
-  style->hud_color_text.fg =
+  style->color_set.hud_color_text.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_HUD_COLOR_TEXT_FG);
-  style->menu_color_default.bg =
+  style->color_set.menu_color_default.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_MENU_COLOR_DEFAULT_BG);
-  style->menu_color_default.fg =
+  style->color_set.menu_color_default.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_MENU_COLOR_DEFAULT_FG);
-  style->menu_color_selected.bg =
+  style->color_set.menu_color_selected.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_MENU_COLOR_SELECTED_BG);
-  style->menu_color_selected.fg =
+  style->color_set.menu_color_selected.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_MENU_COLOR_SELECTED_FG);
-  style->menu_color_disabled.bg =
+  style->color_set.menu_color_disabled.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_MENU_COLOR_DISABLED_BG);
-  style->menu_color_disabled.fg =
+  style->color_set.menu_color_disabled.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_MENU_COLOR_DISABLED_FG);
-  style->view_color_cursor.bg =
+  style->color_set.view_color_cursor.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_VIEW_COLOR_CURSOR_BG);
-  style->view_color_cursor.fg =
+  style->color_set.view_color_cursor.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_VIEW_COLOR_CURSOR_FG);
-  style->view_color_map.bg =
+  style->color_set.view_color_map.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_VIEW_COLOR_MAP_BG);
-  style->view_color_map.fg =
+  style->color_set.view_color_map.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_VIEW_COLOR_MAP_FG);
-  style->system_color.bg =
+  style->color_set.system_color.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_SYSTEM_COLOR_BG);
-  style->system_color.fg =
+  style->color_set.system_color.fg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_SYSTEM_COLOR_FG);
-  style->team_colors[LW6MAP_TEAM_COLOR_RED] =
+  style->color_set.team_color_dead =
+    lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_DEAD);
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_RED] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_RED);
-  style->team_colors[LW6MAP_TEAM_COLOR_GREEN] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_GREEN] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_GREEN);
-  style->team_colors[LW6MAP_TEAM_COLOR_BLUE] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_BLUE] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_BLUE);
-  style->team_colors[LW6MAP_TEAM_COLOR_YELLOW] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_YELLOW] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_YELLOW);
-  style->team_colors[LW6MAP_TEAM_COLOR_CYAN] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_CYAN] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_CYAN);
-  style->team_colors[LW6MAP_TEAM_COLOR_MAGENTA] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_MAGENTA] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_MAGENTA);
-  style->team_colors[LW6MAP_TEAM_COLOR_ORANGE] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_ORANGE] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_ORANGE);
-  style->team_colors[LW6MAP_TEAM_COLOR_LIGHTBLUE] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_LIGHTBLUE] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_LIGHTBLUE);
-  style->team_colors[LW6MAP_TEAM_COLOR_PURPLE] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_PURPLE] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_PURPLE);
-  style->team_colors[LW6MAP_TEAM_COLOR_PINK] =
+  style->color_set.team_colors[LW6MAP_TEAM_COLOR_PINK] =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_TEAM_COLOR_PINK);
+  style->music_file = lw6sys_str_copy (LW6MAP_STYLE_DEFAULT_MUSIC_FILE);
+  style->music_filter = lw6sys_str_copy (LW6MAP_STYLE_DEFAULT_MUSIC_FILTER);
+  style->music_exclude = lw6sys_str_copy (LW6MAP_STYLE_DEFAULT_MUSIC_EXCLUDE);
 }
 
 /*
@@ -157,6 +162,21 @@ lw6map_style_clear (lw6map_style_t * style)
 	  LW6SYS_FREE (style->view_style);
 	}
 
+      if (style->music_file)
+	{
+	  LW6SYS_FREE (style->music_file);
+	}
+
+      if (style->music_filter)
+	{
+	  LW6SYS_FREE (style->music_filter);
+	}
+
+      if (style->music_exclude)
+	{
+	  LW6SYS_FREE (style->music_exclude);
+	}
+
       lw6map_style_zero (style);
     }
 }
@@ -187,6 +207,18 @@ lw6map_style_copy (lw6map_style_t * dst, lw6map_style_t * src)
     {
       dst->view_style = lw6sys_str_copy (src->view_style);
     }
+  if (src->music_file)
+    {
+      dst->music_file = lw6sys_str_copy (src->music_file);
+    }
+  if (src->music_filter)
+    {
+      dst->music_filter = lw6sys_str_copy (src->music_filter);
+    }
+  if (src->music_exclude)
+    {
+      dst->music_exclude = lw6sys_str_copy (src->music_exclude);
+    }
 }
 
 int
@@ -280,150 +312,188 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
 	}
       else if (!strcmp (LW6DEF_COLOR_BASE_BG, formatted_key))
 	{
-	  style->color_base.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.color_base.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_COLOR_BASE_FG, formatted_key))
 	{
-	  style->color_base.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.color_base.fg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_COLOR_ALTERNATE_BG, formatted_key))
 	{
-	  style->color_alternate.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.color_alternate.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_COLOR_ALTERNATE_FG, formatted_key))
 	{
-	  style->color_alternate.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.color_alternate.fg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_ROOT_BG, formatted_key))
 	{
-	  style->background_color_root.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.background_color_root.bg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_ROOT_FG, formatted_key))
 	{
-	  style->background_color_root.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.background_color_root.fg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_STUFF_BG, formatted_key))
 	{
-	  style->background_color_stuff.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.background_color_stuff.bg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_STUFF_FG, formatted_key))
 	{
-	  style->background_color_stuff.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.background_color_stuff.fg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_FRAME_BG, formatted_key))
 	{
-	  style->hud_color_frame.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.hud_color_frame.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_FRAME_FG, formatted_key))
 	{
-	  style->hud_color_frame.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.hud_color_frame.fg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_TEXT_BG, formatted_key))
 	{
-	  style->hud_color_text.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.hud_color_text.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_TEXT_FG, formatted_key))
 	{
-	  style->hud_color_text.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.hud_color_text.fg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DEFAULT_BG, formatted_key))
 	{
-	  style->menu_color_default.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.menu_color_default.bg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DEFAULT_FG, formatted_key))
 	{
-	  style->menu_color_default.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.menu_color_default.fg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_SELECTED_BG, formatted_key))
 	{
-	  style->menu_color_selected.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.menu_color_selected.bg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_SELECTED_FG, formatted_key))
 	{
-	  style->menu_color_selected.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.menu_color_selected.fg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DISABLED_BG, formatted_key))
 	{
-	  style->menu_color_disabled.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.menu_color_disabled.bg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DISABLED_FG, formatted_key))
 	{
-	  style->menu_color_disabled.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.menu_color_disabled.fg =
+	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_CURSOR_BG, formatted_key))
 	{
-	  style->view_color_cursor.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.view_color_cursor.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_CURSOR_FG, formatted_key))
 	{
-	  style->view_color_cursor.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.view_color_cursor.fg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_MAP_BG, formatted_key))
 	{
-	  style->view_color_map.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.view_color_map.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_MAP_FG, formatted_key))
 	{
-	  style->view_color_map.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.view_color_map.fg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_SYSTEM_COLOR_BG, formatted_key))
 	{
-	  style->system_color.bg = lw6sys_color_a_to_8 (value);
+	  style->color_set.system_color.bg = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_SYSTEM_COLOR_FG, formatted_key))
 	{
-	  style->system_color.fg = lw6sys_color_a_to_8 (value);
+	  style->color_set.system_color.fg = lw6sys_color_a_to_8 (value);
+	}
+      else if (!strcmp (LW6DEF_TEAM_COLOR_DEAD, formatted_key))
+	{
+	  style->color_set.team_color_dead = lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_RED, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_RED] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_RED] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_GREEN, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_GREEN] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_GREEN] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_BLUE, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_BLUE] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_BLUE] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_YELLOW, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_YELLOW] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_YELLOW] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_CYAN, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_CYAN] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_CYAN] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_MAGENTA, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_MAGENTA] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_MAGENTA] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_ORANGE, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_ORANGE] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_ORANGE] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_LIGHTBLUE, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_LIGHTBLUE] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_LIGHTBLUE] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_PURPLE, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_PURPLE] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_PURPLE] =
 	    lw6sys_color_a_to_8 (value);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_PINK, formatted_key))
 	{
-	  style->team_colors[LW6MAP_TEAM_COLOR_PINK] =
+	  style->color_set.team_colors[LW6MAP_TEAM_COLOR_PINK] =
 	    lw6sys_color_a_to_8 (value);
 	}
+      else if (!strcmp (LW6DEF_MUSIC_FILE, formatted_key))
+	{
+	  if (style->music_file)
+	    {
+	      LW6SYS_FREE (style->music_file);
+	    }
+	  style->music_file = lw6sys_str_copy (value);
+	}
+      else if (!strcmp (LW6DEF_MUSIC_FILTER, formatted_key))
+	{
+	  if (style->music_filter)
+	    {
+	      LW6SYS_FREE (style->music_filter);
+	    }
+	  style->music_filter = lw6sys_str_copy (value);
+	}
+      else if (!strcmp (LW6DEF_MUSIC_EXCLUDE, formatted_key))
+	{
+	  if (style->music_exclude)
+	    {
+	      LW6SYS_FREE (style->music_exclude);
+	    }
+	  style->music_exclude = lw6sys_str_copy (value);
+	}
       else
 	{
 	  ret = 0;		// no entry matches
@@ -513,154 +583,179 @@ lw6map_style_get (lw6map_style_t * style, char *key)
 	}
       else if (!strcmp (LW6DEF_COLOR_BASE_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->color_base.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.color_base.bg);
 	}
       else if (!strcmp (LW6DEF_COLOR_BASE_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->color_base.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.color_base.fg);
 	}
       else if (!strcmp (LW6DEF_COLOR_ALTERNATE_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->color_alternate.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.color_alternate.bg);
 	}
       else if (!strcmp (LW6DEF_COLOR_ALTERNATE_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->color_alternate.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.color_alternate.fg);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_ROOT_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->background_color_root.bg);
+	  ret =
+	    lw6sys_color_8_to_a (style->color_set.background_color_root.bg);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_ROOT_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->background_color_root.fg);
+	  ret =
+	    lw6sys_color_8_to_a (style->color_set.background_color_root.fg);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_STUFF_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->background_color_stuff.bg);
+	  ret =
+	    lw6sys_color_8_to_a (style->color_set.background_color_stuff.bg);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_STUFF_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->background_color_stuff.fg);
+	  ret =
+	    lw6sys_color_8_to_a (style->color_set.background_color_stuff.fg);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_FRAME_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->hud_color_frame.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.hud_color_frame.bg);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_FRAME_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->hud_color_frame.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.hud_color_frame.fg);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_TEXT_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->color_base.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.color_base.bg);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_TEXT_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->color_base.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.color_base.fg);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DEFAULT_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->menu_color_default.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.menu_color_default.bg);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DEFAULT_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->menu_color_default.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.menu_color_default.fg);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_SELECTED_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->menu_color_selected.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.menu_color_selected.bg);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_SELECTED_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->menu_color_selected.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.menu_color_selected.fg);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DISABLED_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->menu_color_disabled.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.menu_color_disabled.bg);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_DISABLED_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->menu_color_disabled.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.menu_color_disabled.fg);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_CURSOR_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->view_color_cursor.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.view_color_cursor.bg);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_CURSOR_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->view_color_cursor.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.view_color_cursor.fg);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_MAP_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->view_color_map.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.view_color_map.bg);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_MAP_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->view_color_map.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.view_color_map.fg);
 	}
       else if (!strcmp (LW6DEF_SYSTEM_COLOR_BG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->system_color.bg);
+	  ret = lw6sys_color_8_to_a (style->color_set.system_color.bg);
 	}
       else if (!strcmp (LW6DEF_SYSTEM_COLOR_FG, formatted_key))
 	{
-	  ret = lw6sys_color_8_to_a (style->system_color.fg);
+	  ret = lw6sys_color_8_to_a (style->color_set.system_color.fg);
+	}
+      else if (!strcmp (LW6DEF_TEAM_COLOR_DEAD, formatted_key))
+	{
+	  ret = lw6sys_color_8_to_a (style->color_set.team_color_dead);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_RED, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_RED]);
+	    lw6sys_color_8_to_a (style->color_set.team_colors
+				 [LW6MAP_TEAM_COLOR_RED]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_GREEN, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_GREEN]);
+	    lw6sys_color_8_to_a (style->color_set.team_colors
+				 [LW6MAP_TEAM_COLOR_GREEN]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_BLUE, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_BLUE]);
+	    lw6sys_color_8_to_a (style->color_set.team_colors
+				 [LW6MAP_TEAM_COLOR_BLUE]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_YELLOW, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors
+	    lw6sys_color_8_to_a (style->color_set.team_colors
 				 [LW6MAP_TEAM_COLOR_YELLOW]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_CYAN, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_CYAN]);
+	    lw6sys_color_8_to_a (style->color_set.team_colors
+				 [LW6MAP_TEAM_COLOR_CYAN]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_MAGENTA, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors
+	    lw6sys_color_8_to_a (style->color_set.team_colors
 				 [LW6MAP_TEAM_COLOR_MAGENTA]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_ORANGE, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors
+	    lw6sys_color_8_to_a (style->color_set.team_colors
 				 [LW6MAP_TEAM_COLOR_ORANGE]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_LIGHTBLUE, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors
+	    lw6sys_color_8_to_a (style->color_set.team_colors
 				 [LW6MAP_TEAM_COLOR_LIGHTBLUE]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_PURPLE, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors
+	    lw6sys_color_8_to_a (style->color_set.team_colors
 				 [LW6MAP_TEAM_COLOR_PURPLE]);
 	}
       else if (!strcmp (LW6DEF_TEAM_COLOR_PINK, formatted_key))
 	{
 	  ret =
-	    lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_PINK]);
+	    lw6sys_color_8_to_a (style->color_set.team_colors
+				 [LW6MAP_TEAM_COLOR_PINK]);
+	}
+      else if (!strcmp (LW6DEF_MUSIC_FILE, formatted_key))
+	{
+	  ret = lw6sys_str_copy (style->music_file);
+	}
+      else if (!strcmp (LW6DEF_MUSIC_FILTER, formatted_key))
+	{
+	  ret = lw6sys_str_copy (style->music_filter);
+	}
+      else if (!strcmp (LW6DEF_MUSIC_EXCLUDE, formatted_key))
+	{
+	  ret = lw6sys_str_copy (style->music_exclude);
 	}
       LW6SYS_FREE (formatted_key);
     }
@@ -693,11 +788,21 @@ lw6map_style_get_default (char *key)
   return ret;
 }
 
+int
+lw6map_color_set_is_same (lw6map_color_set_t * color_set_a,
+			  lw6map_color_set_t * color_set_b)
+{
+  int ret = 0;
+
+  ret = (memcmp (color_set_a, color_set_b, sizeof (lw6map_color_set_t)) == 0);
+
+  return ret;
+}
+
 int
 lw6map_style_is_same (lw6map_style_t * style_a, lw6map_style_t * style_b)
 {
   int ret = 1;
-  int i;
 
   ret = ret && style_a->keep_ratio == style_b->keep_ratio;
   ret = ret && style_a->zoom == style_b->zoom;
@@ -718,45 +823,12 @@ lw6map_style_is_same (lw6map_style_t * style_a, lw6map_style_t * style_b)
   ret = ret && style_a->colorize == style_b->colorize;
   ret = ret && style_a->pixelize == style_b->pixelize;
   ret = ret
-    && lw6map_color_is_same (&style_a->color_base, &style_b->color_base);
+    && lw6map_color_set_is_same (&style_a->color_set, &style_b->color_set);
+  ret = ret && lw6sys_str_is_same (style_a->music_file, style_b->music_file);
   ret = ret
-    && lw6map_color_is_same (&style_a->color_alternate,
-			     &style_b->color_alternate);
+    && lw6sys_str_is_same (style_a->music_filter, style_b->music_filter);
   ret = ret
-    && lw6map_color_is_same (&style_a->background_color_root,
-			     &style_b->background_color_root);
-  ret = ret
-    && lw6map_color_is_same (&style_a->background_color_stuff,
-			     &style_b->background_color_stuff);
-  ret = ret
-    && lw6map_color_is_same (&style_a->hud_color_frame,
-			     &style_b->hud_color_frame);
-  ret = ret
-    && lw6map_color_is_same (&style_a->hud_color_text,
-			     &style_b->hud_color_text);
-  ret = ret
-    && lw6map_color_is_same (&style_a->menu_color_default,
-			     &style_b->menu_color_default);
-  ret = ret
-    && lw6map_color_is_same (&style_a->menu_color_selected,
-			     &style_b->menu_color_selected);
-  ret = ret
-    && lw6map_color_is_same (&style_a->menu_color_disabled,
-			     &style_b->menu_color_disabled);
-  ret = ret
-    && lw6map_color_is_same (&style_a->view_color_cursor,
-			     &style_b->view_color_cursor);
-  ret = ret
-    && lw6map_color_is_same (&style_a->view_color_map,
-			     &style_b->view_color_map);
-  ret = ret
-    && lw6map_color_is_same (&style_a->system_color, &style_b->system_color);
-  for (i = 0; i < LW6MAP_NB_TEAM_COLORS; ++i)
-    {
-      ret = ret
-	&& lw6sys_color_is_same (style_a->team_colors[i],
-				 style_b->team_colors[i]);
-    }
+    && lw6sys_str_is_same (style_a->music_exclude, style_b->music_exclude);
 
   return ret;
 }
