@@ -28,9 +28,22 @@
 #define LW6MAP_MAX_FIGHTER_HEALTH 10000
 #define LW6MAP_MAX_NB_TEAMS 10
 #define LW6MAP_MAX_NB_CURSORS 26
-#define LW6MAP_MAX_NB_SERVERS 26
+#define LW6MAP_MAX_NB_NODES 26
 #define LW6MAP_MAX_NB_DIR_TRIES 7
 
+#define LW6MAP_RULES_POSITION_MODE_PREDEFINED 0
+#define LW6MAP_RULES_POSITION_MODE_PICK_EXISTING 1
+#define LW6MAP_RULES_POSITION_MODE_TOTAL_RANDOM 2
+
+#define LW6MAP_RULES_COLOR_CONFLICT_MODE_ALLOW_SHARE 0
+#define LW6MAP_RULES_COLOR_CONFLICT_MODE_ALLOW_LOCAL_SHARE 1
+#define LW6MAP_RULES_COLOR_CONFLICT_MODE_PICK_NEW 2
+
+#define LW6MAP_RULES_FRAGS_MODE_ONE_NEGATIVE_POINT 0
+#define LW6MAP_RULES_FRAGS_MODE_ONE_FOR_WINNERS_ALL_FOR_LOSER 1
+#define LW6MAP_RULES_FRAGS_MODE_BALANCED 2
+#define LW6MAP_RULES_FRAGS_MODE_PROPORTIONAL 3
+
 /*
  * All static rules default/min/max
  */
@@ -45,9 +58,9 @@
 #define LW6MAP_RULES_MIN_RESPAWN_TEAM 0
 #define LW6MAP_RULES_MAX_RESPAWN_TEAM 1
 
-#define LW6MAP_RULES_DEFAULT_RESPAWN_RANDOM_PLACE 1
-#define LW6MAP_RULES_MIN_RESPAWN_RANDOM_PLACE 0
-#define LW6MAP_RULES_MAX_RESPAWN_RANDOM_PLACE 1
+#define LW6MAP_RULES_DEFAULT_RESPAWN_POSITION_MODE LW6MAP_RULES_POSITION_MODE_PICK_EXISTING
+#define LW6MAP_RULES_MIN_RESPAWN_POSITION_MODE 0
+#define LW6MAP_RULES_MAX_RESPAWN_POSITION_MODE 2
 
 #define LW6MAP_RULES_DEFAULT_MOVES_PER_ROUND 2
 #define LW6MAP_RULES_MIN_MOVES_PER_ROUND 1
@@ -125,10 +138,10 @@
 #define LW6MAP_RULES_MIN_MAX_NB_CURSORS 2
 #define LW6MAP_RULES_MAX_MAX_NB_CURSORS LW6MAP_MAX_NB_CURSORS
 
-// 10, not 26
-#define LW6MAP_RULES_DEFAULT_MAX_NB_SERVERS LW6MAP_MAX_NB_TEAMS
-#define LW6MAP_RULES_MIN_MAX_NB_SERVERS 2
-#define LW6MAP_RULES_MAX_MAX_NB_SERVERS LW6MAP_MAX_NB_SERVERS
+// LW6MAP_MAX_NB_TEAMS+2
+#define LW6MAP_RULES_DEFAULT_MAX_NB_NODES 12
+#define LW6MAP_RULES_MIN_MAX_NB_NODES 2
+#define LW6MAP_RULES_MAX_MAX_NB_NODES LW6MAP_MAX_NB_NODES
 
 #define LW6MAP_RULES_DEFAULT_X_POLARITY 0
 #define LW6MAP_RULES_MIN_X_POLARITY -1
@@ -246,11 +259,11 @@
 #define LW6MAP_RULES_MIN_START_PINK_Y 0
 #define LW6MAP_RULES_MAX_START_PINK_Y 100
 
-#define LW6MAP_RULES_DEFAULT_START_POSITION_MODE 0
+#define LW6MAP_RULES_DEFAULT_START_POSITION_MODE LW6MAP_RULES_POSITION_MODE_PREDEFINED
 #define LW6MAP_RULES_MIN_START_POSITION_MODE 0
 #define LW6MAP_RULES_MAX_START_POSITION_MODE 2
 
-#define LW6MAP_RULES_DEFAULT_COLOR_CONFLICT_MODE 1
+#define LW6MAP_RULES_DEFAULT_COLOR_CONFLICT_MODE LW6MAP_RULES_COLOR_CONFLICT_MODE_ALLOW_LOCAL_SHARE
 #define LW6MAP_RULES_MIN_COLOR_CONFLICT_MODE 0
 #define LW6MAP_RULES_MAX_COLOR_CONFLICT_MODE 2
 
@@ -274,6 +287,18 @@
 #define LW6MAP_RULES_MIN_MEDICINE_POWER 0
 #define LW6MAP_RULES_MAX_MEDICINE_POWER LW6MAP_MAX_FIGHTER_HEALTH
 
+#define LW6MAP_RULES_DEFAULT_FRAGS_MODE LW6MAP_RULES_FRAGS_MODE_BALANCED
+#define LW6MAP_RULES_MIN_FRAGS_MODE 0
+#define LW6MAP_RULES_MAX_FRAGS_MODE 3
+
+#define LW6MAP_RULES_DEFAULT_FRAGS_TO_DISTRIBUTE 100
+#define LW6MAP_RULES_MIN_FRAGS_TO_DISTRIBUTE 10
+#define LW6MAP_RULES_MAX_FRAGS_TO_DISTRIBUTE 1000
+
+#define LW6MAP_RULES_DEFAULT_FRAGS_FADE_OUT 100
+#define LW6MAP_RULES_MIN_FRAGS_FADE_OUT 10
+#define LW6MAP_RULES_MAX_FRAGS_FADE_OUT 100
+
 /*
  * Note: it's important that floats are never ever used in map rules.
  * In fact, we need maps to be 100,00 (lots of zeroes) predictable,
@@ -287,7 +312,7 @@ typedef struct lw6map_rules_s
 {
   int32_t total_time;
   int32_t respawn_team;
-  int32_t respawn_random_place;
+  int32_t respawn_position_mode;
   int32_t moves_per_round;
   int32_t spreads_per_round;
   int32_t rounds_per_sec;
@@ -305,7 +330,7 @@ typedef struct lw6map_rules_s
   int32_t total_armies_size;
   int32_t max_nb_teams;
   int32_t max_nb_cursors;
-  int32_t max_nb_servers;
+  int32_t max_nb_nodes;
   int32_t x_polarity;
   int32_t y_polarity;
   int32_t z_polarity;
@@ -342,6 +367,9 @@ typedef struct lw6map_rules_s
   int32_t boost_power;
   int32_t danger_power;
   int32_t medicine_power;
+  int32_t frags_mode;
+  int32_t frags_to_distribute;
+  int32_t frags_fade_out;
 } lw6map_rules_t;
 extern char *LW6MAP_RULES_LIST[];
 
