@@ -32,10 +32,12 @@ typedef u_int32_t in_addr_t;
 typedef int socklen_t;
 #else
 #include <sys/types.h>
+#include <sys/signal.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <sys/socket.h>
-#include <sys/signal.h>
+#include <netdb.h>
+#include <ifaddrs.h>
 #endif
 
 #define _LW6NET_IP_SIZE 20	// only 15 required but...
@@ -105,6 +107,7 @@ typedef struct _lw6net_context_s
   _lw6net_socket_counters_t socket_counters;
   lw6sys_assoc_t *threads;
   int server_sock;
+  void *dns_mutex;
 }
 _lw6net_context_t;
 
@@ -123,6 +126,7 @@ extern _lw6net_context_t *_lw6net_global_context;
  * In address.c
  */
 extern char *_lw6net_inet_ntoa (struct in_addr in);
+extern int _lw6net_inet_aton (struct in_addr *in, char *ip);
 
 /*
  * In const.c
@@ -130,6 +134,10 @@ extern char *_lw6net_inet_ntoa (struct in_addr in);
 extern int _lw6net_const_init (int argc, char *argv[]);
 extern void _lw6net_const_quit ();
 
+/* net-dns.c */
+extern int _lw6net_dns_init ();
+extern void _lw6net_dns_quit ();
+
 // net-error.c
 #ifdef LW6_MS_WINDOWS
 extern char *_lw6net_wsa_str (int wsa_int);
