@@ -25,10 +25,14 @@
 #endif
 
 #include "net.h"
+#include "net-internal.h"
 
 #define TEST_ARGC 1
 #define TEST_ARGV0 "prog"
 
+#define TEST_HOST_IP "127.0.0.1"
+#define TEST_HOST_OK "localhost"
+#define TEST_HOST_KO "now-if-this-is-a valid HOST there's a serious PROBLEM!!!!"
 #define TEST_UNREACHABLE_IP "209.85.135.99"
 #define TEST_UNREACHABLE_PORT 8000
 #define TEST_TCP_DELAY 0.1f
@@ -37,6 +41,179 @@
 #define TEST_LINE1 "foo"
 #define TEST_LINE2 "a\tb\tc"
 #define TEST_LINE3 "azerty azerty azerty azerty azerty azerty azerty azerty azerty azerty azerty azerty"
+#define TEST_LINES_OK "there\nare\n4\nlines\n"
+#define TEST_LINES_KO "this\nis\ntruncated"
+
+static int
+test_address ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    struct in_addr in;
+    char *str = NULL;
+
+    ret = 0;
+    if (_lw6net_inet_aton (&in, TEST_HOST_IP))
+      {
+	str = _lw6net_inet_ntoa (in);
+	if (str)
+	  {
+	    if (lw6sys_str_is_same (TEST_HOST_IP, str))
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("\"%s\" converted to/from in_addr OK"), str);
+		ret = 1;
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _("\"%s\" transformed in \"%s\" by aton + ntoa"),
+			    TEST_HOST_IP, str);
+	      }
+	    LW6SYS_FREE (str);
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+static int
+test_dns ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *ip = NULL;
+
+    if (lw6net_dns_is_ip (TEST_HOST_IP) && !lw6net_dns_is_ip (TEST_HOST_OK))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _
+		    ("trivial IP parsing reports \"%s\" is an IP but not \"%s\""),
+		    TEST_HOST_IP, TEST_HOST_OK);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _
+		    ("trivial IP parsing failed to report \"%s\" as an IP and \"%s\" as not"),
+		    TEST_HOST_IP, TEST_HOST_OK);
+	ret = 0;
+      }
+    ip = lw6net_dns_gethostbyname (TEST_HOST_IP);
+    if (ip)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("gethostbyname on \"%s\" returns \"%s\""), TEST_HOST_IP,
+		    ip);
+	LW6SYS_FREE (ip);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("gethostbyname on \"%s\" failed"),
+		    TEST_HOST_IP);
+	ret = 0;
+      }
+    ip = lw6net_dns_gethostbyname (TEST_HOST_OK);
+    if (ip)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("gethostbyname on \"%s\" returns \"%s\""), TEST_HOST_OK,
+		    ip);
+	LW6SYS_FREE (ip);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("gethostbyname on \"%s\" failed"),
+		    TEST_HOST_OK);
+	ret = 0;
+      }
+    ip = lw6net_dns_gethostbyname (TEST_HOST_KO);
+    if (ip)
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _
+		    ("gethostbyname on \"%s\" returns \"%s\", this is... surprising"),
+		    TEST_HOST_KO, ip);
+	LW6SYS_FREE (ip);
+	ret = 0;
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("gethostbyname on \"%s\" returns NULL, this is fine"),
+		    TEST_HOST_KO);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+/*
+ * Testing functions in if.c
+ */
+static int
+test_if ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *ip = NULL;
+    char *public_url = NULL;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("trying to guess local interface IP"));
+    ip = lw6net_if_guess_local ();
+    if (ip)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("local interface IP is \"%s\""), ip);
+	LW6SYS_FREE (ip);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _
+		    ("unable to guess local interface, this is a problem only if machine *really* has no network available"));
+      }
+    public_url =
+      lw6net_if_guess_public_url (LW6NET_ADDRESS_ANY, LW6NET_DEFAULT_PORT);
+    if (public_url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("public URL on default port would be \"%s\""),
+		    public_url);
+	LW6SYS_FREE (public_url);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("unable to guess public URL"));
+	ret = 0;
+      }
+    public_url =
+      lw6net_if_guess_public_url (TEST_UNREACHABLE_IP, LW6NET_HTTP_PORT);
+    if (public_url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("public URL on http port with IP %s would be \"%s\""),
+		    TEST_UNREACHABLE_IP, public_url);
+	LW6SYS_FREE (public_url);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("unable to guess public URL"));
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
 
 static int
 prepare_2_tcp_socks (int *sock1, int *sock2)
@@ -338,6 +515,14 @@ test_udp ()
   return ret;
 }
 
+void
+_udp_lines_callback (void *func_data, void *data)
+{
+  char *line = (char *) data;
+
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("line=\"%s\""), line);
+}
+
 /*
  * Testing functions in line.c
  */
@@ -405,6 +590,7 @@ test_line ()
     char *line;
     char *incoming_ip;
     int incoming_port;
+    lw6sys_list_t *list = NULL;
 
     if (prepare_2_udp_socks (&sock1, &sock2))
       {
@@ -419,6 +605,7 @@ test_line ()
 				     LW6NET_DEFAULT_PORT))
 	  {
 	    lw6sys_log (LW6SYS_LOG_NOTICE, _("lines sent"));
+	    lw6sys_idle ();
 	    ret_tmp = 1;
 	    for (i = 0; i < 4; ++i)
 	      {
@@ -445,6 +632,44 @@ test_line ()
 		  }
 	      }
 	  }
+	if (lw6net_udp_send
+	    (sock2, TEST_LINES_OK, strlen (TEST_LINES_OK),
+	     LW6NET_ADDRESS_LOOPBACK, LW6NET_DEFAULT_PORT))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("lines sent"));
+	    lw6sys_idle ();
+	    list =
+	      lw6net_recv_lines_udp (sock1, &incoming_ip, &incoming_port);
+	    if (list)
+	      {
+		lw6sys_list_map (list, _udp_lines_callback, NULL);
+		lw6sys_list_free (list);
+		LW6SYS_FREE (incoming_ip);
+	      }
+	  }
+	if (lw6net_udp_send
+	    (sock2, TEST_LINES_OK, strlen (TEST_LINES_KO),
+	     LW6NET_ADDRESS_LOOPBACK, LW6NET_DEFAULT_PORT))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("lines sent"));
+	    lw6sys_idle ();
+	    list =
+	      lw6net_recv_lines_udp (sock1, &incoming_ip, &incoming_port);
+	    if (list)
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _
+			    ("received lines, when it should have returned an error"));
+		ret_tmp = 0;
+		lw6sys_list_free (list);
+		LW6SYS_FREE (incoming_ip);
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("truncated lines handled correctly"));
+	      }
+	  }
       }
     if (sock1 >= 0)
       {
@@ -492,8 +717,8 @@ lw6net_test (int mode)
       lw6cfg_test (mode);
     }
 
-  ret = lw6net_init (argc, argv) && test_tcp () && test_udp ()
-    && test_line ();
+  ret = lw6net_init (argc, argv) && test_address () && test_dns ()
+    && test_if () && test_tcp () && test_udp () && test_line ();
 
   if (ret)
     {
