@@ -37,6 +37,8 @@ lw6net_udp_client ()
 {
   int sock = -1;
   int err = 0;
+  int enable = 1;
+
 #ifdef LW6_MS_WINDOWS
   unsigned long enable_ul = 1;
 #endif
@@ -48,8 +50,17 @@ lw6net_udp_client ()
   if (sock >= 0)
     {
       lw6sys_log (LW6SYS_LOG_INFO, _("new UDP socket %d"), sock);
+
       _lw6net_global_context->socket_counters.open_counter++;
 
+      if (setsockopt (sock, SOL_SOCKET, SO_BROADCAST,
+		      (char *) &enable, sizeof (int)))
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("setsockopt(SO_BROADCAST) failed"));
+	  lw6net_last_error ();
+	}
+
 #ifdef LW6_MS_WINDOWS
       err = ioctlsocket (sock, FIONBIO, &enable_ul);
 #else
@@ -72,6 +83,8 @@ lw6net_udp_server (char *ip, int port)
 {
   int sock = -1;
   int err = 0;
+  int enable = 1;
+
 #ifdef LW6_MS_WINDOWS
   unsigned long enable_ul = 1;
 #endif
@@ -79,6 +92,14 @@ lw6net_udp_server (char *ip, int port)
   sock = _lw6net_socket_bind (ip, port, SOCK_DGRAM);
   if (sock >= 0)
     {
+      if (setsockopt (sock, SOL_SOCKET, SO_BROADCAST,
+		      (char *) &enable, sizeof (int)))
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("setsockopt(SO_BROADCAST) failed"));
+	  lw6net_last_error ();
+	}
+
 #ifdef LW6_MS_WINDOWS
       err = ioctlsocket (sock, FIONBIO, &enable_ul);
 #else
@@ -104,11 +125,7 @@ lw6net_udp_send (int sock, char *buf, int len, char *ip, int port)
   int res;
 
   name.sin_family = AF_INET;
-#ifdef LW6_MS_WINDOWS
-  if ((name.sin_addr.s_addr = inet_addr (ip)) != 0)
-#else
-  if (inet_aton (ip, &name.sin_addr) != 0)
-#endif
+  if (_lw6net_inet_aton (&name.sin_addr, ip))
     {
       name.sin_port = htons (port);
       res =
@@ -119,15 +136,12 @@ lw6net_udp_send (int sock, char *buf, int len, char *ip, int port)
 	  lw6sys_log (LW6SYS_LOG_DEBUG, _("%d bytes sent on UDP socket %d"),
 		      send_size, sock);
 	}
-    }
-  else
-    {
-#ifdef LW6_MS_WINDOWS
-      lw6sys_log (LW6SYS_LOG_WARNING, _("inet_addr() failed, ip=\"%s\""), ip);
-#else
-      lw6sys_log (LW6SYS_LOG_WARNING, _("inet_aton() failed, ip=\"%s\""), ip);
-#endif
-      lw6net_last_error ();
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
+		      _("unable to send %d bytes on UDP socket %d"), len,
+		      sock);
+	}
     }
 
   return send_size;
