@@ -27,12 +27,23 @@
 #include "../cfg/cfg.h"
 
 #define LW6NET_ADDRESS_ANY "0.0.0.0"
+#define LW6NET_ADDRESS_BROADCAST "255.255.255.255"
 #define LW6NET_ADDRESS_LOOPBACK "127.0.0.1"
 #define LW6NET_DEFAULT_PORT 8056
+#define LW6NET_HTTP_PORT 80
+#define LW6NET_MAX_PACKET_SIZE 2000
 
 // net-error.c
 extern int lw6net_last_error ();
 
+/* net-dns.c */
+extern int lw6net_dns_is_ip (char *ip);
+extern char *lw6net_dns_gethostbyname (char *name);
+
+/* net-if.c */
+extern char *lw6net_if_guess_local ();
+extern char *lw6net_if_guess_public_url (char *bind_ip, int bind_port);
+
 /*
  * In line.c
  */
@@ -40,6 +51,9 @@ extern char *lw6net_recv_line_tcp (int sock);
 extern int lw6net_send_line_tcp (int sock, char *line);
 extern char *lw6net_recv_line_udp (int sock,
 				   char **incoming_ip, int *incoming_port);
+extern lw6sys_list_t *lw6net_recv_lines_udp (int sock,
+					     char **incoming_ip,
+					     int *incoming_port);
 extern int lw6net_send_line_udp (int sock, char *line, char *ip, int port);
 
 /*
