@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ typedef struct _lw6pil_spread_data_s
 } _lw6pil_spread_data_t;
 
 /* pil-bench.c */
-extern void _lw6pil_bench_dummy_nop (float *dummy);
+extern void _lw6pil_bench_dummy_nop (int64_t * dummy);
 
 /* pil-command.c */
 extern int _lw6pil_command_sort_callback (lw6sys_list_t ** list_a,
