@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 #include "mod-ogg.h"
 #include "mod-ogg-internal.h"
 
-
 static int
 _play_sound (void *snd_context, int sound_id)
 {
@@ -45,7 +44,7 @@ _play_sound (void *snd_context, int sound_id)
 }
 
 static int
-_play_music (void *snd_context, char *music_name)
+_is_music_file (void *snd_context, char *music_file)
 {
   int ret = 0;
 
@@ -53,12 +52,56 @@ _play_music (void *snd_context, char *music_name)
 
   if (mod_ogg_context)
     {
-      ret = _mod_ogg_play_music (mod_ogg_context, music_name);
+      ret = _mod_ogg_is_music_file (mod_ogg_context, music_file);
     }
 
   return ret;
 }
 
+static int
+_play_music_file (void *snd_context, char *music_file)
+{
+  int ret = 0;
+
+  _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
+
+  if (mod_ogg_context)
+    {
+      ret = _mod_ogg_play_music_file (mod_ogg_context, music_file);
+    }
+
+  return ret;
+}
+
+static int
+_play_music_random (void *snd_context, char *music_path, char *music_filter,
+		    char *music_exclude)
+{
+  int ret = 0;
+
+  _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
+
+  if (mod_ogg_context)
+    {
+      ret =
+	_mod_ogg_play_music_random (mod_ogg_context, music_path,
+				    music_filter, music_exclude);
+    }
+
+  return ret;
+}
+
+static void
+_stop_music (void *snd_context)
+{
+  _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
+
+  if (mod_ogg_context)
+    {
+      _mod_ogg_stop_music (mod_ogg_context);
+    }
+}
+
 static void *
 _init (int argc, char *argv[], float sound_volume, float music_volume)
 {
@@ -153,7 +196,10 @@ mod_ogg_create_backend ()
       memset (backend, 0, sizeof (lw6snd_backend_t));
 
       backend->play_sound = _play_sound;
-      backend->play_music = _play_music;
+      backend->is_music_file = _is_music_file;
+      backend->play_music_file = _play_music_file;
+      backend->play_music_random = _play_music_random;
+      backend->stop_music = _stop_music;
       backend->init = _init;
       backend->set_sound_volume = _set_sound_volume;
       backend->set_music_volume = _set_music_volume;
