@@ -28,19 +28,45 @@
 #include "mod-tcpd-internal.h"
 
 int
-_mod_tcpd_can_handle_tcp (_tcpd_context_t * tcpd_context,
-			  lw6srv_tcp_accepter_t * tcp_accepter)
+_mod_tcpd_analyse_tcp (_tcpd_context_t * tcpd_context,
+		       lw6srv_tcp_accepter_t * tcp_accepter)
 {
   int ret = 0;
 
-  // todo
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("trying to recognize tcpd protocol"));
+
+  if (!lw6net_tcp_is_alive (tcp_accepter->sock))
+    {
+      ret |= LW6SRV_ANALYSE_DEAD;
+      lw6net_socket_close (tcp_accepter->sock);
+      tcp_accepter->sock = -1;
+    }
+
+  if (!strncmp
+      (tcp_accepter->first_line, _MOD_TCPD_PROTOCOL_LW6_STRING,
+       _MOD_TCPD_PROTOCOL_LW6_SIZE))
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("recognized tcpd protocol"));
+      ret |= LW6SRV_ANALYSE_UNDERSTANDABLE;
+    }
+  if (lw6sys_chr_is_eol (tcp_accepter->first_line[0])
+      || lw6sys_str_starts_with_no_case (tcp_accepter->first_line,
+					 LW6MSG_OOB_PING)
+      || lw6sys_str_starts_with_no_case (tcp_accepter->first_line,
+					 LW6MSG_OOB_INFO)
+      || lw6sys_str_starts_with_no_case (tcp_accepter->first_line,
+					 LW6MSG_OOB_LIST))
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("recognized tcpd protocol (OOB)"));
+      ret |= (LW6SRV_ANALYSE_UNDERSTANDABLE | LW6SRV_ANALYSE_OOB);
+    }
 
   return ret;
 }
 
 int
-_mod_tcpd_can_handle_udp (_tcpd_context_t * tcpd_context,
-			  lw6srv_udp_buffer_t * udp_buffer)
+_mod_tcpd_analyse_udp (_tcpd_context_t * tcpd_context,
+		       lw6srv_udp_buffer_t * udp_buffer)
 {
   int ret = 0;
 
