@@ -28,25 +28,33 @@
 #include "mod-udpd-internal.h"
 
 int
-_mod_udpd_can_handle_tcp (_udpd_context_t * udpd_context,
-			  lw6srv_tcp_accepter_t * tcp_accepter)
+_mod_udpd_analyse_tcp (_udpd_context_t * udpd_context,
+		       lw6srv_tcp_accepter_t * tcp_accepter)
 {
   int ret = 0;
 
   /*
-   * TCP is never handled by mod_tcpd, return always false
+   * TCP is never handled by mod_udpd.
    */
 
   return ret;
 }
 
 int
-_mod_udpd_can_handle_udp (_udpd_context_t * udpd_context,
-			  lw6srv_udp_buffer_t * udp_buffer)
+_mod_udpd_analyse_udp (_udpd_context_t * udpd_context,
+		       lw6srv_udp_buffer_t * udp_buffer)
 {
   int ret = 0;
 
-  // todo
+  if (lw6sys_str_starts_with_no_case (udp_buffer->line,
+				      LW6MSG_OOB_PING)
+      || lw6sys_str_starts_with_no_case (udp_buffer->line,
+					 LW6MSG_OOB_INFO)
+      || lw6sys_str_starts_with_no_case (udp_buffer->line, LW6MSG_OOB_LIST))
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("recognized tcpd protocol (OOB)"));
+      ret |= (LW6SRV_ANALYSE_UNDERSTANDABLE | LW6SRV_ANALYSE_OOB);
+    }
 
   return ret;
 }
