@@ -28,27 +28,45 @@
 #include "mod-udpd-internal.h"
 
 _udpd_context_t *
-_mod_udpd_init ()
+_mod_udpd_init (int argc, char *argv[], lw6srv_listener_t * listener)
 {
-  _udpd_context_t *srv_context = NULL;
-
-  srv_context = (_udpd_context_t *) LW6SYS_CALLOC (sizeof (_udpd_context_t));
-  if (!srv_context)
-    {
-      /*
-       * No use to continue if this basic malloc fails...
-       */
-      exit (1);
-    }
+  _udpd_context_t *udpd_context = NULL;
+  char *data_dir = NULL;
+  int ok = 0;
 
   lw6sys_log (LW6SYS_LOG_INFO, _("udpd init"));
 
-  return srv_context;
+  udpd_context = (_udpd_context_t *) LW6SYS_CALLOC (sizeof (_udpd_context_t));
+  if (udpd_context)
+    {
+      data_dir = lw6sys_get_data_dir (argc, argv);
+      if (data_dir)
+	{
+	  if (_mod_udpd_load_data (&(udpd_context->data), data_dir))
+	    {
+	      ok = 1;
+	    }
+	  LW6SYS_FREE (data_dir);
+	}
+      if (!ok)
+	{
+	  _mod_udpd_quit (udpd_context);
+	  udpd_context = NULL;
+	}
+    }
+
+  if (!udpd_context)
+    {
+      lw6sys_log (LW6SYS_LOG_ERROR, _("can't initialize mod_udpd"));
+    }
+
+  return udpd_context;
 }
 
 void
-_mod_udpd_quit (_udpd_context_t * srv_context)
+_mod_udpd_quit (_udpd_context_t * udpd_context)
 {
   lw6sys_log (LW6SYS_LOG_INFO, _("udpd quit"));
-  LW6SYS_FREE (srv_context);
+  _mod_udpd_unload_data (&(udpd_context->data));
+  LW6SYS_FREE (udpd_context);
 }
