@@ -44,3 +44,18 @@ _mod_udpd_is_alive (_udpd_context_t * udpd_context,
 
   return ret;
 }
+
+int
+_mod_udpd_timeout_ok (_udpd_context_t * udpd_context,
+		      int64_t origin_timestamp)
+{
+  int ret = 0;
+  int d = 0;
+
+  d =
+    origin_timestamp + (udpd_context->data.consts.error_timeout * 1000) -
+    lw6sys_get_timestamp ();
+  ret = (d > 0);
+
+  return ret;
+}
