@@ -31,9 +31,48 @@
 
 #define TEST_NB_BACKENDS 3
 
+#define _NODE_INFO_ID 0x1234123412341234LL
+#define _NODE_INFO_URL "http://localhost/"
+#define _NODE_INFO_TITLE "test node"
+#define _NODE_INFO_DESCRIPTION "this is a test node"
+#define _NODE_INFO_BENCH 10
+#define _NODE_INFO_IDLE_SCREENSHOT_SIZE 4
+#define _NODE_INFO_IDLE_SCREENSHOT_DATA "test"
+
 #define _TEST_FAKE_SOCK 7
 #define _TEST_LINE "foo bar BARfoo bar.bar"
 
+#define _TEST_OOB_REMOTE_IP "1.2.3.4"
+#define _TEST_OOB_REMOTE_PORT 6789
+#define _TEST_OOB_INVALID_SOCK -1
+
+static int
+_test_oob ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6srv_oob_t *oob;
+
+    oob =
+      lw6srv_oob_new (_TEST_OOB_REMOTE_IP, _TEST_OOB_REMOTE_PORT,
+		      _TEST_OOB_INVALID_SOCK, _TEST_LINE);
+    if (oob)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("created oob object"));
+	lw6srv_oob_free (oob);
+      }
+    else
+      {
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 _test_tcp_accepter ()
 {
@@ -178,11 +217,14 @@ lw6srv_test (int mode)
        * Just to make sure most functions are stuffed in the binary
        */
       lw6sys_test (mode);
+      lw6glb_test (mode);
       lw6cfg_test (mode);
       lw6net_test (mode);
+      lw6nod_test (mode);
+      lw6msg_test (mode);
     }
 
-  ret = _test_tcp_accepter () && _test_udp_buffer ();
+  ret = _test_oob () && _test_tcp_accepter () && _test_udp_buffer ();
 
   if (ret)
     {
