@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,10 +43,14 @@
 static int bazooka_size = 0;
 static _lw6sys_bazooka_t *bazooka_data = NULL;
 static void *bazooka_spinlock = NULL;
-static int bazooka_malloc_counter = 0;
-static int bazooka_free_counter = 0;
-static int bazooka_malloc_total = 0;
-static int bazooka_malloc_max = 0;
+static int bazooka_malloc_count = 0;
+static int bazooka_free_count = 0;
+static int bazooka_malloc_current_count = 0;
+static int bazooka_malloc_max_count = 0;
+static int64_t bazooka_malloc_bytes = 0;
+static int64_t bazooka_free_bytes = 0;
+static int bazooka_malloc_current_bytes = 0;
+static int bazooka_malloc_max_bytes = 0;
 static int bazooka_eraser = 1;
 static int bazooka_trustable = 1;
 
@@ -136,9 +140,14 @@ bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
 
 #ifndef LW6_OPTIMIZE
   bazooka_lock ();
-  bazooka_malloc_counter++;
-  bazooka_malloc_total++;
-  bazooka_malloc_max = lw6sys_max (bazooka_malloc_max, bazooka_malloc_total);
+  bazooka_malloc_count++;
+  bazooka_malloc_current_count++;
+  bazooka_malloc_max_count =
+    lw6sys_max (bazooka_malloc_max_count, bazooka_malloc_current_count);
+  bazooka_malloc_bytes += size;
+  bazooka_malloc_current_bytes += size;
+  bazooka_malloc_max_bytes =
+    lw6sys_max (bazooka_malloc_max_bytes, bazooka_malloc_current_bytes);
   if (bazooka_data)
     {
       int i;
@@ -168,7 +177,7 @@ bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
 	      strncpy (bazooka_data[i].file, file_only,
 		       _LW6SYS_BAZOOKA_FILE_SIZE - 1);
 	      bazooka_data[i].line = line;
-	      bazooka_data[i].timestamp = lw6sys_timestamp ();
+	      bazooka_data[i].timestamp = lw6sys_get_timestamp ();
 	      break;		// important to leave loop, else serious perfomance problem
 	    }
 	}
@@ -467,6 +476,11 @@ _lw6sys_bazooka_register_realloc_1 (char *ptr, int size, char *file, int line)
 	{
 	  if (bazooka_data[i].ptr == ptr)
 	    {
+	      bazooka_malloc_bytes += size - bazooka_data[i].size;
+	      bazooka_malloc_current_bytes += size - bazooka_data[i].size;
+	      bazooka_malloc_max_bytes =
+		lw6sys_max (bazooka_malloc_max_bytes,
+			    bazooka_malloc_current_bytes);
 	      if (bazooka_eraser && bazooka_data[i].size > size)
 		{
 		  memset (bazooka_data[i].ptr + size,
@@ -527,7 +541,7 @@ _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2, int size,
 		  strncpy (bazooka_data[i].file, file_only,
 			   _LW6SYS_BAZOOKA_FILE_SIZE - 1);
 		  bazooka_data[i].line = line;
-		  bazooka_data[i].timestamp = lw6sys_timestamp ();
+		  bazooka_data[i].timestamp = lw6sys_get_timestamp ();
 		}
 	      break;		// important to leave loop, else serious perfomance problem           
 	    }
@@ -563,7 +577,7 @@ _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2, int size,
 		  strncpy (bazooka_data[i].file, file_only,
 			   _LW6SYS_BAZOOKA_FILE_SIZE - 1);
 		  bazooka_data[i].line = line;
-		  bazooka_data[i].timestamp = lw6sys_timestamp ();
+		  bazooka_data[i].timestamp = lw6sys_get_timestamp ();
 		  break;	// important to leave loop, else serious perfomance problem
 		}
 	    }
@@ -588,12 +602,12 @@ _lw6sys_bazooka_register_free (char *ptr)
   int i;
 
   bazooka_lock ();
-  bazooka_free_counter++;
-  bazooka_malloc_total--;
-  if (bazooka_free_counter > bazooka_malloc_counter)
+  bazooka_free_count++;
+  bazooka_malloc_current_count--;
+  if (bazooka_free_count > bazooka_malloc_count)
     {
       lw6sys_log_critical (_("problem, more free (%d) than malloc (%d)"),
-			   bazooka_free_counter, bazooka_malloc_counter);
+			   bazooka_free_count, bazooka_malloc_count);
     }
 
 #ifdef LW6_PARANOID
@@ -622,6 +636,15 @@ _lw6sys_bazooka_register_free (char *ptr)
 	{
 	  if (bazooka_data[i].ptr == ptr)
 	    {
+	      bazooka_free_bytes += bazooka_data[i].size;
+	      bazooka_malloc_current_bytes -= bazooka_data[i].size;
+	      if (bazooka_free_bytes > bazooka_malloc_bytes)
+		{
+		  lw6sys_log_critical (_
+				       ("problem, more bytes freed (%d) than malloced (%d)"),
+				       bazooka_free_bytes,
+				       bazooka_malloc_bytes);
+		}
 	      if (bazooka_eraser)
 		{
 		  memset (bazooka_data[i].ptr, BAZOOKA_ERASER_FREE,
@@ -659,7 +682,7 @@ lw6sys_get_memory_bazooka_malloc_count ()
   int ret = 0;
 
 #ifndef LW6_OPTIMIZE
-  ret = bazooka_malloc_counter;
+  ret = bazooka_malloc_count;
 #endif
 
   return ret;
@@ -680,14 +703,37 @@ lw6sys_get_memory_bazooka_free_count ()
   int ret = 0;
 
 #ifndef LW6_OPTIMIZE
-  return bazooka_free_counter;
+  return bazooka_free_count;
 #endif
 
   return ret;
 }
 
 /**
- * lw6sys_get_memory_bazooka_malloc_max
+ * lw6sys_get_memory_bazooka_malloc_current_count
+ *
+ * Provided you have always called the @LW6SYS_MALLOC an @LW6SYS_CALLOC to 
+ * allocate memory, this function will tell you the current number of
+ * pointer returned by @LW6SYS_MALLOC an @LW6SYS_CALLOC, currently
+ * alive on the heap.
+ *
+ * Return value: the number of calls to @lw6sys_malloc or @lw6sys_calloc since
+ *   program was started.
+ */
+int
+lw6sys_get_memory_bazooka_malloc_current_count ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = bazooka_malloc_current_count;
+#endif
+
+  return ret;
+}
+
+/**
+ * lw6sys_get_memory_bazooka_malloc_max_count
  *
  * Provided you have always called the @LW6SYS_MALLOC an @LW6SYS_CALLOC to 
  * allocate memory, this function will tell you the maximum of pointers
@@ -697,12 +743,100 @@ lw6sys_get_memory_bazooka_free_count ()
  *   program was started.
  */
 int
-lw6sys_get_memory_bazooka_malloc_max ()
+lw6sys_get_memory_bazooka_malloc_max_count ()
 {
   int ret = 0;
 
 #ifndef LW6_OPTIMIZE
-  ret = bazooka_malloc_max;
+  ret = bazooka_malloc_max_count;
+#endif
+
+  return ret;
+}
+
+/**
+ * lw6sys_get_memory_bazooka_malloc_megabytes
+ *
+ * Provided you have always called the @LW6SYS_MALLOC an @LW6SYS_CALLOC to 
+ * allocate memory, this function will tell you how many bytes @malloc 
+ * has reserved.
+ *
+ * Return value: the number of calls to @lw6sys_malloc or @lw6sys_calloc since
+ *   program was started.
+ */
+int
+lw6sys_get_memory_bazooka_malloc_megabytes ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = (int64_t) (bazooka_malloc_bytes / 0x100000L);
+#endif
+
+  return ret;
+}
+
+/**
+ * lw6sys_get_memory_bazooka_free_megabytes
+ *
+ * Provided you have always called the @LW6SYS_FREE macro to free
+ * memory, this function will tell you how many bytes @free has freed.
+ *
+ * Return value: the number of calls to @lw6sys_free since
+ *   program was started.
+ */
+int
+lw6sys_get_memory_bazooka_free_megabytes ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = (int64_t) (bazooka_free_bytes / 0x100000L);
+#endif
+
+  return ret;
+}
+
+/**
+ * lw6sys_get_memory_bazooka_malloc_current_bytes
+ *
+ * Provided you have always called the @LW6SYS_MALLOC an @LW6SYS_CALLOC to 
+ * allocate memory, this function will tell you the current number of
+ * bytes returned by @LW6SYS_MALLOC an @LW6SYS_CALLOC, currently
+ * alive on the heap.
+ *
+ * Return value: the number of calls to @lw6sys_malloc or @lw6sys_calloc since
+ *   program was started.
+ */
+int
+lw6sys_get_memory_bazooka_malloc_current_bytes ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = bazooka_malloc_current_bytes;
+#endif
+
+  return ret;
+}
+
+/**
+ * lw6sys_get_memory_bazooka_malloc_max_bytes
+ *
+ * Provided you have always called the @LW6SYS_MALLOC an @LW6SYS_CALLOC to 
+ * allocate memory, this function will tell you the maximum bytes
+ * returned by @malloc that were present at the same time on the heap.
+ *
+ * Return value: the number of calls to @lw6sys_malloc or @lw6sys_calloc since
+ *   program was started.
+ */
+int
+lw6sys_get_memory_bazooka_malloc_max_bytes ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = bazooka_malloc_max_bytes;
 #endif
 
   return ret;
@@ -752,9 +886,15 @@ lw6sys_memory_bazooka_report ()
 #else
   int recreate_spinlock = 0;
   int i;
-  int malloc_counter;
-  int free_counter;
-  int malloc_max;
+  int malloc_count;
+  int free_count;
+  int malloc_current_count;
+  int malloc_max_count;
+  int malloc_megabytes;
+  int free_megabytes;
+  int malloc_current_bytes;
+  int malloc_max_bytes;
+  int malloc_max_megabytes;
 
   if (bazooka_spinlock)
     {
@@ -762,25 +902,44 @@ lw6sys_memory_bazooka_report ()
       recreate_spinlock = 1;
     }
 
-  malloc_counter = lw6sys_get_memory_bazooka_malloc_count ();
-  free_counter = lw6sys_get_memory_bazooka_free_count ();
-  malloc_max = lw6sys_get_memory_bazooka_malloc_max ();
+  malloc_count = lw6sys_get_memory_bazooka_malloc_count ();
+  free_count = lw6sys_get_memory_bazooka_free_count ();
+  malloc_current_count = lw6sys_get_memory_bazooka_malloc_current_count ();
+  malloc_max_count = lw6sys_get_memory_bazooka_malloc_max_count ();
+  malloc_megabytes = lw6sys_get_memory_bazooka_malloc_megabytes ();
+  free_megabytes = lw6sys_get_memory_bazooka_free_megabytes ();
+  malloc_current_bytes = lw6sys_get_memory_bazooka_malloc_current_bytes ();
+  malloc_max_bytes = lw6sys_get_memory_bazooka_malloc_max_bytes ();
+  malloc_max_megabytes = (malloc_max_bytes >> 20) + 1;
 
-  if (malloc_counter == free_counter)
+  lw6sys_log (LW6SYS_LOG_INFO, _("malloc_count=%d"), malloc_count);
+  lw6sys_log (LW6SYS_LOG_INFO, _("free_count=%d"), free_count);
+  lw6sys_log (LW6SYS_LOG_INFO, _("malloc_current_count=%d"),
+	      malloc_current_count);
+  lw6sys_log (LW6SYS_LOG_INFO, _("malloc_max_count=%d"), malloc_max_count);
+  lw6sys_log (LW6SYS_LOG_INFO, _("malloc_megabytes=%d"), malloc_megabytes);
+  lw6sys_log (LW6SYS_LOG_INFO, _("free_megabytest=%d"), free_megabytes);
+  lw6sys_log (LW6SYS_LOG_INFO, _("malloc_current_bytes=%d"),
+	      malloc_current_bytes);
+  lw6sys_log (LW6SYS_LOG_INFO, _("malloc_max_bytes=%d"), malloc_max_bytes);
+
+  if (malloc_count == free_count)
     {
       if (bazooka_data)
 	{
 	  if (bazooka_trustable)
 	    {
-	      lw6sys_log (LW6SYS_LOG_NOTICE, _("%d malloc calls"),
-			  malloc_counter);
-	      lw6sys_log (LW6SYS_LOG_INFO, _("malloc_max=%d bazooka_size=%d"),
-			  bazooka_malloc_max, bazooka_size);
+	      lw6sys_log (LW6SYS_LOG_NOTICE,
+			  _
+			  ("%d malloc calls, %d megabytes system heap"),
+			  malloc_count, malloc_max_megabytes);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_NOTICE, _("%d malloc calls (untrusted)"),
-			  malloc_counter);
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _
+			  ("%d malloc calls, %d megabytes system heap (untrusted)"),
+			  malloc_count, malloc_max_megabytes);
 	    }
 	}
     }
@@ -790,7 +949,7 @@ lw6sys_memory_bazooka_report ()
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("possible memory leak, %d calls to malloc and %d calls to free, note that if the program exited abnormally because of an unexpected error, this difference might be \"normal\""),
-		  malloc_counter, free_counter);
+		  malloc_count, free_count);
     }
 
   if (bazooka_data)
