@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -546,6 +546,26 @@ lw6sys_color_hsv_to_rgb (lw6sys_color_hsv_t * color_hsv)
   return color_8;
 }
 
+/*
+ * lw6sys_color_is_grey
+ * 
+ * @color: the color to test
+ *
+ * Tells wether a color is pure grey or not. This is interesting
+ * for such colors have no hue and sometimes need special handling.
+ *
+ * Return value: 1 if grey, 0 if colored
+ */
+int
+lw6sys_color_is_grey (lw6sys_color_8_t color)
+{
+  int ret;
+
+  ret = (color.r == color.g) && (color.g == color.b);
+
+  return ret;
+}
+
 /**
  * lw6sys_color_average
  *
@@ -619,6 +639,7 @@ lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
   lw6sys_color_hsv_t color1_hsv;
   lw6sys_color_hsv_t color2_hsv;
   lw6sys_color_hsv_t ret_hsv = LW6SYS_COLOR_HSV_BLACK;
+  float one_minus_coeff;
 
   if (coeff <= 0.0f)
     {
@@ -630,21 +651,32 @@ lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
     }
   else
     {
-      lw6sys_color_rgb_to_hsv (&color1_hsv, color1);
-      lw6sys_color_rgb_to_hsv (&color2_hsv, color2);
-      if (color2_hsv.h - color1_hsv.h < 180.0f)
+      one_minus_coeff = 1.0f - coeff;
+      if (lw6sys_color_is_grey (color1) || lw6sys_color_is_grey (color2))
 	{
-	  color2_hsv.h += 360.0f;
+	  ret.r = one_minus_coeff * color1.r + coeff * color2.r;
+	  ret.g = one_minus_coeff * color1.g + coeff * color2.g;
+	  ret.b = one_minus_coeff * color1.b + coeff * color2.b;
+	  ret.a = one_minus_coeff * color1.a + coeff * color2.a;
 	}
-      if (color2_hsv.h - color1_hsv.h > 180.0f)
+      else
 	{
-	  color1_hsv.h += 360.0f;
+	  lw6sys_color_rgb_to_hsv (&color1_hsv, color1);
+	  lw6sys_color_rgb_to_hsv (&color2_hsv, color2);
+	  if (color2_hsv.h - color1_hsv.h < 180.0f)
+	    {
+	      color2_hsv.h += 360.0f;
+	    }
+	  if (color2_hsv.h - color1_hsv.h > 180.0f)
+	    {
+	      color1_hsv.h += 360.0f;
+	    }
+	  ret_hsv.h = one_minus_coeff * color1_hsv.h + coeff * color2_hsv.h;
+	  ret_hsv.s = one_minus_coeff * color1_hsv.s + coeff * color2_hsv.s;
+	  ret_hsv.v = one_minus_coeff * color1_hsv.v + coeff * color2_hsv.v;
+	  ret_hsv.a = one_minus_coeff * color1_hsv.a + coeff * color2_hsv.a;
+	  ret = lw6sys_color_hsv_to_rgb (&ret_hsv);
 	}
-      ret_hsv.h = (1.0f - coeff) * color1_hsv.h + coeff * color2_hsv.h;
-      ret_hsv.s = (1.0f - coeff) * color1_hsv.s + coeff * color2_hsv.s;
-      ret_hsv.v = (1.0f - coeff) * color1_hsv.v + coeff * color2_hsv.v;
-      ret_hsv.a = (1.0f - coeff) * color1_hsv.a + coeff * color2_hsv.a;
-      ret = lw6sys_color_hsv_to_rgb (&ret_hsv);
     }
 
   return ret;
