@@ -843,3 +843,112 @@ lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
 
   return ret;
 }
+
+static int
+_hexa_str_to_buf (void *buf, int size, char *str)
+{
+  char *buffer = (char *) buf;
+  int ret = 0;
+  int i = 0, j = 0;
+  char hexa2[3] = { 0, 0, 0 };	// third 0 is *very* important
+
+  if (strlen (str) == 2 * size)
+    {
+      for (i = 0; i < size; ++i)
+	{
+	  memcpy (hexa2, str + 2 * i, 2);
+	  sscanf (hexa2, "%02x", &j);
+	  buffer[i] = (u_int8_t) j;
+	  TMP3 ("s2b %s %d %d", hexa2, j, (int) buffer[i]);
+	}
+      str[2 * size] = '\0';
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _
+		  ("incorrect string (bad size) \"%s\" expected %d but got %d"),
+		  str, 2 * size, strlen (str));
+    }
+
+  return ret;
+}
+
+static char *
+_hexa_buf_to_str (void *buf, int size)
+{
+  char *buffer = (char *) buf;
+  char *str = NULL;
+  int i = 0;
+  u_int8_t c = 0;
+
+  str = (char *) LW6SYS_MALLOC (2 * size + 1);
+  if (str)
+    {
+      for (i = 0; i < size; ++i)
+	{
+	  c = buffer[i];
+	  snprintf (str + 2 * i, 3, "%02x", (u_int32_t) c);
+	}
+      str[2 * size] = '\0';
+    }
+
+  return str;
+}
+
+/**
+ * lw6sys_hexa_str_to_ptr
+ *
+ * @str: the string containing an hexa representation of pointer
+ *
+ * Transforms a string into a pointer, this is typically used
+ * to store pointers in temporary agnostic storage such as
+ * a database. Beware not to use that to exchange data with
+ * other computers and/or use it for persistent data. This
+ * is a high-risk function as it lets you do real dirty stuff
+ * but it really does save time compared to using a key returned
+ * by the database engine and then search this key in a user-space
+ * hash table. Direct pointer access is definitely faster.
+ *
+ * Return value: the pointer, or NULL is str is invalid.
+ */
+void *
+lw6sys_hexa_str_to_ptr (char *str)
+{
+  void *ptr = NULL;
+
+  if (!_hexa_str_to_buf (&ptr, sizeof (void *), str))
+    {
+      ptr = NULL;
+    }
+
+  return ptr;
+}
+
+/**
+ * lw6sys_hexa_ptr_to_str
+ *
+ * @ptr: pointer to convert into string representation
+ *
+ * Transforms a pointer into a string, this is typically used
+ * to store pointers in temporary agnostic storage such as
+ * a database. Beware not to use that to exchange data with
+ * other computers and/or use it for persistent data. This
+ * is a high-risk function as it lets you do real dirty stuff
+ * but it really does save time compared to using a key returned
+ * by the database engine and then search this key in a user-space
+ * hash table. Direct pointer access is definitely faster.
+ *
+ * Return value: the string, can be NULL on errror, must be freed.
+ */
+char *
+lw6sys_hexa_ptr_to_str (void *ptr)
+{
+  char *str = NULL;
+
+  TMP2 ("p2s ptr=%p &ptr=%p", ptr, &ptr);
+  str = _hexa_buf_to_str (&ptr, sizeof (void *));
+
+  return str;
+}
