@@ -124,5 +124,8 @@ extern int _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2,
 					       int line);
 extern int _lw6sys_bazooka_register_free (char *ptr);
 extern char *_lw6sys_new_vsnprintf (int n, char *fmt, va_list ap);
+#ifdef LW6_MAC_OS_X
+extern void _lw6sys_macosx_alert (char *title, char *msg);
+#endif
 
 #endif
