@@ -34,11 +34,18 @@
 #include <sys/time.h>
 #include <errno.h>
 
+#ifdef LW6_GTK
+#include <gtk/gtk.h>
+#endif
+
 #define HISTORY_LENGTH 256
 
 #define MSGBOX_LENGTH 4096
 #define MSGBOX_WIDTH 128
 
+#define CRITICAL_FILE "sys-log.c"
+#define CRITICAL_LINE __LINE__
+
 #define STATIC_LOG_FILENAME_SIZE 65536
 static char static_log_filename[STATIC_LOG_FILENAME_SIZE + 1] = { 0 };
 
@@ -547,22 +554,11 @@ static void
 log_to_file (FILE * f, int level_id, char *level_str, char *file, int line,
 	     char *fmt, va_list ap)
 {
-  char *file_only = NULL;
   time_t t_now;
   struct tm tm_now;
   struct tm *tm_ret = NULL;
   struct timeval timeval_now;
 
-  file_only = strrchr (file, '/');
-  if (file_only && *file_only)
-    {
-      file_only++;
-    }
-  else
-    {
-      file_only = file;
-    }
-
   memset (&t_now, 0, sizeof (time_t));
   memset (&tm_now, 0, sizeof (struct tm));
   memset (&timeval_now, 0, sizeof (struct timeval));
@@ -577,7 +573,7 @@ log_to_file (FILE * f, int level_id, char *level_str, char *file, int line,
 	       (int) tm_now.tm_min, (int) tm_now.tm_sec,
 	       (int) timeval_now.tv_usec / (int) (1000000 /
 						  LW6SYS_TICKS_PER_SEC),
-	       file_only, line, level_id, level_str);
+	       file, line, level_id, level_str);
     }
   vfprintf (f, fmt, ap);
   fprintf (f, "\n");
@@ -612,33 +608,45 @@ log_to_history (char *level_str, char *fmt, va_list ap)
 }
 
 static void
-msgbox_alert (char *fmt, va_list ap)
+msgbox_alert (char *level_str, char *file, int line, char *fmt, va_list ap)
 {
-#ifdef LW6_MS_WINDOWS
-  {
-    char *message_raw = NULL;
-    char *message_formatted = NULL;
+  char *message_raw = NULL;
+  char *message_formatted = NULL;
+  char *message_full = NULL;
 
-    message_raw = _lw6sys_new_vsnprintf (MSGBOX_LENGTH, fmt, ap);
-    if (!message_raw)
-      {
-	message_raw = lw6sys_str_copy (_("Error (message too long...)"));
-      }
-    if (message_raw)
-      {
-	message_formatted =
-	  lw6sys_str_reformat (message_raw, "", MSGBOX_WIDTH);
-	if (message_formatted)
-	  {
-	    MessageBox (NULL,
-			message_formatted,
-			lw6sys_build_get_package_name (),
-			MB_OK | MB_ICONERROR | MB_APPLMODAL);
-	    LW6SYS_FREE (message_formatted);
-	  }
-	LW6SYS_FREE (message_raw);
-      }
-  }
+  message_raw = _lw6sys_new_vsnprintf (MSGBOX_LENGTH, fmt, ap);
+  if (!message_raw)
+    {
+      message_raw = lw6sys_str_copy (_("See log file for details."));
+    }
+  if (message_raw)
+    {
+      message_formatted = lw6sys_str_reformat (message_raw, "", MSGBOX_WIDTH);
+    }
+  if (message_formatted)
+    {
+      message_full =
+	lw6sys_new_sprintf ("%s (%s:%d)\n\n%s", level_str, file, line,
+			    message_formatted);
+    }
+  else
+    {
+      message_full = lw6sys_str_copy ("?");
+    }
+#ifdef LW6_MS_WINDOWS
+  if (message_full)
+    {
+      MessageBox (NULL,
+		  message_full,
+		  lw6sys_build_get_package_name (),
+		  MB_OK | MB_ICONERROR | MB_APPLMODAL);
+    }
+#else
+#ifdef LW6_MAC_OS_X
+  if (message_full)
+    {
+      _lw6sys_macosx_alert (lw6sys_build_get_package_name (), message_full);
+    }
 #else
 /*
  * Not implemented yet, below sample code, which would require to
@@ -646,23 +654,70 @@ msgbox_alert (char *fmt, va_list ap)
  * CFLAGS=`pkg-config --cflags gtk+-2.0`
  * LDFLAGS=`pkg-config --libs gtk+-2.0`
  */
-#if 0
-  {
-    GtkWidget *dlg = NULL;
-    gtk_init (&argc, &argv);
-    dlg = gtk_message_dialog_new (NULL,
-				  GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_NONE, "Il y a un bleme");
-    if (dlg)
-      {
-	gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK,
-			       GTK_RESPONSE_OK);
-	gtk_dialog_run (GTK_DIALOG (dlg));
-	gtk_widget_destroy (dlg);
-      }
-  }
+#ifdef LW6_GTK
+  if (message_full)
+    {
+      static int gtk_init_done = 0;
+      int argc = 1;
+      char **argv;
+      GtkWidget *dlg = NULL;
+
+      /*
+       * We fake argc & argv, OK this way GTK won't
+       * be aware of *real* argc & argv values, but
+       * passing them everywhere just for this is a pain.
+       * calloc 2 pointers, last will be NULL, not
+       * sure this is mandatory, but just in case.
+       */
+      argv = (char **) LW6SYS_CALLOC (2 * sizeof (char *));
+      if (argv)
+	{
+	  argv[0] = lw6sys_str_copy ("");
+	  if (argv[0])
+	    {
+	      if (!gtk_init_done)
+		{
+		  gtk_init (&argc, &argv);
+		  gtk_init_done = 1;
+		}
+	      dlg = gtk_message_dialog_new (NULL,
+					    GTK_DIALOG_MODAL,
+					    GTK_MESSAGE_ERROR,
+					    GTK_BUTTONS_NONE, "%s",
+					    message_full);
+	      if (dlg)
+		{
+		  gtk_window_set_title (GTK_WINDOW (dlg),
+					lw6sys_build_get_package_name ());
+		  gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK,
+					 GTK_RESPONSE_OK);
+		  gtk_dialog_run (GTK_DIALOG (dlg));
+		  gtk_widget_hide_all (dlg);
+		  gtk_main_iteration ();
+		  gtk_widget_destroy (dlg);
+		  gtk_main_iteration ();
+		}
+	      LW6SYS_FREE (argv[0]);
+	    }
+	  LW6SYS_FREE (argv);
+	}
+    }
 #endif
 #endif
+#endif
+
+  if (message_raw)
+    {
+      LW6SYS_FREE (message_raw);
+    }
+  if (message_formatted)
+    {
+      LW6SYS_FREE (message_formatted);
+    }
+  if (message_full)
+    {
+      LW6SYS_FREE (message_full);
+    }
 }
 
 /**
@@ -713,9 +768,20 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
       int errno_int;
       va_list ap;
       va_list ap2;
+      char *file_only = NULL;
 
       errno_int = errno;
 
+      file_only = strrchr (file, '/');
+      if (file_only && *file_only)
+	{
+	  file_only++;
+	}
+      else
+	{
+	  file_only = file;
+	}
+
       va_start (ap, fmt);
 
       switch (level_id)
@@ -806,14 +872,14 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 	  if (f)
 	    {
 	      va_copy (ap2, ap);
-	      log_to_file (f, level_id, level_str, file, line, fmt, ap2);
+	      log_to_file (f, level_id, level_str, file_only, line, fmt, ap2);
 	      va_end (ap2);
 	      fclose (f);
 	    }
 	  if (level_id <= LW6SYS_LOG_ERROR_ID)
 	    {
 	      va_copy (ap2, ap);
-	      msgbox_alert (fmt, ap2);
+	      msgbox_alert (level_str, file_only, line, fmt, ap2);
 	      va_end (ap2);
 	    }
 	}
@@ -861,7 +927,7 @@ lw6sys_log_critical (char *fmt, ...)
   va_end (ap2);
 
   va_copy (ap2, ap);
-  msgbox_alert (fmt, ap2);
+  msgbox_alert (_("CRITICAL!"), CRITICAL_FILE, CRITICAL_LINE, fmt, ap2);
   va_end (ap2);
 
   exit (_LW6SYS_EXIT_CRITICAL);
