@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #endif
 
 #include <dirent.h>
+#include <limits.h>
+
 #include <sys/stat.h>
 
 #include "sys.h"
@@ -513,3 +515,290 @@ lw6sys_path_unparent_no_malloc (char *path)
 
   return unparent;
 }
+
+static void
+_dir_list_add_entry (lw6sys_list_t ** list, char *dir, char *item,
+		     lw6sys_dir_list_filter_func_t filter_func,
+		     void *func_data, int *n)
+{
+  int ok = 0;
+  char *path = NULL;
+
+  path = lw6sys_path_concat (dir, item);
+  if (path)
+    {
+      if (filter_func)
+	{
+	  ok = filter_func (func_data, path);
+	}
+      else
+	{
+	  ok = 1;
+	}
+      if (ok)
+	{
+	  lw6sys_list_push_front (list, path);
+	  if (n)
+	    {
+	      (*n)++;
+	    }
+	}
+      else
+	{
+	  LW6SYS_FREE (path);
+	}
+    }
+}
+
+static void
+_dir_list_add_entries (lw6sys_list_t ** list, char *dir,
+		       lw6sys_dir_list_filter_func_t filter_func,
+		       void *func_data, int *n)
+{
+#ifdef LW6_MS_WINDOWS
+  WIN32_FIND_DATA dir_entry;
+  HANDLE dir_handle = INVALID_HANDLE_VALUE;
+  char *dir_wildcard = NULL;
+#else
+  struct dirent *dir_entry = NULL;
+  struct dirent *dir_entry_result = NULL;
+  int dir_entry_size = 0;
+  DIR *dir_handle = NULL;
+#endif
+  int old_n = 0;
+  int eod = 0;
+
+  if (n)
+    {
+      old_n = *n;
+    }
+#ifdef LW6_MS_WINDOWS
+  memset (&dir_entry, 0, sizeof (WIN32_FIND_DATA));
+  if (strlen (dir) + 2 < MAX_PATH)
+    {
+      dir_wildcard = lw6sys_path_concat (dir, "*");
+      if (dir_wildcard)
+	{
+	  dir_handle = FindFirstFile (dir_wildcard, &dir_entry);
+	  LW6SYS_FREE (dir_wildcard);
+	}
+    }
+  if (dir_handle != INVALID_HANDLE_VALUE)
+    {
+      while (!eod)
+	{
+	  _dir_list_add_entry (list, dir,
+			       dir_entry.cFileName, filter_func, func_data,
+			       n);
+	  memset (&dir_entry, 0, sizeof (WIN32_FIND_DATA));
+	  if (!FindNextFile (dir_handle, &dir_entry))
+	    {
+	      eod = 1;
+	    }
+	}
+      FindClose (dir_handle);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, "", _("no files in dir \"%s\""), dir);
+    }
+#else
+  dir_handle = opendir (dir);
+  if (dir_handle)
+    {
+      while (!eod)
+	{
+	  dir_entry_size = sizeof (struct dirent) + NAME_MAX + 1;
+	  dir_entry = (struct dirent *) LW6SYS_CALLOC (dir_entry_size);
+	  if (dir_entry)
+	    {
+	      readdir_r (dir_handle, dir_entry, &dir_entry_result);
+	      if (dir_entry_result && (dir_entry_result == dir_entry))
+		{
+		  _dir_list_add_entry (list,
+				       dir, dir_entry->d_name, filter_func,
+				       func_data, n);
+		}
+	      else
+		{
+		  eod = 1;
+		}
+	      LW6SYS_FREE (dir_entry);
+	    }
+	}
+      closedir (dir_handle);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("couldn't read dir \"%s\""), dir);
+    }
+#endif
+  if (n && ((*n) == old_n))
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("nothing in dir \"%s\""), dir);
+    }
+}
+
+/**
+ * lw6sys_dir_list
+ *
+ * @dir: the path of the directory to list
+ * @filter_func: a function which will filter entries, can be NULL
+ * @func_data: additionnal data passed to filter_func
+ * @n: will contain the number of items found
+ *
+ * This list a directory. The filter will be passed the file path
+ * as an argument. If it returns 1, the file is kept, if it returns 0
+ * it's suppressed from the list.
+ *
+ * Return value: a list containing strings (file paths).
+ */
+lw6sys_list_t *
+lw6sys_dir_list (char *dir, lw6sys_dir_list_filter_func_t filter_func,
+		 void *func_data, int *n)
+{
+  lw6sys_list_t *ret = NULL;
+
+  if (n)
+    {
+      (*n) = 0;
+    }
+  ret = lw6sys_list_new (lw6sys_free_callback);
+  if (ret)
+    {
+      if (lw6sys_dir_exists (dir))
+	{
+	  _dir_list_add_entries (&ret, dir, filter_func, func_data, n);
+	}
+    }
+
+  return ret;
+}
+
+/**
+ * lw6sys_path_list
+ *
+ * @path: the path of the path to list
+ * @filter_func: a function which will filter entries, can be NULL
+ * @func_data: additionnal data passed to filter_func
+ * @n: will contain the number of items found
+ *
+ * This list a directory. By path we mean here a list of separated
+ * directories, separated by : for instance.
+ * The filter will be passed the file path
+ * as an argument. If it returns 1, the file is kept, if it returns 0
+ * it's suppressed from the list. It's like performing a call
+ * to @lw6sys_dir_list on each of the path members.
+ *
+ * Return value: a list containing strings (file paths).
+ */
+lw6sys_list_t *
+lw6sys_path_list (char *path,
+		  lw6sys_dir_list_filter_func_t
+		  filter_func, void *func_data, int *n)
+{
+  lw6sys_list_t *ret = NULL;
+  lw6sys_list_t *dirs = NULL;
+  char *dir = NULL;
+
+  if (n)
+    {
+      (*n) = 0;
+    }
+  ret = lw6sys_list_new (lw6sys_free_callback);
+  if (ret)
+    {
+      dirs = lw6sys_env_split (path);
+      if (dirs)
+	{
+	  while (dirs
+		 && ((dir = (char *) lw6sys_list_pop_front (&dirs)) != NULL))
+	    {
+	      _dir_list_add_entries (&ret, dir, filter_func, func_data, n);
+	      LW6SYS_FREE (dir);
+	    }
+	  // normally dirs is already freed here
+	}
+    }
+
+  return ret;
+}
+
+/**
+ * lw6sys_find_in_dir_and_path
+ *
+ * @dir: a directory, when to search the file first
+ * @path: the path to search too, a separated list of dirs
+ * @file: the filename to search for
+ *
+ * Tries to find a file in the given paths. The function is typically
+ * used to find music files. First it tries to find the file in dir,
+ * then it tries to find it in each dir of path. @file must be only
+ * a file name and not contain any directory. The function will use
+ * the filename only anyway.
+ *
+ * Return value: the full path of the found file.
+ */
+char *
+lw6sys_find_in_dir_and_path (char *dir, char *path, char *file)
+{
+  char *ret = NULL;
+  char *file_only = NULL;
+  char *tmp = NULL;
+  char *full_path;
+  lw6sys_list_t *dirs = NULL;
+
+  file_only = file;
+  tmp = strrchr (file, DIR_SEP_CHAR_UNIX);
+  if (tmp)
+    {
+      file_only = tmp + 1;
+    }
+  tmp = strrchr (file, DIR_SEP_CHAR_MS_WINDOWS);
+  if (tmp)
+    {
+      file_only = tmp + 1;
+    }
+  if (dir && !ret)
+    {
+      full_path = lw6sys_path_concat (dir, file_only);
+      if (full_path)
+	{
+	  if ((!ret) && lw6sys_file_exists (full_path))
+	    {
+	      ret = full_path;
+	    }
+	  else
+	    {
+	      LW6SYS_FREE (full_path);
+	    }
+	}
+    }
+  if (path && !ret)
+    {
+      dirs = lw6sys_env_split (path);
+      if (dirs)
+	{
+	  while (dirs
+		 && ((dir = (char *) lw6sys_list_pop_front (&dirs)) != NULL))
+	    {
+	      full_path = lw6sys_path_concat (dir, file_only);
+	      if (full_path)
+		{
+		  if ((!ret) && lw6sys_file_exists (full_path))
+		    {
+		      ret = full_path;
+		    }
+		  else
+		    {
+		      LW6SYS_FREE (full_path);
+		    }
+		}
+	      LW6SYS_FREE (dir);
+	    }
+	  // normally dirs is already freed here
+	}
+    }
+
+  return ret;
+}
