@@ -247,6 +247,78 @@ lw6sys_str_is_same (char *str_a, char *str_b)
   return ret;
 }
 
+/**
+ * lw6sys_str_is_same_no_case
+ *
+ * @str_a: 1st string to compare, can be NULL
+ * @str_b: 2nd string to compare, can be NULL
+ *
+ * Compares two strings for equality. Difference with strcmp
+ * is that this one won't check for alphabetical order and
+ * return -1 or +1, but will check for NULL args.
+ * of space, tabs, or carriage returns only. This function
+ * is not case sensitive.
+ *
+ * Return value: 1 if same, 0 if not.
+ */
+int
+lw6sys_str_is_same_no_case (char *str_a, char *str_b)
+{
+  int ret = 1;
+
+  if (((!str_a) && str_b) || (str_a && (!str_b)))
+    {
+      ret = 0;
+    }
+  if (str_a && str_b)
+    {
+      ret = strcasecmp (str_a, str_b) ? 0 : 1;
+    }
+
+  return ret;
+}
+
+/**
+ * lw6sys_str_starts_with
+ *
+ * @str: the string to analyse
+ * @beginning: the pattern to search
+ *
+ * Tells wether string starts with a given beginning.
+ *
+ * Return value: 1 if @str starts with @beginning, 0 if not
+ */
+int
+lw6sys_str_starts_with (char *str, char *beginning)
+{
+  int ret = 0;
+
+  ret = !strncmp (str, beginning, strlen (beginning));
+
+  return ret;
+}
+
+/**
+ * lw6sys_str_starts_with_no_case
+ *
+ * @str: the string to analyse
+ * @beginning: the pattern to search
+ *
+ * Tells wether string starts with a given beginning. This function
+ * is not case sensitive.
+ *
+ * Return value: 1 if @str starts with @beginning, 0 if not
+ */
+int
+lw6sys_str_starts_with_no_case (char *str, char *beginning)
+{
+  int ret = 0;
+
+  ret = !strncasecmp (str, beginning, strlen (beginning));
+
+  return ret;
+}
+
 /**
  * lw6sys_skip_blanks
  *
@@ -262,7 +334,7 @@ lw6sys_skip_blanks (char **str_ptr)
 {
   int ret = 0;
 
-  while ((**str_ptr) == ' ' || (**str_ptr) == '\t')
+  while (lw6sys_chr_is_space (**str_ptr))
     {
       ret = 1;
       (*str_ptr)++;
@@ -288,9 +360,13 @@ lw6sys_skip_blanks (char **str_ptr)
 void
 lw6sys_str_cleanup (char *str)
 {
-  char *pos;
+  /*
+   * It's important to have pos unsigned here else characters
+   * over 127 are handled differently.
+   */
+  unsigned char *pos;
 
-  pos = str;
+  pos = (unsigned char *) str;
   while (*pos)
     {
       if ((*pos) < 32)
@@ -301,6 +377,41 @@ lw6sys_str_cleanup (char *str)
     }
 }
 
+/**
+ * lw6sys_str_cleanup_ascii7
+ *
+ * @str: a pointer to the string, which will be modified in-place.
+ *
+ * Used to clean up some strings, for instance if they
+ * come from the network, we don't necessarly want system
+ * chars to be displayed on the console. Basically it removes
+ * all characters with an ASCII code inferior to 32, that is,
+ * all system characters. This way, there won't be any tab,
+ * linefeed, or any of such characters left. This function
+ * will even remove any character above ASCII 127.
+ *
+ * Return value: none. 
+ */
+void
+lw6sys_str_cleanup_ascii7 (char *str)
+{
+  /*
+   * It's important to have pos unsigned here else characters
+   * over 127 are handled differently.
+   */
+  unsigned char *pos;
+
+  pos = (unsigned char *) str;
+  while (*pos)
+    {
+      if ((*pos) < 32 || (*pos) > 127)
+	{
+	  (*pos) = ' ';
+	}
+      pos++;
+    }
+}
+
 static void
 reformat_newline (char **formatted_str, char *append, char *prefix)
 {
@@ -352,9 +463,9 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
       pos = str_copy;
       while (pos[0] && ret)
 	{
-	  if (pos[0] == '\n')
+	  if (lw6sys_chr_is_eol (pos[0]))
 	    {
-	      while (pos[1] == '\n')
+	      while (lw6sys_chr_is_eol (pos[0]))
 		{
 		  pos++;
 		}
@@ -369,7 +480,7 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
 	      space_i = 0;
 	      while (i > 0)
 		{
-		  if (line_start[i] == ' ' || line_start[i] == '\t')
+		  if (lw6sys_chr_is_space (line_start[i]))
 		    {
 		      space_i = i;
 		      break;
@@ -381,8 +492,8 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
 		  i = 1;
 		  while (line_start[i] && !space_i)
 		    {
-		      if (line_start[i] == ' ' || line_start[i] == '\t'
-			  || line_start[i] == '\n')
+		      if (lw6sys_chr_is_eol (line_start[i])
+			  || lw6sys_chr_is_space (line_start[i]))
 			{
 			  space_i = i;
 			  break;
@@ -617,3 +728,23 @@ lw6sys_str_tolower (char *str)
       pos++;
     }
 }
+
+/**
+ * lw6sys_str_truncate
+ *
+ * @str: the string to truncate
+ * @len: the new length
+ *
+ * Truncates a string to the max given length. If truncated to 3,
+ * "abcdef" becomes "abc".
+ *
+ * Return value: none, @str pointed data modified in-place
+ */
+void
+lw6sys_str_truncate (char *str, int len)
+{
+  if (strlen (str) > len)
+    {
+      str[len] = '\0';
+    }
+}
