@@ -55,6 +55,18 @@
 #define PATH_RELATIVE "../../foo/bar"
 #define PATH_RELATIVE_UNPARENT "../foo/bar"
 #endif
+#define _TEST_LIST_STR1 "str1"
+#define _TEST_LIST_STR2 "str2"
+#define _TEST_LIST_STR3 "str3"
+#define _TEST_LIST_STR4 "str4"
+#define _TEST_LIST_STR5 "str5"
+#define _TEST_ASSOC_KEY1 "1"
+#define _TEST_ASSOC_KEY2 "2"
+#define _TEST_ASSOC_KEY3 "3"
+#define _TEST_ASSOC_KEY4 "4"
+#define _TEST_ASSOC_KEY5 "5"
+#define _TEST_LIST_FILTER_NB_ITEMS 25
+#define _TEST_LIST_FILTER_RANGE 100
 #define TEST_PATH_CWD "./"
 #define TEST_PATH_SPLIT "/foo/\\bar\\"
 #define _TEST_DIR_LIST_FUNC_DATA "foo,bar"
@@ -71,8 +83,17 @@
 #define VTHREAD_N 3
 #define TEST_SLEEP_TIME 3
 #define TEST_DELAY_TIME 50
+#define TEST_RFC1123_SECONDS_FROM_NOW 100000
+#define TEST_READABLE_UPTIME_1 3689
+#define TEST_READABLE_UPTIME_2 1234567
 #define TEST_SLEEP_TIME_SHORT_STEP 0.001f
 #define BLANK_STR "\t "
+#define CLEANUP_FORMAT "<foo %c bar %c>"
+#define CLEANUP_CONTROL '\n'
+#define CLEANUP_ACCENT 233
+#define STR_STARTS_WITH "abcdef"
+#define STR_STARTS_WITH_OK "abc"
+#define STR_STARTS_WITH_KO "def"
 #define ASCII_STR "foo,bar"
 #define TEST_ARGC 4
 #define TEST_ARGV0 "test.out"
@@ -113,6 +134,10 @@
 #else
 #define TEST_ENV_SPLIT "foo1/foo2;foo3:bar1;bar2/bar3"
 #endif
+#define _ESCAPE_STR "this is a string with a simple quote ' a double quote \" a tab char \"\t\" and a backslash \"\\\" a lower and greater <> and a few allowed chars _-.,#:;?& OK"
+#define _ESCAPE_STR_HTTP_URI "this%20is%20a%20string%20with%20a%20simple%20quote%20%27%20a%20double%20quote%20%22%20a%20tab%20char%20%22%22%20and%20a%20backslash%20%22%5C%22%20a%20lower%20and%20greater%20%3C%3E%20and%20a%20few%20allowed%20chars%20_-.,#:;?&%20OK"
+#define _ESCAPE_STR_HTML_ATTRIBUTE "this is a string with a simple quote ' a double quote &quot; a tab char &quot; &quot; and a backslash &quot;\\&quot; a lower and greater &lt;&gt; and a few allowed chars _-.,#:;?&amp; OK"
+#define _ESCAPE_STR_SQL_VALUE "this is a string with a simple quote '' a double quote \" a tab char \" \" and a backslash \"\\\" a lower and greater <> and a few allowed chars _-.,#:;?& OK"
 #define TEST_REFORMAT_STR1 "this is a short string"
 #define TEST_REFORMAT_STR2 "this is a very long string it should be cut in some places but wherever there is a very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very long word it won't be cut.\n\nIt should even handle newlines in some places but well, this is not absolutely necessary"
 #define TEST_REFORMAT_PREFIX "# "
@@ -120,6 +145,7 @@
 #define TEST_SPLIT_STR "/foo/bar,/foo/bar"
 #define TEST_SPLIT_CHAR 'o'
 #define _TEST_STR_LOWER_UPPER "foObaR!"
+#define _TEST_STR_TRUNCATE 5
 #define TEST_SERIALIZE 12345
 #define TEST_SORT_LENGTH 10
 #define TEST_SORT_INT {9,3,4,5,6,8,7,2,0,1};
@@ -170,6 +196,20 @@
 #define TEST_MATH_HEARTBEAT_Y2 1.5f
 #define TEST_MATH_BLINK_N 10
 #define TEST_MATH_BLINK_PERIOD 3
+#define TEST_URL_IP_1 "127.0.0.1"
+#define TEST_URL_PORT_1 1234
+#define TEST_URL_IP_2 "5.6.7.8"
+#define TEST_URL_PORT_2 80
+#define TEST_URL_CANONIZE_1 "http://www.toto.com/"
+#define TEST_URL_CANONIZE_2 "http://www.ToTo.com:81"
+#define TEST_URL_CANONIZE_3 "https://www.ToTo.com:443/tItI"
+#define TEST_URL_CANONIZE_4 "www.toto.com"
+#define TEST_URL_CANONIZE_5 ":123"
+#define TEST_URL_CANONIZE_6 ""
+#define TEST_URL_NOT_CANONIZED "ftp://truc"
+#define TEST_PASSWORD_SEED "http://"
+#define TEST_PASSWORD1 "abc"
+#define TEST_PASSWORD2 "XY"
 
 /*
  * Testing functions in arg.c
@@ -291,23 +331,24 @@ test_assoc ()
 		_("testing free_func callback and dup on string assoc"));
     assoc = lw6sys_assoc_new (&lw6sys_free_callback);
     str1 = LW6SYS_MALLOC (5);
-    strncpy (str1, "str1", 5);
-    lw6sys_assoc_set (&assoc, "1", (void *) str1);
+    strncpy (str1, _TEST_LIST_STR1, 5);
+    lw6sys_assoc_set (&assoc, _TEST_ASSOC_KEY1, (void *) str1);
     str2 = LW6SYS_MALLOC (5);
-    strncpy (str2, "str2", 5);
-    lw6sys_assoc_set (&assoc, "2", (void *) str2);
+    strncpy (str2, _TEST_LIST_STR2, 5);
+    lw6sys_assoc_set (&assoc, _TEST_ASSOC_KEY2, (void *) str2);
     str3 = LW6SYS_MALLOC (5);
-    strncpy (str3, "str3", 5);
-    lw6sys_assoc_set (&assoc, "3", (void *) str3);
-    lw6sys_assoc_unset (assoc, "1");
-    lw6sys_assoc_unset (assoc, "3");
+    strncpy (str3, _TEST_LIST_STR3, 5);
+    lw6sys_assoc_set (&assoc, _TEST_ASSOC_KEY3, (void *) str3);
+    lw6sys_assoc_unset (assoc, _TEST_ASSOC_KEY1);
+    lw6sys_assoc_unset (assoc, _TEST_ASSOC_KEY3);
     assoc_copy =
       lw6sys_assoc_dup (assoc, (lw6sys_dup_func_t) lw6sys_str_copy);
-    ret = ret && !lw6sys_assoc_has_key (assoc_copy, "1");
-    ret = ret && lw6sys_assoc_has_key (assoc_copy, "2");
-    ret = ret && !lw6sys_assoc_has_key (assoc_copy, "3");
+    ret = ret && !lw6sys_assoc_has_key (assoc_copy, _TEST_ASSOC_KEY1);
+    ret = ret && lw6sys_assoc_has_key (assoc_copy, _TEST_ASSOC_KEY2);
+    ret = ret && !lw6sys_assoc_has_key (assoc_copy, _TEST_ASSOC_KEY3);
     ret = ret
-      && strcmp ((char *) lw6sys_assoc_get (assoc_copy, "2"), "str2") == 0;
+      && strcmp ((char *) lw6sys_assoc_get (assoc_copy, _TEST_ASSOC_KEY2),
+		 _TEST_LIST_STR2) == 0;
     lw6sys_assoc_free (assoc_copy);
     lw6sys_assoc_free (assoc);
   }
@@ -617,13 +658,13 @@ test_env ()
 		    TEST_ENV_SETENV_KEYWORD);
 	ret = 0;
       }
-    if (!lw6sys_env_exists (TEST_ENV_KEYWORD))
+    if (!lw6sys_env_exists_prefixed (TEST_ENV_KEYWORD))
       {
 	lw6sys_log (LW6SYS_LOG_WARNING, _("ENV \"%s\" doesn't exist"),
 		    TEST_ENV_KEYWORD);
 	ret = 0;
       }
-    value = lw6sys_getenv (TEST_ENV_KEYWORD);
+    value = lw6sys_getenv_prefixed (TEST_ENV_KEYWORD);
     if (value)
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _("ENV value for \"%s\" is \"%s\""),
@@ -693,6 +734,143 @@ test_env ()
   return ret;
 }
 
+/*
+ * Testing functions in env.c
+ */
+static int
+test_escape ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *escaped = NULL;
+
+    escaped = lw6sys_escape_http_uri (_ESCAPE_STR);
+    if (escaped)
+      {
+	if (!strcmp (_ESCAPE_STR_HTTP_URI, escaped))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("http uri escape for \"%s\" is \"%s\""),
+			_ESCAPE_STR, escaped);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_
+			("http uri escape for \"%s\" is \"%s\" but should be \"%s\""),
+			_ESCAPE_STR, escaped, _ESCAPE_STR_HTTP_URI);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (escaped);
+      }
+    escaped = lw6sys_escape_html_attribute (_ESCAPE_STR);
+    if (escaped)
+      {
+	if (!strcmp (_ESCAPE_STR_HTML_ATTRIBUTE, escaped))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("http uri escape for \"%s\" is \"%s\""),
+			_ESCAPE_STR, escaped);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_
+			("http uri escape for \"%s\" is \"%s\" but should be \"%s\""),
+			_ESCAPE_STR, escaped, _ESCAPE_STR_HTML_ATTRIBUTE);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (escaped);
+      }
+    escaped = lw6sys_escape_sql_value (_ESCAPE_STR);
+    if (escaped)
+      {
+	if (!strcmp (_ESCAPE_STR_SQL_VALUE, escaped))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("http uri escape for \"%s\" is \"%s\""),
+			_ESCAPE_STR, escaped);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_
+			("http uri escape for \"%s\" is \"%s\" but should be \"%s\""),
+			_ESCAPE_STR, escaped, _ESCAPE_STR_SQL_VALUE);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (escaped);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+/*
+ * Testing functions in exec.c
+ */
+static int
+test_exec (int argc, char *argv[], int mode)
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *myself;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("executed_again=%d"),
+		lw6sys_is_executed_again (argc, argv));
+    myself = lw6sys_exec_find_myself (argc, argv);
+    if (myself)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("found myself in \"%s\""), myself);
+	if (mode)
+	  {
+	    if (lw6sys_exec_again (argc, argv))
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _
+			    ("exec again of \"%s\" successfull, means we're already \"executed again\""),
+			    myself);
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _("exec again of \"%s\" failed"), myself);
+		ret = 0;
+	      }
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("check mode, so not trying to exec again \"%s\""),
+			myself);
+	  }
+	LW6SYS_FREE (myself);
+      }
+    else
+      {
+	if (mode)
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING, _("could not find myself"));
+	    ret = 0;
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_
+			("could not find myself, this is only check mode so no panic, but this is strange"));
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in file.c
  */
@@ -706,6 +884,7 @@ test_file ()
     char *content = NULL;
     char *user_dir = NULL;
     char *filename = NULL;
+    int filesize = 0;
     int argc = TEST_ARGC;
     char *argv[TEST_ARGC] =
       { TEST_ARGV0, TEST_ARGV1, TEST_ARGV2, TEST_ARGV3 };
@@ -723,7 +902,6 @@ test_file ()
 	    if (lw6sys_write_file_content (filename, TEST_CONTENT))
 	      {
 		content = lw6sys_read_file_content (filename);
-
 		if (content && !strcmp (TEST_CONTENT, content))
 		  {
 		    lw6sys_log (LW6SYS_LOG_NOTICE,
@@ -735,6 +913,21 @@ test_file ()
 		  {
 		    ret = 0;
 		  }
+
+		content = lw6sys_read_file_content_bin (&filesize, filename);
+		if (content && !strcmp (TEST_CONTENT, content)
+		    && strlen (content) == filesize)
+		  {
+		    lw6sys_log (LW6SYS_LOG_NOTICE,
+				_
+				("bin file \"%s\" has size %d and contains \"%s\""),
+				filename, filesize, content);
+		    LW6SYS_FREE (content);
+		  }
+		else
+		  {
+		    ret = 0;
+		  }
 	      }
 	    else
 	      {
@@ -814,22 +1007,23 @@ test_hash ()
 		_("testing free_func callback and dup on string hash"));
     hash = lw6sys_hash_new (&lw6sys_free_callback, 7);
     str1 = LW6SYS_MALLOC (5);
-    strncpy (str1, "str1", 5);
-    lw6sys_hash_set (hash, "1", (void *) str1);
+    strncpy (str1, _TEST_LIST_STR1, 5);
+    lw6sys_hash_set (hash, _TEST_ASSOC_KEY1, (void *) str1);
     str2 = LW6SYS_MALLOC (5);
-    strncpy (str2, "str2", 5);
-    lw6sys_hash_set (hash, "2", (void *) str2);
+    strncpy (str2, _TEST_LIST_STR2, 5);
+    lw6sys_hash_set (hash, _TEST_ASSOC_KEY2, (void *) str2);
     str3 = LW6SYS_MALLOC (5);
-    strncpy (str3, "str3", 5);
-    lw6sys_hash_set (hash, "3", (void *) str3);
-    lw6sys_hash_unset (hash, "1");
-    lw6sys_hash_unset (hash, "3");
+    strncpy (str3, _TEST_LIST_STR3, 5);
+    lw6sys_hash_set (hash, _TEST_ASSOC_KEY3, (void *) str3);
+    lw6sys_hash_unset (hash, _TEST_ASSOC_KEY1);
+    lw6sys_hash_unset (hash, _TEST_ASSOC_KEY3);
     hash_copy = lw6sys_hash_dup (hash, (lw6sys_dup_func_t) lw6sys_str_copy);
-    ret = ret && !lw6sys_hash_has_key (hash_copy, "1");
-    ret = ret && lw6sys_hash_has_key (hash_copy, "2");
-    ret = ret && !lw6sys_hash_has_key (hash_copy, "3");
+    ret = ret && !lw6sys_hash_has_key (hash_copy, _TEST_ASSOC_KEY1);
+    ret = ret && lw6sys_hash_has_key (hash_copy, _TEST_ASSOC_KEY2);
+    ret = ret && !lw6sys_hash_has_key (hash_copy, _TEST_ASSOC_KEY3);
     ret = ret
-      && strcmp ((char *) lw6sys_hash_get (hash_copy, "2"), "str2") == 0;
+      && strcmp ((char *) lw6sys_hash_get (hash_copy, _TEST_ASSOC_KEY2),
+		 _TEST_LIST_STR2) == 0;
     lw6sys_hash_free (hash_copy);
     lw6sys_hash_free (hash);
   }
@@ -871,6 +1065,8 @@ test_hexa ()
     lw6sys_whd_t test_whd = TEST_HEXA_WHD;
     lw6sys_xyz_t test_xyz = TEST_HEXA_XYZ;
     lw6sys_color_8_t test_color = TEST_HEXA_COLOR;
+    void *ptr = NULL;
+    char *ptr_str = NULL;
 
     hexa_serializer = lw6sys_hexa_serializer_new ("");
     if (hexa_serializer)
@@ -1030,6 +1226,31 @@ test_hexa ()
 	      }
 	  }
 
+	ptr_str = lw6sys_hexa_ptr_to_str ((void *) hexa_serializer);
+	if (ptr_str)
+	  {
+	    ptr = lw6sys_hexa_str_to_ptr (ptr_str);
+	    if (ptr == (void *) hexa_serializer)
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("pointer %p string is \"%s\""), ptr, ptr_str);
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _
+			    ("error converting pointer %p from string \"%s\""),
+			    ptr, ptr_str);
+		ret = 0;
+	      }
+	    LW6SYS_FREE (ptr_str);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING, _("error converting pointer %p"),
+			hexa_serializer);
+	    ret = 0;
+	  }
 	lw6sys_hexa_serializer_free (hexa_serializer);
       }
     else
@@ -1240,12 +1461,42 @@ test_keyword ()
  * Used to test lw6sys_list_map.
  */
 static void
-list_map_func (void *func_data, void *data)
+list_map_int_func (void *func_data, void *data)
 {
   int *ret = (int *) func_data;
   int *i = (int *) data;
 
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("list item ret=%d, data=%d"), *ret, *i);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("list item ret=%d, i=%d"), *ret, *i);
+}
+
+/*
+ * Used to test lw6sys_list_map.
+ */
+static void
+list_map_str_func (void *func_data, void *data)
+{
+  int *ret = (int *) func_data;
+  char *str = (char *) data;
+
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("list item ret=%d, str=\"%s\""), *ret,
+	      str);
+}
+
+/*
+ * Used to test lw6sys_list_map.
+ */
+static int
+list_filter_func (void *func_data, void *data)
+{
+  int *limit = (int *) func_data;
+  int *d = (int *) data;
+  int ret = 0;
+
+  ret = (*d < *limit);
+  lw6sys_log (LW6SYS_LOG_NOTICE,
+	      _("list item limit=%d, d=%d, pass filter=%d"), *limit, *d, ret);
+
+  return ret;
 }
 
 /*
@@ -1268,35 +1519,262 @@ test_list ()
 
   {
     int a = 3, b = 5, c = 7;
+    int i;
 
     lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo push/pop on int list"));
     list = lw6sys_list_new (NULL);
     lw6sys_lifo_push (&list, (void *) &a);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo push %d"), a);
     lw6sys_lifo_push (&list, (void *) &b);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo push %d"), b);
     lw6sys_lifo_push (&list, (void *) &c);
-    lw6sys_list_map (list, &list_map_func, &ret);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo push %d"), c);
+    lw6sys_list_map (list, &list_map_int_func, &ret);
     ret = ret && lw6sys_list_length (list) == 3;
-    ret = ret && (*((int *) lw6sys_lifo_pop (&list)) == c);
-    ret = ret && (*((int *) lw6sys_lifo_pop (&list)) == b);
-    ret = ret && (*((int *) lw6sys_lifo_pop (&list)) == a);
+    i = *((int *) lw6sys_lifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo pop %d"), i);
+    ret = ret && (i == c);
+    i = *((int *) lw6sys_lifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo pop %d"), i);
+    ret = ret && (i == b);
+    i = *((int *) lw6sys_lifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo pop %d"), i);
+    ret = ret && (i == a);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("free list"));
     lw6sys_list_free (list);
   }
 
   {
     int a = 2, b = 4, c = 6, d = 8;
+    int i;
 
     lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo push/pop on int list"));
     list = lw6sys_list_new (NULL);
     lw6sys_fifo_push (&list, (void *) &a);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo push %d"), a);
     lw6sys_fifo_push (&list, (void *) &b);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo push %d"), b);
     lw6sys_fifo_push (&list, (void *) &c);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo push %d"), c);
     lw6sys_fifo_push (&list, (void *) &d);
-    lw6sys_list_map (list, &list_map_func, &ret);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo push %d"), d);
+    lw6sys_list_map (list, &list_map_int_func, &ret);
     ret = ret && lw6sys_list_length (list) == 4;
-    ret = ret && (*((int *) lw6sys_fifo_pop (&list)) == a);
-    ret = ret && (*((int *) lw6sys_fifo_pop (&list)) == b);
-    ret = ret && (*((int *) lw6sys_fifo_pop (&list)) == c);
-    ret = ret && (*((int *) lw6sys_fifo_pop (&list)) == d);
+    i = *((int *) lw6sys_fifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo pop %d"), i);
+    ret = ret && (i == a);
+    i = *((int *) lw6sys_fifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo pop %d"), i);
+    ret = ret && (i == b);
+    i = *((int *) lw6sys_fifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo pop %d"), i);
+    ret = ret && (i == c);
+    i = *((int *) lw6sys_fifo_pop (&list));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo pop %d"), i);
+    ret = ret && (i == d);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("free list"));
+    lw6sys_list_free (list);
+  }
+
+  {
+    char *str;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front/pop_front on string list"));
+    list = lw6sys_list_new (lw6sys_free_callback);
+    lw6sys_list_push_front (&list,
+			    (void *) lw6sys_str_copy (_TEST_LIST_STR1));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front \"%s\""), _TEST_LIST_STR1);
+    lw6sys_list_push_front (&list,
+			    (void *) lw6sys_str_copy (_TEST_LIST_STR2));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front \"%s\""), _TEST_LIST_STR2);
+    lw6sys_list_push_front (&list,
+			    (void *) lw6sys_str_copy (_TEST_LIST_STR3));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front \"%s\""), _TEST_LIST_STR3);
+    lw6sys_list_map (list, &list_map_str_func, &ret);
+    str = (char *) lw6sys_list_pop_front (&list);
+    if (str)
+      {
+	ret = ret && (!strcmp (str, _TEST_LIST_STR3));
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_front \"%s\""), str);
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_front (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_front \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR2));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_front (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_front \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR1));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("free list"));
+    lw6sys_list_free (list);
+  }
+
+  {
+    char *str;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back/pop_front on string list"));
+    list = lw6sys_list_new (lw6sys_free_callback);
+    lw6sys_list_push_back (&list, (void *) lw6sys_str_copy (_TEST_LIST_STR1));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back \"%s\""), _TEST_LIST_STR1);
+    lw6sys_list_push_back (&list, (void *) lw6sys_str_copy (_TEST_LIST_STR2));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back \"%s\""), _TEST_LIST_STR2);
+    lw6sys_list_push_back (&list, (void *) lw6sys_str_copy (_TEST_LIST_STR3));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back \"%s\""), _TEST_LIST_STR3);
+    lw6sys_list_map (list, &list_map_str_func, &ret);
+    str = (char *) lw6sys_list_pop_front (&list);
+    if (str)
+      {
+	ret = ret && (!strcmp (str, _TEST_LIST_STR1));
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_front \"%s\""), str);
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_front (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_front \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR2));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_front (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_front \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR3));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("free list"));
+    lw6sys_list_free (list);
+  }
+
+  {
+    char *str;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front/pop_back on string list"));
+    list = lw6sys_list_new (lw6sys_free_callback);
+    lw6sys_list_push_front (&list,
+			    (void *) lw6sys_str_copy (_TEST_LIST_STR1));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front \"%s\""), _TEST_LIST_STR1);
+    lw6sys_list_push_front (&list,
+			    (void *) lw6sys_str_copy (_TEST_LIST_STR2));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front \"%s\""), _TEST_LIST_STR2);
+    lw6sys_list_push_front (&list,
+			    (void *) lw6sys_str_copy (_TEST_LIST_STR3));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_front \"%s\""), _TEST_LIST_STR3);
+    lw6sys_list_map (list, &list_map_str_func, &ret);
+    str = (char *) lw6sys_list_pop_back (&list);
+    if (str)
+      {
+	ret = ret && (!strcmp (str, _TEST_LIST_STR1));
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_back \"%s\""), str);
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_back (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_back \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR2));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_back (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_back \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR3));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("free list"));
+    lw6sys_list_free (list);
+  }
+
+  {
+    char *str;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back/pop_back on string list"));
+    list = lw6sys_list_new (lw6sys_free_callback);
+    lw6sys_list_push_back (&list, (void *) lw6sys_str_copy (_TEST_LIST_STR1));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back \"%s\""), _TEST_LIST_STR1);
+    lw6sys_list_push_back (&list, (void *) lw6sys_str_copy (_TEST_LIST_STR2));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back \"%s\""), _TEST_LIST_STR2);
+    lw6sys_list_push_back (&list, (void *) lw6sys_str_copy (_TEST_LIST_STR3));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("push_back \"%s\""), _TEST_LIST_STR3);
+    lw6sys_list_map (list, &list_map_str_func, &ret);
+    str = (char *) lw6sys_list_pop_back (&list);
+    if (str)
+      {
+	ret = ret && (!strcmp (str, _TEST_LIST_STR3));
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_back \"%s\""), str);
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_back (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_back \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR2));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (str)
+      {
+	str = (char *) lw6sys_list_pop_back (&list);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pop_back \"%s\""), str);
+	ret = ret && (!strcmp (str, _TEST_LIST_STR1));
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("free list"));
     lw6sys_list_free (list);
   }
 
@@ -1310,7 +1788,7 @@ test_list ()
     lw6sys_list_push_back (&list, (void *) &c);
     lw6sys_list_push_back (&list, (void *) &d);
     lw6sys_list_push_back (&list, (void *) &e);
-    lw6sys_list_map (list, &list_map_func, &ret);
+    lw6sys_list_map (list, &list_map_int_func, &ret);
     ret = ret && lw6sys_list_length (list) == 5;
     ret = ret && (*((int *) lw6sys_list_pop_back (&list)) == e);
     ret = ret && (*((int *) lw6sys_list_pop_back (&list)) == d);
@@ -1326,13 +1804,13 @@ test_list ()
     lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("testing free_func callback and dup on string list"));
     list = lw6sys_list_new (&lw6sys_free_callback);
-    str1 = lw6sys_str_copy ("str1");
+    str1 = lw6sys_str_copy (_TEST_LIST_STR1);
     lw6sys_lifo_push (&list, (void *) str1);
-    str2 = lw6sys_str_copy ("str2");
+    str2 = lw6sys_str_copy (_TEST_LIST_STR2);
     lw6sys_fifo_push (&list, (void *) str2);
-    str3 = lw6sys_str_copy ("str3");
+    str3 = lw6sys_str_copy (_TEST_LIST_STR3);
     lw6sys_lifo_push (&list, (void *) str3);
-    str4 = lw6sys_str_copy ("str4");
+    str4 = lw6sys_str_copy (_TEST_LIST_STR4);
     lw6sys_fifo_push (&list, (void *) str4);
     list_copy = lw6sys_list_dup (list, (lw6sys_dup_func_t) lw6sys_str_copy);
     ret = ret && lw6sys_list_length (list_copy) == 4;
@@ -1369,6 +1847,36 @@ test_list ()
 	  }
       }
   }
+  {
+    int i = 0;
+    int *d = NULL;
+    int limit = 0;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing list filter"));
+    list = lw6sys_list_new (lw6sys_free_callback);
+    if (list)
+      {
+	for (i = 0; i < _TEST_LIST_FILTER_NB_ITEMS; ++i)
+	  {
+	    d = (int *) LW6SYS_MALLOC (sizeof (int));
+	    if (d)
+	      {
+		(*d) = lw6sys_random (_TEST_LIST_FILTER_RANGE);
+		lw6sys_list_push_front (&list, d);
+	      }
+	  }
+	limit = (2 * _TEST_LIST_FILTER_RANGE) / 3;
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("1st filter limit=%d"), limit);
+	lw6sys_list_filter (&list, list_filter_func, &limit);
+	limit = _TEST_LIST_FILTER_RANGE / 3;
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("2nd filter limit=%d"), limit);
+	lw6sys_list_filter (&list, list_filter_func, &limit);
+	limit = -_TEST_LIST_FILTER_RANGE / 10;
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("3rd filter limit=%d"), limit);
+	lw6sys_list_filter (&list, list_filter_func, &limit);
+	lw6sys_list_free (list);
+      }
+  }
 
   LW6SYS_TEST_FUNCTION_END;
   return ret;
@@ -1378,7 +1886,7 @@ test_list ()
  * Testing functions in log.c
  */
 static int
-test_log ()
+test_log (int mode)
 {
   int ret = 1;
   LW6SYS_TEST_FUNCTION_BEGIN;
@@ -1388,9 +1896,17 @@ test_log ()
 
     log_level = lw6sys_log_get_level ();
     lw6sys_log_set_level (log_level);
-    /*
-     * We do not test WARNING & ERROR to avoid confusion...
-     */
+    if (mode)
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("this is a /TEST/ warning"));
+	lw6sys_log (LW6SYS_LOG_ERROR, _("this is a /TEST/ error"));
+      }
+    else
+      {
+	/*
+	 * We do not test WARNING & ERROR to avoid confusion...
+	 */
+      }
     lw6sys_log (LW6SYS_LOG_NOTICE, _("testing log_notice %s=%d"),
 		"log_level=%d", log_level);
     lw6sys_log (LW6SYS_LOG_INFO, _("testing log_info %s=%d"), "log_level=%d",
@@ -1685,6 +2201,118 @@ _dir_list_print (void *func_data, void *data)
   lw6sys_log (LW6SYS_LOG_NOTICE, _("entry \"%s\""), file);
 }
 
+/*
+ * Testing functions in password.c
+ */
+static int
+test_password ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *checksum = NULL;
+
+    checksum = lw6sys_password_checksum (NULL, NULL);
+    if (checksum)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("checksum for password NULL is \"%s\""), checksum);
+	LW6SYS_FREE (checksum);
+      }
+    else
+      {
+	ret = 0;
+      }
+    checksum = lw6sys_password_checksum (NULL, "");
+    if (checksum)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("checksum for empty password is \"%s\""), checksum);
+	LW6SYS_FREE (checksum);
+      }
+    else
+      {
+	ret = 0;
+      }
+    checksum = lw6sys_password_checksum (TEST_PASSWORD_SEED, "");
+    if (checksum)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _
+		    ("checksum for empty password with seed \"%s\" is \"%s\""),
+		    TEST_PASSWORD_SEED, checksum);
+	LW6SYS_FREE (checksum);
+      }
+    else
+      {
+	ret = 0;
+      }
+    checksum = lw6sys_password_checksum (TEST_PASSWORD_SEED, TEST_PASSWORD1);
+    if (checksum)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("checksum for password \"%s\" is \"%s\""),
+		    TEST_PASSWORD1, checksum);
+	if (lw6sys_password_verify
+	    (TEST_PASSWORD_SEED, TEST_PASSWORD1, TEST_PASSWORD1))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("same password test works"));
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	if (lw6sys_password_verify
+	    (TEST_PASSWORD_SEED, TEST_PASSWORD1, checksum))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("same password test works using checksum"));
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	if (lw6sys_password_verify (TEST_PASSWORD_SEED, NULL, TEST_PASSWORD2))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("same password test works when it's NULL here"));
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	if (!lw6sys_password_verify
+	    (TEST_PASSWORD_SEED, TEST_PASSWORD1, TEST_PASSWORD2))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("same password test detects wrong passwords"));
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	if (!lw6sys_password_verify (NULL, TEST_PASSWORD1, TEST_PASSWORD2))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("same password test detects wrong seed"));
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	LW6SYS_FREE (checksum);
+      }
+    else
+      {
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in path.c
  */
@@ -2175,12 +2803,33 @@ test_str ()
     lw6sys_log (LW6SYS_LOG_NOTICE, _("testing is_blank on \"%s\""),
 		BLANK_STR);
     ret = ret && lw6sys_str_is_blank (BLANK_STR);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing cleanup"));
+    str =
+      lw6sys_new_sprintf (CLEANUP_FORMAT, CLEANUP_CONTROL, CLEANUP_ACCENT);
+    if (str)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("before cleanup, string is \%s\""),
+		    str);
+	lw6sys_str_cleanup (str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("after cleanup, string is \"%s\""),
+		    str);
+	lw6sys_str_cleanup_ascii7 (str);
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("after cleanup (ascii-7), string is \"%s\""), str);
+	LW6SYS_FREE (str);
+      }
     lw6sys_log (LW6SYS_LOG_NOTICE, _("testing is_same"));
     ret = ret && lw6sys_str_is_same (BLANK_STR, BLANK_STR)
       && lw6sys_str_is_same (NULL, NULL)
       && (!lw6sys_str_is_same (NULL, BLANK_STR))
       && (!lw6sys_str_is_same (BLANK_STR, NULL))
-      && (!lw6sys_str_is_same (BLANK_STR, TEST_REFORMAT_STR1));
+      && (!lw6sys_str_is_same (BLANK_STR, TEST_REFORMAT_STR1))
+      && (!lw6sys_str_is_same_no_case (BLANK_STR, TEST_REFORMAT_STR1));
+    ret = ret && lw6sys_str_starts_with (STR_STARTS_WITH, STR_STARTS_WITH_OK)
+      && !lw6sys_str_starts_with (STR_STARTS_WITH, STR_STARTS_WITH_KO)
+      && lw6sys_str_starts_with_no_case (STR_STARTS_WITH, STR_STARTS_WITH_OK)
+      && !lw6sys_str_starts_with_no_case (STR_STARTS_WITH,
+					  STR_STARTS_WITH_KO);
     str =
       lw6sys_str_reformat (TEST_REFORMAT_STR1, TEST_REFORMAT_PREFIX,
 			   TEST_REFORMAT_COLUMNS);
@@ -2238,6 +2887,8 @@ test_str ()
 	lw6sys_log (LW6SYS_LOG_NOTICE, _("lowered string=\"%s\""), str);
 	lw6sys_str_toupper (str);
 	lw6sys_log (LW6SYS_LOG_NOTICE, _("uppered string=\"%s\""), str);
+	lw6sys_str_truncate (str, _TEST_STR_TRUNCATE);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("truncated string=\"%s\""), str);
 	LW6SYS_FREE (str);
       }
   }
@@ -2534,6 +3185,9 @@ test_time ()
     int64_t uptime = 0;
     int64_t timestamp = 0;
     int32_t cycle = 0;
+    char *rfc1123 = NULL;
+    char *clf = NULL;
+    char *uptime_str = NULL;
 
     lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %" LW6SYS_PRINTF_LL "d"),
 		lw6sys_get_timestamp ());
@@ -2543,8 +3197,13 @@ test_time ()
     lw6sys_idle ();
     lw6sys_timer_update (&timestamp, &uptime, &cycle);
     lw6sys_log (LW6SYS_LOG_NOTICE,
-		_("timestamp=%" LW6SYS_PRINTF_LL "d uptime=%" LW6SYS_PRINTF_LL
-		  "d cycle=%d"), timestamp, uptime, cycle);
+		_("after idle timestamp=%" LW6SYS_PRINTF_LL "d uptime=%"
+		  LW6SYS_PRINTF_LL "d cycle=%d"), timestamp, uptime, cycle);
+    lw6sys_snooze ();
+    lw6sys_timer_update (&timestamp, &uptime, &cycle);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("after snooze timestamp=%" LW6SYS_PRINTF_LL "d uptime=%"
+		  LW6SYS_PRINTF_LL "d cycle=%d"), timestamp, uptime, cycle);
     last_uptime = lw6sys_get_uptime ();
     lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds"), TEST_SLEEP_TIME);
     lw6sys_sleep (TEST_SLEEP_TIME);
@@ -2562,6 +3221,173 @@ test_time ()
       }
     lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %" LW6SYS_PRINTF_LL "d ms"),
 		lw6sys_get_uptime () - last_uptime);
+
+    rfc1123 = lw6sys_date_rfc1123 (0);
+    if (rfc1123)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("rfc1123 date for now is \"%s\""),
+		    rfc1123);
+	LW6SYS_FREE (rfc1123);
+      }
+    rfc1123 = lw6sys_date_rfc1123 (TEST_RFC1123_SECONDS_FROM_NOW);
+    if (rfc1123)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("rfc1123 date in %d seconds is \"%s\""),
+		    TEST_RFC1123_SECONDS_FROM_NOW, rfc1123);
+	LW6SYS_FREE (rfc1123);
+      }
+    clf = lw6sys_date_clf ();
+    if (clf)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("clf date is \"%s\""), clf);
+	LW6SYS_FREE (clf);
+      }
+    uptime_str = lw6sys_readable_uptime (TEST_READABLE_UPTIME_1);
+    if (uptime_str)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("readable uptime for %d is \"%s\""),
+		    TEST_READABLE_UPTIME_1, uptime_str);
+	LW6SYS_FREE (uptime_str);
+      }
+    uptime_str = lw6sys_readable_uptime (TEST_READABLE_UPTIME_2);
+    if (uptime_str)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("readable uptime for %d is \"%s\""),
+		    TEST_READABLE_UPTIME_2, uptime_str);
+	LW6SYS_FREE (uptime_str);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+/*
+ * Testing functions in url.c
+ */
+static int
+test_url ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *url;
+
+    url = lw6sys_url_http_from_ip_port (TEST_URL_IP_1, TEST_URL_PORT_1);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("url from \"%s:%d\" is \"%s\""),
+		    TEST_URL_IP_1, TEST_URL_PORT_1, url);
+	LW6SYS_FREE (url);
+      }
+    else
+      {
+	ret = 0;
+      }
+    url = lw6sys_url_http_from_ip_port (TEST_URL_IP_2, TEST_URL_PORT_2);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("url from \"%s:%d\"is \"%s\""),
+		    TEST_URL_IP_2, TEST_URL_PORT_2, url);
+	LW6SYS_FREE (url);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (lw6sys_url_is_canonized (TEST_URL_NOT_CANONIZED))
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _("url \"%s\" reported as canonized, but it isn't"),
+		    TEST_URL_NOT_CANONIZED);
+	ret = 0;
+      }
+    url = lw6sys_url_canonize (TEST_URL_CANONIZE_1);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("canonical url for \"%s\" is \"%s\""),
+		    TEST_URL_CANONIZE_1, url);
+	if (!lw6sys_url_is_canonized (url))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("url \"%s\" not reported as canonized"), url);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (url);
+      }
+    url = lw6sys_url_canonize (TEST_URL_CANONIZE_2);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("canonical url for \"%s\" is \"%s\""),
+		    TEST_URL_CANONIZE_2, url);
+	if (!lw6sys_url_is_canonized (url))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("url \"%s\" not reported as canonized"), url);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (url);
+      }
+    url = lw6sys_url_canonize (TEST_URL_CANONIZE_3);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("canonical url for \"%s\" is \"%s\""),
+		    TEST_URL_CANONIZE_3, url);
+	if (!lw6sys_url_is_canonized (url))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("url \"%s\" not reported as canonized"), url);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (url);
+      }
+    url = lw6sys_url_canonize (TEST_URL_CANONIZE_4);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("canonical url for \"%s\" is \"%s\""),
+		    TEST_URL_CANONIZE_4, url);
+	if (!lw6sys_url_is_canonized (url))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("url \"%s\" not reported as canonized"), url);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (url);
+      }
+    url = lw6sys_url_canonize (TEST_URL_CANONIZE_5);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("canonical url for \"%s\" is \"%s\""),
+		    TEST_URL_CANONIZE_5, url);
+	if (!lw6sys_url_is_canonized (url))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("url \"%s\" not reported as canonized"), url);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (url);
+      }
+    url = lw6sys_url_canonize (TEST_URL_CANONIZE_6);
+    if (url)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("canonical url for \"%s\" is \"%s\""),
+		    TEST_URL_CANONIZE_6, url);
+	if (!lw6sys_url_is_canonized (url))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("url \"%s\" not reported as canonized"), url);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (url);
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -2659,6 +3485,30 @@ test_vthread ()
   return ret;
 }
 
+/**
+ * lw6sys_test_exec
+ *
+ * @argc: number of args as passed to main
+ * @argv: array of args as passed to main
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @sys module test suite which is specific to exec functions,
+ * these ones require @argc and @argv to be correctly set so the
+ * extra argument justifies putting it outside @lw6sys_test.
+ * Additionnally, it's not fool proof...
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
+int
+lw6sys_test_exec (int argc, char *argv[], int mode)
+{
+  int ret = 0;
+
+  ret = test_exec (argc, argv, mode);
+
+  return ret;
+}
+
 /**
  * lw6sys_test
  *
@@ -2678,13 +3528,14 @@ lw6sys_test (int mode)
 
   ret = test_arg () && test_assoc () && test_build () && test_checksum ()
     && test_color () && test_convert () && test_dump () && test_env ()
-    && test_file () && test_profiler () && test_hash () && test_hexa ()
-    && test_history () && test_i18n () && test_id () && test_keyword ()
-    && test_list () && test_log () && test_math () && test_mem ()
-    && test_mutex () && test_options () && test_nop () && test_path ()
-    && test_progress () && test_random () && test_sdl () && test_serial ()
-    && test_shape () && test_sort () && test_spinlock () && test_str ()
-    && test_thread () && test_time () && test_vthread ();
+    && test_escape () && test_file () && test_profiler () && test_hash ()
+    && test_hexa () && test_history () && test_i18n () && test_id ()
+    && test_keyword () && test_list () && test_log (mode) && test_math ()
+    && test_mem () && test_mutex () && test_options () && test_nop ()
+    && test_password () && test_path () && test_progress () && test_random ()
+    && test_sdl () && test_serial () && test_shape () && test_sort ()
+    && test_spinlock () && test_str () && test_thread () && test_time ()
+    && test_url () && test_vthread ();
 
   return ret;
 }
