@@ -120,6 +120,8 @@ typedef char *char_ptr_t;
 #define LW6SYS_SCRIPT_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin script function \"%s\""),__FUNCTION__); }
 #define LW6SYS_SCRIPT_FUNCTION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end script function \"%s\""),__FUNCTION__); }
 
+#define LW6SYS_TEST_OUTPUT { if (ret) { lw6sys_log(LW6SYS_LOG_NOTICE,_("test SUCCESSFULL!")); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("test FAILED...")); } }
+
 typedef struct lw6sys_xyz_s
 {
   /*
@@ -231,6 +233,7 @@ typedef void (*lw6sys_free_func_t) (void *data);
 typedef void (*lw6sys_assoc_callback_func_t) (void *func_data, char *key,
 					      void *value);
 typedef void (*lw6sys_list_callback_func_t) (void *func_data, void *data);
+typedef int (*lw6sys_list_filter_func_t) (void *func_data, void *data);
 typedef void *(*lw6sys_dup_func_t) (void *data);
 typedef void (*lw6sys_thread_callback_func_t) (void *callback_data);
 typedef int (*lw6sys_dir_list_filter_func_t) (void *func_data, char *file);
@@ -271,6 +274,15 @@ typedef struct lw6sys_hexa_serializer_s
 }
 lw6sys_hexa_serializer_t;
 
+typedef struct lw6sys_url_s
+{
+  int use_ssl;
+  char *host;
+  int port;
+  char *uri;
+}
+lw6sys_url_t;
+
 extern lw6sys_color_f_t LW6SYS_COLOR_F_WHITE;
 extern lw6sys_color_f_t LW6SYS_COLOR_F_BLACK;
 extern lw6sys_color_f_t LW6SYS_COLOR_F_RED;
@@ -407,6 +419,7 @@ extern char *lw6sys_build_get_includedir ();
 extern char *lw6sys_build_get_localedir ();
 extern char *lw6sys_build_get_docdir ();
 extern char *lw6sys_build_get_enable_console ();
+extern char *lw6sys_build_get_enable_gtk ();
 extern char *lw6sys_build_get_enable_mod_gl ();
 extern char *lw6sys_build_get_enable_mod_csound ();
 extern char *lw6sys_build_get_enable_mod_ogg ();
@@ -423,6 +436,32 @@ extern char *lw6sys_build_get_enable_valgrind ();
 extern int lw6sys_build_get_bin_id ();
 extern void lw6sys_build_log_all ();
 
+/* sys-chr.c */
+static inline int
+lw6sys_chr_is_digit (char c)
+{
+  return (c >= '0' && c <= '9');
+}
+
+static inline int
+lw6sys_chr_is_alnum (char c)
+{
+  return (c >= '0' && c <= '9') || (c >= 'a' && c <= 'z') || (c >= 'A'
+							      && c <= 'Z');
+}
+
+static inline int
+lw6sys_chr_is_space (char c)
+{
+  return (c == ' ' || c == '\t');
+}
+
+static inline int
+lw6sys_chr_is_eol (char c)
+{
+  return (c == '\n' || c == '\r');
+}
+
 /* sys-checksum.c */
 extern u_int32_t lw6sys_checksum (unsigned char *data, int len);
 extern u_int32_t lw6sys_checksum_str (char *value);
@@ -493,17 +532,30 @@ extern int lw6sys_dump (char *user_dir, char *content);
 extern char lw6sys_env_separator_char ();
 extern char *lw6sys_env_separator_str ();
 extern char *lw6sys_env_concat (char *value1, char *value2);
-extern int lw6sys_env_exists (char *keyword);
-extern char *lw6sys_getenv (char *keyword);
+extern int lw6sys_env_exists_prefixed (char *keyword);
+extern char *lw6sys_getenv (char *key);
+extern char *lw6sys_getenv_prefixed (char *keyword);
 extern int lw6sys_setenv (char *keyword, char *value);
+extern int lw6sys_setenv_prefixed (char *keyword, char *value);
 extern lw6sys_list_t *lw6sys_env_split (char *value);
 extern char *lw6sys_get_home ();
 extern char *lw6sys_get_username ();
 extern char *lw6sys_get_hostname ();
 
+/* sys-escape.c */
+extern char *lw6sys_escape_http_uri (char *src);
+extern char *lw6sys_escape_html_attribute (char *src);
+extern char *lw6sys_escape_sql_value (char *src);
+
+/* sys-exec.c */
+extern char *lw6sys_exec_find_myself (int argc, char *argv[]);
+extern int lw6sys_is_executed_again (int argc, char *argv[]);
+extern int lw6sys_exec_again (int argc, char *argv[]);
+
 /* sys-file.c */
 extern int lw6sys_clear_file (char *filename);
 extern char *lw6sys_read_file_content (char *filename);
+extern void *lw6sys_read_file_content_bin (int *filesize, char *filename);
 extern int lw6sys_write_file_content (char *filename, char *content);
 
 /* sys-profiler.c */
@@ -583,6 +635,9 @@ extern int lw6sys_hexa_serializer_pop_whd (lw6sys_hexa_serializer_t *
 extern int lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
 					     hexa_serializer,
 					     lw6sys_color_8_t * value);
+extern void *lw6sys_hexa_str_to_ptr (char *str);
+extern char *lw6sys_hexa_ptr_to_str (void *ptr);
+
 /* sys-history.c */
 extern void lw6sys_history_init ();
 extern void lw6sys_history_register (char *msg);
@@ -618,6 +673,9 @@ extern int lw6sys_list_length (lw6sys_list_t * list);
 extern void lw6sys_list_map (lw6sys_list_t * list,
 			     lw6sys_list_callback_func_t func,
 			     void *func_data);
+extern void lw6sys_list_filter (lw6sys_list_t ** list,
+				lw6sys_list_filter_func_t func,
+				void *func_data);
 extern void lw6sys_list_push_front (lw6sys_list_t ** list, void *data);
 extern void *lw6sys_list_pop_front (lw6sys_list_t ** list);
 extern void lw6sys_list_push_back (lw6sys_list_t ** list, void *data);
@@ -710,6 +768,11 @@ extern char *lw6sys_get_map_path (int argc, char *argv[]);
 extern char *lw6sys_get_script_file (int argc, char *argv[]);
 extern void lw6sys_options_log (int argc, char *argv[]);
 
+/* sys-password.c */
+extern char *lw6sys_password_checksum (char *seed, char *password);
+extern int lw6sys_password_verify (char *seed, char *password_here,
+				   char *password_received);
+
 /* sys-path.c */
 extern int lw6sys_file_exists (char *filename);
 extern int lw6sys_dir_exists (char *dirname);
@@ -821,8 +884,12 @@ extern char *lw6sys_str_concat (char *str1, char *str2);
 extern char *lw6sys_new_sprintf (char *fmt, ...);
 extern int lw6sys_str_is_blank (char *str);
 extern int lw6sys_str_is_same (char *str_a, char *str_b);
+extern int lw6sys_str_is_same_no_case (char *str_a, char *str_b);
+extern int lw6sys_str_starts_with (char *str, char *beginning);
+extern int lw6sys_str_starts_with_no_case (char *str, char *beginning);
 extern int lw6sys_skip_blanks (char **str_ptr);
 extern void lw6sys_str_cleanup (char *str);
+extern void lw6sys_str_cleanup_ascii7 (char *str);
 extern char *lw6sys_str_reformat (char *str, char *prefix, int nb_columns);
 extern char *lw6sys_eol ();
 extern lw6sys_list_t *lw6sys_str_split (char *str, char c);
@@ -830,8 +897,10 @@ extern lw6sys_list_t *lw6sys_str_split_no_0 (char *str, char c);
 extern lw6sys_list_t *lw6sys_str_split_config_item (char *str);
 extern void lw6sys_str_toupper (char *str);
 extern void lw6sys_str_tolower (char *str);
+extern void lw6sys_str_truncate (char *str, int len);
 
 /* sys-test.c */
+extern int lw6sys_test_exec (int argc, char *argv[], int mode);
 extern int lw6sys_test (int mode);
 
 /* sys-testandset.s */
@@ -859,7 +928,18 @@ extern void lw6sys_timer_update (int64_t * timestamp, int64_t * uptime,
 extern void lw6sys_sleep (float seconds);
 extern void lw6sys_delay (int msec);
 extern void lw6sys_idle ();
+extern void lw6sys_snooze ();
 extern void lw6sys_time_init ();
+extern char *lw6sys_date_rfc1123 (int seconds_from_now);
+extern char *lw6sys_date_clf ();
+extern char *lw6sys_readable_uptime (int64_t timestamp_delta);
+
+/* sys-url.c */
+extern char *lw6sys_url_http_from_ip_port (char *ip, int port);
+extern lw6sys_url_t *lw6sys_url_parse (char *url);
+extern void lw6sys_url_free (lw6sys_url_t * url);
+extern char *lw6sys_url_canonize (char *url);
+extern int lw6sys_url_is_canonized (char *url);
 
 /* sys-vthread.c */
 extern int lw6sys_vthread_run (lw6sys_thread_callback_func_t callback_func,
