@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -156,6 +156,8 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
   lw6map_level_t *level = NULL;
   int display_w = 0;
   int display_h = 0;
+  int bench_value = 0;
+  int magic_number = 0;
   lw6map_level_t *src2 = NULL;
   lw6sys_progress_t progress;
   float dummy = 0.0f;
@@ -188,6 +190,8 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
 			  (lw6sys_dup_func_t) lw6sys_str_copy);
       display_w = loader_data->stage1.display_w;
       display_h = loader_data->stage1.display_h;
+      bench_value = loader_data->stage1.bench_value;
+      magic_number = loader_data->stage1.magic_number;
 
       stage1_clear_request (&(loader_data->stage1));
     }
@@ -200,7 +204,8 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
       lw6sys_progress_begin (&progress);
       level =
 	lw6ldr_read_relative (map_path, relative_path, default_param,
-			      forced_param, display_w, display_h, &progress);
+			      forced_param, display_w, display_h, bench_value,
+			      magic_number, &progress);
       if (level)
 	{
 	  lw6sys_progress_end (&progress);
@@ -422,7 +427,8 @@ void
 lw6tsk_loader_push (lw6tsk_loader_t * loader, char *map_path,
 		    char *relative_path, lw6sys_assoc_t * default_param,
 		    lw6sys_assoc_t * forced_param,
-		    int display_w, int display_h)
+		    int display_w, int display_h, int bench_value,
+		    int magic_number)
 {
   _lw6tsk_loader_data_t *loader_data;
 
@@ -440,6 +446,8 @@ lw6tsk_loader_push (lw6tsk_loader_t * loader, char *map_path,
     lw6sys_assoc_dup (forced_param, (lw6sys_dup_func_t) lw6sys_str_copy);
   loader_data->stage1.display_w = display_w;
   loader_data->stage1.display_h = display_h;
+  loader_data->stage1.bench_value = bench_value;
+  loader_data->stage1.magic_number = magic_number;
 
   LOADER_UNLOCK;
 }
