@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #define TEST_MANAGER_SLEEP 1.0f
 #define TEST_LOOP_SLEEP 0.1f
 #define TEST_LOOP_N 600
-#define TEST_LOAD_MAP "strange-new-world"
+#define TEST_LOAD_MAP "subflower"
 #define TEST_OPTION_KEY1 LW6DEF_TOTAL_TIME
 #define TEST_OPTION_VALUE1 "250"
 #define TEST_OPTION_KEY2 LW6DEF_BACKGROUND_STYLE
@@ -75,11 +75,15 @@ test_manager ()
 	      {
 		lw6tsk_loader_push (manager, map_path, TEST_LOAD_MAP,
 				    default_param, forced_param,
-				    TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT);
+				    TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT,
+				    LW6LDR_DEFAULT_BENCH_VALUE,
+				    LW6LDR_DEFAULT_MAGIC_NUMBER);
 		lw6sys_sleep (TEST_LOOP_SLEEP);
 		lw6tsk_loader_push (manager, map_path, TEST_LOAD_MAP,
 				    default_param, forced_param,
-				    TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT);
+				    TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT,
+				    LW6LDR_DEFAULT_BENCH_VALUE,
+				    LW6LDR_DEFAULT_MAGIC_NUMBER);
 		for (i = 0; i < TEST_LOOP_N && !done; i++)
 		  {
 		    lw6sys_sleep (TEST_LOOP_SLEEP);
@@ -151,8 +155,17 @@ test_manager ()
   return ret;
 }
 
+/**
+ * lw6tsk_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @tsk module test suite.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6tsk_test ()
+lw6tsk_test (int mode)
 {
   int ret = 0;
 
@@ -161,12 +174,12 @@ lw6tsk_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6cfg_test ();
-      lw6hlp_test ();
-      lw6map_test ();
-      lw6ker_test ();
-      lw6ldr_test ();
+      lw6sys_test (mode);
+      lw6cfg_test (mode);
+      lw6hlp_test (mode);
+      lw6map_test (mode);
+      lw6ker_test (mode);
+      lw6ldr_test (mode);
     }
 
   ret = test_manager ();
