@@ -72,6 +72,7 @@ _("Music volume");		// extracted by scriptpo-update.sh
 _("Sound backend");		// extracted by scriptpo-update.sh
 _("Graphics backend");		// extracted by scriptpo-update.sh
 _("Sound backend");		// extracted by scriptpo-update.sh
+_("This is a test node.");	// extracted by scriptpo-update.sh
 _("testing map");		// extracted by scriptpo-update.sh
 _("testing game struct");	// extracted by scriptpo-update.sh
 _("testing game state");	// extracted by scriptpo-update.sh
@@ -80,6 +81,7 @@ _("testing bot");		// extracted by scriptpo-update.sh
 _("testing smobs GC, step 1");	// extracted by scriptpo-update.sh
 _("testing smobs GC, step 2");	// extracted by scriptpo-update.sh
 _("testing async load");	// extracted by scriptpo-update.sh
+_("testing db");		// extracted by scriptpo-update.sh
 _("testing node");		// extracted by scriptpo-update.sh
 _("begin main game loop");	// extracted by scriptpo-update.sh
 _("Please wait...");		// extracted by scriptpo-update.sh
@@ -130,9 +132,11 @@ _("Back to main menu");		// extracted by scriptpo-update.sh
 _("Play");			// extracted by scriptpo-update.sh
 _("Play");			// extracted by scriptpo-update.sh
 _("running \"~a\"");		// extracted by scriptpo-update.sh
+_("environment \"~a\" is \"~a\"");	// extracted by scriptpo-update.sh
+_("environment \"~a\" is \"~a\"");	// extracted by scriptpo-update.sh
 _("upgrading to version ~a");	// extracted by scriptpo-update.sh
-_("no graphical backend found, game can only run in pure server/console mode");	// extracted by scriptpo-update.sh
-_("server mode not implemented yet");	// extracted by scriptpo-update.sh
+_("no graphical backend found, game can only run in server mode");	// extracted by scriptpo-update.sh
+_("running in server mode");	// extracted by scriptpo-update.sh
 _("Display FPS");		// extracted by scriptpo-update.sh
 _("FPS hidden");		// extracted by scriptpo-update.sh
 _("Display MPS");		// extracted by scriptpo-update.sh
